@@ -345,6 +345,11 @@ return [
 			'url' => '/api/settings/importance-classification-default',
 			'verb' => 'PUT'
 		],
+		[
+			'name' => 'settings#setLayoutMessageView',
+			'url' => '/api/settings/layout-message-view',
+			'verb' => 'PUT'
+		],
 		[
 			'name' => 'trusted_senders#setTrusted',
 			'url' => '/api/trustedsenders/{email}',
@@ -490,6 +495,11 @@ return [
 			'url' => '/api/follow-up/check-message-ids',
 			'verb' => 'POST',
 		],
+		[
+			'name' => 'textBlockShares#getTextBlockShares',
+			'url' => '/api/textBlocks/{id}/shares',
+			'verb' => 'GET',
+		],
 	],
 	'resources' => [
 		'accounts' => ['url' => '/api/accounts'],
@@ -502,6 +512,8 @@ return [
 		'outbox' => ['url' => '/api/outbox'],
 		'preferences' => ['url' => '/api/preferences'],
 		'smimeCertificates' => ['url' => '/api/smime/certificates'],
+		'textBlock' => ['url' => '/api/textBlocks'],
+		'textBlockShares' => ['url' => '/api/textBlockshares'],
 	],
 	'ocs' => [
 		[
