@@ -41,6 +41,7 @@ OC.L10N.register(
     "Go back" : "Gaan terug",
     "Email address" : "E-posadres",
     "Cancel" : "Kanselleer",
+    "Accounts" : "Accounts",
     "Add mail account" : "Voeg posrekening toe",
     "General" : "Algemeen",
     "Register" : "Registreer",
@@ -83,6 +84,7 @@ OC.L10N.register(
     "Accept" : "Aanvaar",
     "Remove" : "Verwyder",
     "email" : "e-pos",
+    "Choose target folder" : "Kies teikenvouer",
     "Other" : "Ander",
     "Forward" : "Stuur aan",
     "View source" : "Bekyk bron",
@@ -91,29 +93,29 @@ OC.L10N.register(
     "Import into calendar" : "Voer in na kalender",
     "Download attachment" : "Laai aanhangsel af",
     "Move" : "Skuif",
-    "Loading …" : "Laai …",
     "Remove account" : "Verwyder rekening",
-    "Quota" : "Kwota",
+    "Add folder" : "Voeg 'n gids by",
     "Saving" : "Stoor tans",
+    "Loading …" : "Laai …",
     "New message" : "Nuwe boodskap",
     "Reply" : "Antwoord",
     "Retry" : "Herprobeer",
-    "Sending …" : "Stuur…",
     "Add" : "Voeg by",
     "Date" : "Datum",
     "Tags" : "Etikette",
     "Custom" : "Eie",
     "Message source" : "Boodskapbron",
-    "Actions" : "Aksies",
+    "Recipient" : "Ontvanger",
     "Priority" : "Prioriteit",
     "Reset" : "Herstel",
-    "Client ID" : "Kliënt-ID",
+    "Client ID" : "Klant-ID",
     "User" : "Gebruiker",
     "Host" : "Gasheer",
     "Port" : "Poort",
     "Valid until" : "Geldig tot",
     "Certificate" : "Sertifikaat",
     "Submit" : "Dien in",
+    "Shared" : "Gedeel",
     "Connect your mail account" : "Koppel u posrekening",
     "All" : "Alle",
     "Drafts" : "Konsepte",
@@ -127,6 +129,7 @@ OC.L10N.register(
     "Forwarding to %s" : "Stuur aan na %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
     "Redirect" : "Herverwys",
-    "The link leads to %s" : "Die skakel lei na %s"
+    "The link leads to %s" : "Die skakel lei na %s",
+    "Actions" : "Aksies"
 },
 "nplurals=2; plural=(n != 1);");
