@@ -46,6 +46,7 @@ OC.L10N.register(
     "Sorting" : "Orde",
     "Gravatar settings" : "Configuración de Gravatar",
     "Register" : "Rexistrase",
+    "Shared with me" : "Compartióse conmigo",
     "S/MIME" : "S/MIME",
     "About" : "Tocante a",
     "Keyboard shortcuts" : "Atayos del tecláu",
@@ -54,6 +55,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Unviar",
     "Refresh" : "Anovar",
+    "Ok" : "D'acuerdu",
     "Certificate updated" : "Anovóse'l certificáu",
     "Could not update certificate" : "Nun se pudo anovar el certificáu",
     "Send later" : "Unviar dempués",
@@ -84,14 +86,12 @@ OC.L10N.register(
     "An error occurred, unable to delete the tag." : "Prodúxose un error, nun ye posible desaniciar la etiqueta.",
     "Plain text" : "Testu ensin formatu",
     "Rich text" : "Testu arriquecíu",
-    "No messages in this mailbox" : "Nun hai nengún mensaxe nesta bandexa",
     "No messages" : "Nun hai nengún mensaxe",
     "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
     "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
     "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
     "Could not delete message" : "Nun se pudo desaniciar el mensaxe",
     "Could not archive message" : "Nun se pudo archivar el mensaxe",
-    "Draft: " : "Borrador:",
     "Encrypted message" : "Mensaxe cifráu",
     "This message is unread" : "Esta mensaxe ta ensin lleer",
     "Favorite" : "Meter en Favoritos",
@@ -100,7 +100,9 @@ OC.L10N.register(
     "Edit tags" : "Editar le setiquetes",
     "Move thread" : "Mover el filu",
     "Archive thread" : "Archivar el filu",
+    "Archive message" : "Archivar el mensaxe",
     "Delete thread" : "Desaniciar el filu",
+    "Delete message" : "Desaniciar el mensaxe",
     "More actions" : "Más aiciones",
     "Back" : "Atrás",
     "Create event" : "Crear un eventu",
@@ -131,12 +133,11 @@ OC.L10N.register(
     "Decline" : "Refugar",
     "Tentatively accept" : "Aceptar provisionalmente",
     "More options" : "Más opciones",
-    "This event is in the past." : "Esti eventu ye del pasáu.",
     "individual" : "individual",
     "domain" : "dominiu",
     "Remove" : "Quitar",
-    "Could not open mailbox" : "Nun se pudo abrir la bandexa de corréu",
     "Loading messages …" : "Cargando los mensaxes…",
+    "Choose target folder" : "Escoyer la carpeta de destín",
     "No more submailboxes in here" : "Equí nun hai más sobandexes",
     "Important info" : "Información importante",
     "Forward" : "Avanzar",
@@ -153,27 +154,21 @@ OC.L10N.register(
     "Show images temporarily" : "Amosar les imáxenes temporalmente",
     "Quoted text" : "Cita",
     "Move" : "Mover",
-    "Loading …" : "Cargando…",
-    "Not supported by the server" : "Nun ye compatible col sirvidor",
-    "{usage} of {limit} used" : "{usage} de {limit} n'usu",
     "Remove account" : "Quitar la cuenta",
     "Remove {email}" : "Quitar {email}",
-    "Quota" : "Cuota",
-    "Add mailbox" : "Amestar una bandexa",
-    "Mailbox name" : "Nome de la bandexa",
+    "Add folder" : "Amestar una carpeta",
+    "Folder name" : "Nome de la carpeta",
     "Saving" : "Guardando",
     "Move up" : "Xubir",
     "Move down" : "Baxar",
-    "Show all mailboxes" : "Amosar toles bandexes",
-    "Collapse mailboxes" : "Contrayer toles bandexes",
+    "Show all folders" : "Amosar toles carpetes",
+    "Collapse folders" : "Contrayer carpetes",
     "_{total} message_::_{total} messages_" : ["{total} mensaxe","{total} mensaxes"],
+    "Loading …" : "Cargando…",
     "All messages in mailbox will be deleted." : "Van desaniciase tolos mensaxes d'esta bandexa.",
-    "The mailbox and all messages in it will be deleted." : "Van desaniciase toles bandexes y tolos mensaxes que contengan.",
-    "Delete mailbox" : "Desaniciar la bandexa",
-    "Delete mailbox {name}" : "Desaniciar la bandexa «{name}»",
+    "Delete folder" : "Desaniciar la carpeta",
     "An error occurred, unable to rename the mailbox." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
     "Rename" : "Renomar",
-    "Move mailbox" : "Mover la bandexa",
     "Outbox" : "Bandexa de salida",
     "New message" : "Mensaxe nuevu",
     "Edit message" : "Editar el mensaxe",
@@ -184,12 +179,11 @@ OC.L10N.register(
     "Failed to save draft" : "Nun se pue guardar el borrador",
     "Message discarded" : "Escartóse'l mensaxe",
     "Could not discard message" : "Nun se pudo escartar el mensaxe",
-    "Error sending your message" : "Hebo un error al unviar el mensaxe",
-    "Retry" : "Retentar",
-    "Sending …" : "Unviando…",
-    "Send anyway" : "Unviar de toes toes",
     "Maximize composer" : "Maximizar el compositor",
     "Minimize composer" : "Minimizar el compositor",
+    "Error sending your message" : "Hebo un error al unviar el mensaxe",
+    "Retry" : "Retentar",
+    "Send anyway" : "Unviar de toes toes",
     "First day" : "El primer día",
     "Message" : "Mensaxe",
     "Oh Snap!" : "¡Meca!",
@@ -220,6 +214,7 @@ OC.L10N.register(
     "Save sieve settings" : "Guardar la configuración de sieve",
     "The syntax seems to be incorrect:" : "La sintaxis paez ser incorreuta",
     "Save sieve script" : "Guardar el script de sieve",
+    "Message source" : "Orixe del mensaxe",
     "An error occurred, unable to rename the tag." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
     "Delete tag" : "Desaniciar la etiqueta",
     "Set tag" : "Afitar la etiqueta",
@@ -227,7 +222,7 @@ OC.L10N.register(
     "Tag already exists" : "La etiqueta yá esiste",
     "Tag name cannot be empty" : "El nome de la etiqueta nun pue tar baleru",
     "An error occurred, unable to create the tag." : "Prodúxose un error, nun ye posible crear la bandexa de corréu.",
-    "Add tag" : "Amestar la etiqueta",
+    "Add tag" : "Amestar una etiqueta",
     "Saving tag …" : "Guardando la etiqueta…",
     "Task created" : "Creóse la xera",
     "Could not create task" : "Nun se pudo crear la xera",
@@ -235,9 +230,6 @@ OC.L10N.register(
     "Could not load your message thread" : "Nun se pudo cargar el filu de mensaxes",
     "Loading thread" : "Cargando'l filu",
     "Not found" : "Nun s'atopó",
-    "Archive message" : "Archivar el mensaxe",
-    "Delete message" : "Desaniciar el mensaxe",
-    "Message source" : "Orixe del mensaxe",
     "Go to latest message" : "Dir al últimu mensaxe",
     "Go to newest message" : "Dir al mensaxe más nuevu",
     "The message could not be translated" : "Nun se pudo traducir el mensaxe",
@@ -251,8 +243,9 @@ OC.L10N.register(
     "Train" : "Tren",
     "Flag" : "Bandera",
     "Operator" : "Operador",
+    "contains" : "contién",
+    "matches" : "concasa",
     "Filter name" : "Nome de la peñera",
-    "Actions" : "Aiciones",
     "Priority" : "Prioridá",
     "Error saving config" : "Hebo un error al guardar la configuración",
     "Anti Spam Service" : "Serviciu de antispam",
@@ -284,7 +277,12 @@ OC.L10N.register(
     "Certificate" : "Certificáu",
     "Private key (optional)" : "Clave privada (opcional)",
     "Submit" : "Unviar",
-    "Account connected" : "Conectóse la cuenta",
+    "Guest" : "Convidáu",
+    "Group" : "Grupu",
+    "Shared" : "Compartióse",
+    "Shares" : "Comparticiones",
+    "Insert" : "Inxertar",
+    "Account connected" : "Cuenta conectada",
     "You can close this window" : "Pues zarrar esta ventana",
     "All" : "Too",
     "Drafts" : "Borradores",
@@ -307,6 +305,18 @@ OC.L10N.register(
     "Could not load the message" : "Nun se pudo cargar el mensaxe",
     "Error loading message" : "Hebo un error al cargar el mensaxe",
     "Redirect" : "Redirixir",
-    "The link leads to %s" : "L'enllaz lleva a %s"
+    "The link leads to %s" : "L'enllaz lleva a %s",
+    "No messages in this mailbox" : "Nun hai nengún mensaxe nesta bandexa",
+    "Draft: " : "Borrador:",
+    "Could not open mailbox" : "Nun se pudo abrir la bandexa de corréu",
+    "Add mailbox" : "Amestar una bandexa",
+    "Mailbox name" : "Nome de la bandexa",
+    "Show all mailboxes" : "Amosar toles bandexes",
+    "Collapse mailboxes" : "Contrayer toles bandexes",
+    "The mailbox and all messages in it will be deleted." : "Van desaniciase toles bandexes y tolos mensaxes que contengan.",
+    "Delete mailbox" : "Desaniciar la bandexa",
+    "Delete mailbox {name}" : "Desaniciar la bandexa «{name}»",
+    "Move mailbox" : "Mover la bandexa",
+    "Actions" : "Aiciones"
 },
 "nplurals=2; plural=(n != 1);");
