@@ -5,33 +5,35 @@ OC.L10N.register(
     "Work" : "İş",
     "Personal" : "Şəxsi",
     "Mail" : "Məktub",
+    "Save" : "Saxla",
+    "Connect" : "Qoşul",
     "Name" : "Ad",
     "Password" : "Şifrə",
     "None" : "Heç bir",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "SMTP Password" : "SMTP Şifrəsi",
-    "Save" : "Saxla",
-    "Connect" : "Qoşul",
     "Signature" : "İmza",
     "Cancel" : "Dayandır",
+    "Accounts" : "Accounts",
     "General" : "Ümumi",
     "Archive" : "Arxiv",
     "Delete" : "Sil",
     "Search" : "Axtarış",
     "Send" : "Göndər",
     "Refresh" : "Yenilə",
+    "Ok" : "Oldu",
     "Subject" : "Mövzu",
     "Enter a date" : "Tarixi əlavə edin",
-    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
     "Choose" : "Seç",
+    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
     "Confirm" : "Təsdiq edin",
     "Favorite" : "İstəkli",
     "Read" : "Oxu",
-    "Select" : "Select",
     "Back" : "Geri",
     "Description" : "Açıqlanma",
     "Create" : "Yarat",
+    "Select" : "Select",
     "Comment" : "Komentariya",
     "Accept" : "Qəbul et",
     "Decline" : "İmtina",
@@ -39,19 +41,17 @@ OC.L10N.register(
     "Other" : "Digər",
     "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
     "Move" : "Move",
-    "Quota" : "Norma",
+    "Folder name" : "Qovluq adı",
     "Saving" : "Saxlanılır",
     "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
     "Rename" : "Adı dəyiş",
     "Clear cache" : "Keşi təmizlə",
-    "Sending …" : "Göndərilir...",
     "Reply" : "Cavab",
     "Add" : "Əlavə etmək",
     "Close" : "Bağla",
     "Date" : "Date",
     "Tags" : "Işarələr",
     "Not found" : "Tapılmadı",
-    "Actions" : "İşlər",
     "Priority" : "Prioritet",
     "Reset" : "Sıfırla",
     "Client ID" : "Müştəri İD-s",
@@ -61,6 +61,8 @@ OC.L10N.register(
     "Port" : "Port",
     "Valid until" : "Vaxtadək keçərlidir",
     "Certificate" : "Sertifikat",
+    "Group" : "Qrup",
+    "Shares" : "Yayımlanmalar",
     "All" : "Hamısı",
     "Drafts" : "Qaralamalar",
     "Favorites" : "Sevimlilər",
@@ -68,6 +70,7 @@ OC.L10N.register(
     "Junk" : "Önəmsiz",
     "Sent" : "Göndərildi",
     "Trash" : "Zibil",
-    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi"
+    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi",
+    "Actions" : "İşlər"
 },
 "nplurals=2; plural=(n != 1);");
