@@ -98,6 +98,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Използване на аватари тип Gravatar и favicon",
     "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
     "Register" : "Регистрация",
+    "Shared with me" : "Споделено с мен",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
     "Trusted senders" : "Доверени податели",
     "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
@@ -115,6 +116,7 @@ OC.L10N.register(
     "Search" : "Търси",
     "Send" : "Изпрати",
     "Refresh" : "Опресняване",
+    "Ok" : "Добре",
     "No certificate" : "Няма сертификат",
     "Certificate updated" : "Актуализиран е сертификат",
     "Could not update certificate" : "Сертификата не можа да се актуализира",
@@ -248,6 +250,8 @@ OC.L10N.register(
     "email" : "имейл",
     "Itinerary for {type} is not supported yet" : "Маршрутът за {type} все още не се поддържа",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Нямате право да преместите това съобщение в архивната папка и/или да изтриете това съобщение от текущата папка",
+    "Last hour" : "Последния  час",
+    "Last week" : "Миналата седмица",
     "Loading messages …" : "Зареждане на съобщения ...",
     "Choose target folder" : "Избор на папка",
     "No more submailboxes in here" : "Тук няма повече допълнителни пощенски кутии",
@@ -300,6 +304,7 @@ OC.L10N.register(
     "Move up" : "Преместване нагоре",
     "Move down" : "Преместване  надолу",
     "Show all folders" : "Покажи всички папки",
+    "Collapse folders" : "Свиване на папки",
     "_{total} message_::_{total} messages_" : ["{total} съобщения","{total} съобщения"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочетени от {total}","{unread} непрочетени от {total}"],
     "Loading …" : "Зарежда …",
@@ -522,6 +527,9 @@ OC.L10N.register(
     "Private key (optional)" : "Частен ключ (по избор)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Частният ключ е необходим само ако възнамерявате да изпращате подписани и криптирани имейли, като използвате този сертификат.",
     "Submit" : "Изпращане",
+    "Shared" : "Споделен",
+    "Shares" : "Споделени",
+    "Insert" : "Вмъкване",
     "Account connected" : "Профилът е свързан",
     "You can close this window" : "Можете да затворите този прозорец",
     "Connect your mail account" : "Свързване към ваш имейл профил",
