@@ -37,6 +37,7 @@ OC.L10N.register(
     "Accept" : "Asantiñ",
     "Remove" : "Lemel",
     "email" : "postel",
+    "Choose target folder" : "Dibab an teuliad moned",
     "Important info" : "Titouroù pouezus",
     "Other" : "All",
     "Forward" : "War-raok",
@@ -44,9 +45,12 @@ OC.L10N.register(
     "Show images" : "Diskouzh ar skeudennoù",
     "Message frame" : "Fram kemenadenn",
     "Move" : "Diplasañ",
-    "Loading …" : "O Kargañ ...",
     "Remove account" : "Lemel ar c'hont",
-    "Quota" : "Quota",
+    "Folder name" : "Anv teuliad",
+    "Loading …" : "O Kargañ ...",
+    "The folder and all messages in it will be deleted." : "An teuliad a pep kemenadenn enhañ a vo lamet",
+    "Delete folder" : "Diverkañ an teuliad",
+    "Delete folder {name}" : "Lemel an teuliad {folderid}",
     "Rename" : "Adenvel",
     "Clear cache" : "Gwalc'hiñ ar c'hache",
     "Reply" : "Respont",
@@ -56,16 +60,19 @@ OC.L10N.register(
     "Close" : "Serriñ",
     "Date" : "Deiz",
     "Tags" : "Klavioù",
-    "Actions" : "Oberoù",
+    "Translate to" : "Treiñ e",
     "Client ID" : "ID kliant",
     "User" : "Implijer",
     "Host" : "Ostiz",
     "Port" : "Porzh",
     "Valid until" : "Gwir betek",
     "Submit" : "Kinnig",
+    "Shared" : "Rannet",
+    "Shares" : "Rannañ",
     "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
-    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
+    "Actions" : "Oberoù"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
