@@ -49,6 +49,7 @@ OC.L10N.register(
     "Search" : "Chwilio",
     "Send" : "Anfon",
     "Refresh" : "Ail-lwytho",
+    "Ok" : "Iawn",
     "Subject" : "Pwnc",
     "Saving draft …" : "Yn cadw drafft …",
     "Draft saved" : "Cadwyd y drafft",
@@ -70,6 +71,7 @@ OC.L10N.register(
     "Accept" : "Derbyn",
     "Decline" : "Gwrthod",
     "Remove" : "Gwaredu",
+    "Today" : "Heddiw",
     "Other" : "Arall",
     "Translate" : "Cyfieithu",
     "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
@@ -103,6 +105,8 @@ OC.L10N.register(
     "Recipient" : "Derbynnydd",
     "User" : "Defnyddwyr",
     "Certificate" : "Tystysgrif",
+    "Group" : "Grŵp",
+    "Shared" : "Rhannwyd",
     "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
     "All" : "Popeth",
     "Drafts" : "Drafftiau",
