@@ -116,6 +116,7 @@ OC.L10N.register(
     "Search" : "Søg",
     "Send" : "Send",
     "Refresh" : "Opdater",
+    "Ok" : "OK",
     "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
     "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
     "Send later" : "Send senere",
@@ -229,6 +230,8 @@ OC.L10N.register(
     "More options" : "Flere muligheder",
     "Remove" : "Fjern",
     "email" : "e-mail",
+    "Today" : "I dag",
+    "Last week" : "Seneste uge",
     "Loading messages …" : "Indlæser beskeder...",
     "Choose target folder" : "Vælg destinationsmappe",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
@@ -266,7 +269,7 @@ OC.L10N.register(
     "Move up" : "Flyt op",
     "Move down" : "Flyt ned",
     "Show all folders" : "Vis alle mapper",
-    "Collapse mailboxes" : "Skjul postkasser ",
+    "Collapse folders" : "Fold mapper sammen",
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
     "Loading …" : "Indlæser…",
     "Clear mailbox {name}" : "Ryd postkasse {name}",
@@ -370,6 +373,10 @@ OC.L10N.register(
     "Private key (optional)" : "Privat nøgle (valgfrit)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøgle er kun påkrævet, hvis du har til hensigt at sende signerede og krypterede e-mails ved hjælp af dette certifikat.",
     "Submit" : "Send",
+    "Group" : "Gruppe",
+    "Shared" : "Delt",
+    "Shares" : "Delinger",
+    "Insert" : "Indsæt",
     "Account connected" : "Kontoen er tilknyttet",
     "Connect your mail account" : "Forbind din mail konto",
     "All" : "Alle",
@@ -408,6 +415,7 @@ OC.L10N.register(
     "Add mailbox" : "Tilføj postkasse",
     "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
     "Show all mailboxes" : "Vis alle postkasser",
+    "Collapse mailboxes" : "Skjul postkasser ",
     "Clear mailbox" : "Ryd postkasse",
     "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
     "Add submailbox" : "Tilføj underpostkasse",
