@@ -59,6 +59,7 @@ OC.L10N.register(
     "Search" : "Serĉi",
     "Send" : "Sendi",
     "Refresh" : "Aktualigi",
+    "Ok" : "Bone",
     "From" : "De",
     "Select account" : "Elekti konton",
     "To" : "Al",
@@ -77,8 +78,8 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
     "Confirm" : "Konfirmi",
     "Plain text" : "Ebenaĵa teksto",
+    "No messages in this folder" : "Neniu mesaĝo en tiu dosierujo",
     "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
-    "Draft: " : "Malneto:",
     "Unfavorite" : "Malpliŝatati",
     "Favorite" : "Pliŝatati",
     "Read" : "Legi",
@@ -96,8 +97,8 @@ OC.L10N.register(
     "Decline" : "Malakcepti",
     "Remove" : "Forigi",
     "email" : "retpoŝtadreso",
-    "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
+    "Today" : "Hodiaŭ",
+    "Choose target folder" : "Elekti celan dosierujon",
     "Other" : "Alia",
     "Forward" : "Antaŭen",
     "Translate" : "Traduku",
@@ -111,21 +112,24 @@ OC.L10N.register(
     "Save all to Files" : "Konservi ĉiujn al „Dosieroj“",
     "The images have been blocked to protect your privacy." : "Bildoj ne montriĝis por protekti vian privatecon.",
     "Move" : "Movi",
-    "Loading …" : "Ŝargas …",
     "Remove account" : "Forigi konton",
-    "Quota" : "Kvoto",
+    "Add folder" : "Aldoni dosierujon",
+    "Folder name" : "Dosierujnomo",
     "Saving" : "Konservado",
     "Move down" : "Movi malsupren",
+    "Show all folders" : "Montri ĉiujn dosierujojn",
+    "Collapse folders" : "Maletendi dosierujojn",
     "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
+    "Loading …" : "Ŝargas …",
     "Mark all as read" : "Marki ĉion kiel legita",
+    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
+    "Add subfolder" : "Aldoni subdosierujon",
     "Rename" : "Alinomi",
     "Clear cache" : "Forviŝi la kaŝmemoron",
     "New message" : "Nova mesaĝo",
     "Reply" : "Respondi",
     "Error sending your message" : "Eraro dum sendo de via mesaĝo",
     "Retry" : "Reprovi",
-    "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
-    "Sending …" : "Sendado...",
     "Message" : "Mesaĝo",
     "Copy to clipboard" : "Kopii tondejen",
     "Add" : "Aldoni",
@@ -153,7 +157,8 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
     "Train" : "Trajno",
-    "Actions" : "Agoj",
+    "Recipient" : "Ricevonto",
+    "matches" : "kongruas kun",
     "Priority" : "Prioritato",
     "Mail app" : "Retpoŝtprogrameto",
     "Reset" : "Restarigi",
@@ -169,6 +174,9 @@ OC.L10N.register(
     "Valid until" : "Valida ĝis",
     "Certificate" : "Atestilo",
     "Submit" : "Sendi",
+    "Group" : "Grupo",
+    "Shared" : "Kunhavigita",
+    "Shares" : "Kunhavoj",
     "Account connected" : "Konto konektita",
     "Connect your mail account" : "Konekti vian retpoŝtan konton",
     "All" : "Ĉiuj",
@@ -192,6 +200,10 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
     "Redirect" : "Alidirekto",
     "The link leads to %s" : "La ligilo iras al %s",
-    "Continue to %s" : "Daŭrigi al %s"
+    "Continue to %s" : "Daŭrigi al %s",
+    "Draft: " : "Malneto:",
+    "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
+    "Actions" : "Agoj"
 },
 "nplurals=2; plural=(n != 1);");
