@@ -63,6 +63,7 @@ OC.L10N.register(
     "More options" : "Más opciones",
     "Remove" : "Borrar",
     "email" : "correo electrónico",
+    "Today" : "Hoy",
     "Choose target folder" : "Elegir carpeta destino",
     "Other" : "Otro",
     "Forward" : "Reenviar",
@@ -79,6 +80,7 @@ OC.L10N.register(
     "Folder name" : "Nombre de la carpeta",
     "Saving" : "Guardando",
     "Show all folders" : "Mostrar todos las carpetas",
+    "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Limpiar caché",
@@ -110,6 +112,9 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
+    "Group" : "Grupo",
+    "Shared" : "Compartido",
+    "Shares" : "Elementos compartido",
     "Account connected" : "Cuenta conectada",
     "Connect your mail account" : "Conecte su cuenta de correo",
     "All" : "Todos",
