@@ -113,6 +113,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
+    "Ok" : "Ok",
     "No certificate" : "Sin certificado",
     "Certificate updated" : "Certificado actualizado",
     "Could not update certificate" : "No se pudo actualizar el certificado",
@@ -163,6 +164,7 @@ OC.L10N.register(
     "Custom date and time" : "Fecha y hora personalizada",
     "Enter a date" : "Ingresa una fecha",
     "Choose" : "Seleccionar",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["El archivo adjunto supera el tamaño permitido de archivos adjuntos de {size}. Comparte el archivo a través de un enlace en su lugar.","Los archivos adjuntos superan el tamaño permitido de archivos adjuntos de {size}. Comparte los archivos a través de un enlace en su lugar.","Los archivos adjuntos superan el tamaño permitido de archivos adjuntos de {size}. Comparte los archivos a través de un enlace en su lugar."],
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Choose a file to share as a link" : "Elige un archivo para compartir como enlace",
     "_{count} attachment_::_{count} attachments_" : ["{count} adjunto","{count} adjuntos","{count} adjuntos"],
@@ -172,14 +174,12 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Plain text" : "Texto sin formato",
     "Rich text" : "Texto enriquecido",
-    "No messages in this mailbox" : "No hay mensajes en esta bandeja de entrada",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "No messages" : "Sin mensajes",
     "Blind copy recipients only" : "Copias ocultas para los destinatarios solamente",
     "No subject" : "Sin asunto",
-    "No trash mailbox configured" : "No se ha configurado una bandeja de papelera",
     "Could not delete message" : "No se pudo eliminar el mensaje",
     "Could not archive message" : "No se pudo archivar el mensaje",
-    "Draft: " : "Borrador: ",
     "Encrypted message" : "Mensaje cifrado",
     "This message is unread" : "Este mensaje no se ha leído",
     "Unfavorite" : "Quitar favorito",
@@ -192,7 +192,9 @@ OC.L10N.register(
     "Edit tags" : "Editar etiquetas",
     "Move thread" : "Mover hilo",
     "Archive thread" : "Archivar hilo",
+    "Archive message" : "Archivar mensaje",
     "Delete thread" : "Eliminar hilo",
+    "Delete message" : "Eliminar mensaje",
     "More actions" : "Más acciones",
     "Back" : "Atrás",
     "Edit as new message" : "Editar como nuevo mensaje",
@@ -235,18 +237,18 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Tentatively accept" : "Aceptar tentativamente",
     "More options" : "Más opciones",
-    "This event is in the past." : "Este evento está en el pasado.",
     "individual" : "individual",
     "domain" : "dominio",
     "Remove" : "Eliminar",
     "email" : "correo electrónico",
     "Itinerary for {type} is not supported yet" : "El itinerario de {type} aún no es compatible",
-    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivo en la configuración de la cuenta",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivos y/o eliminar este mensaje de la carpeta actual",
-    "Could not open mailbox" : "No se pudo abrir el buzón",
+    "Last hour" : "Última hora",
+    "Today" : "Hoy",
+    "Last week" : "La semana pasada",
+    "Last month" : "El mes pasado",
     "Loading messages …" : "Cargando mensajes...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexando tus mensajes. Esto puede llevar un poco más de tiempo para buzones más grandes.",
-    "Choose target mailbox" : "Selecciona el buzón de destino",
+    "Choose target folder" : "Selecciona la carpeta de destino.",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Los mensajes se marcarán automáticamente como importantes en función de los mensajes con los que interactúes o que marques como importantes. Al principio, es posible que debas cambiar manualmente la importancia para enseñar al sistema, pero mejorará con el tiempo.",
     "Important info" : "Información importante",
@@ -287,37 +289,26 @@ OC.L10N.register(
     "Moving" : "Moviendo",
     "Moving thread" : "Moviendo hilo",
     "Moving message" : "Moviendo mensaje",
-    "Loading …" : "Loading …",
-    "Not supported by the server" : "No es compatible con el servidor",
-    "{usage} of {limit} used" : "{usage} de {limit} usado",
     "Remove account" : "Eliminar cuenta",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "La cuenta para {email} y los datos de correo en caché se eliminarán de Nextcloud, pero no de tu proveedor de correo electrónico.",
     "Remove {email}" : "Eliminar {email}",
     "Provisioned account is disabled" : "La cuenta proporcionada está desactivada",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Inicia sesión usando una contraseña para habilitar esta cuenta. La sesión actual está utilizando autenticación sin contraseña, como SSO o WebAuthn.",
-    "Quota" : "Cuota",
-    "Show only subscribed mailboxes" : "Mostrar solo buzones suscritos",
-    "Add mailbox" : "Agregar buzón",
+    "Folder name" : "Nombre de la carpeta",
     "Saving" : "Guardando",
     "Move up" : "Mover hacia arriba",
     "Move down" : "Mover hacia abajo",
-    "Show all subscribed mailboxes" : "Mostrar todos los buzones suscritos",
-    "Show all mailboxes" : "Mostrar todos los buzones",
-    "Collapse mailboxes" : "Colapsar buzones",
+    "Show all folders" : "Mostrar todas las carpetas",
+    "Collapse folders" : "Compactar carpetas",
     "_{total} message_::_{total} messages_" : ["{total} mensaje","{total} mensajes","{total} mensajes"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} sin leer de {total}","{unread} sin leer de {total}","{unread} sin leer de {total}"],
+    "Loading …" : "Loading …",
     "All messages in mailbox will be deleted." : "Se eliminarán todos los mensajes del buzón.",
     "Clear mailbox {name}" : "Limpiar buzón {name}",
-    "Clear mailbox" : "Limpiar buzón",
-    "The mailbox and all messages in it will be deleted." : "Se eliminará el buzón y todos los mensajes en él.",
-    "Delete mailbox" : "Eliminar buzón",
-    "Delete mailbox {name}" : "Eliminar buzón {name}",
     "An error occurred, unable to rename the mailbox." : "Se produjo un error, no se puede cambiar el nombre del buzón.",
     "Mark all as read" : "Marcar todos como leídos",
-    "Mark all messages of this mailbox as read" : "Marcar todos los mensajes de este buzón como leídos",
-    "Add submailbox" : "Agregar sub-buzón",
     "Rename" : "Renombrar",
-    "Move mailbox" : "Mover buzón",
+    "Move folder" : "Mover carpeta",
     "Clear cache" : "Borrar el caché",
     "Clear locally cached data, in case there are issues with synchronization." : "Borrar datos en caché local, en caso de problemas con la sincronización.",
     "Subscribed" : "Suscrito",
@@ -330,17 +321,14 @@ OC.L10N.register(
     "Message saved" : "Mensaje guardado",
     "Failed to save message" : "Error al guardar el mensaje",
     "Failed to save draft" : "Error al guardar el borrador",
-    "No sent mailbox configured. Please pick one in the account settings." : "No hay un buzón de envío configurado. Por favor, elige uno en la configuración de la cuenta.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Estás intentando enviar a muchos destinatarios en Para y/o Cc. Considera usar Bcc para ocultar las direcciones de los destinatarios.",
     "Message discarded" : "Mensaje descartado",
     "Could not discard message" : "No se pudo descartar el mensaje",
+    "Minimize composer" : "Minimizar editor",
     "Error sending your message" : "Error al enviar tu mensaje",
     "Retry" : "Reintentar",
-    "Uploading attachments …" : "Subiendo adjuntos...",
-    "Sending …" : "Enviando ...",
     "Warning sending your message" : "Advertencia al enviar tu mensaje",
     "Send anyway" : "Enviar de todos modos",
-    "Minimize composer" : "Minimizar editor",
     "Autoresponder off" : "Respuesta automática desactivada",
     "Autoresponder on" : "Respuesta automática activada",
     "First day" : "Primer día",
@@ -364,7 +352,6 @@ OC.L10N.register(
     "Show less" : "Mostrar menos",
     "Show more" : "Mostrar más",
     "Clear" : "Limpiar",
-    "Search in mailbox" : "Buscar en el correo",
     "Close" : "Cerrar",
     "Search parameters" : "Parámetros de búsqueda",
     "Body" : "Cuerpo",
@@ -390,6 +377,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Tu firma tiene un tamaño mayor de 2 MB. Esto puede afectar el rendimiento de tu editor.",
     "Save signature" : "Guardar firma",
     "Place signature above quoted text" : "Colocar firma sobre el texto citado",
+    "Message source" : "Origen del mensaje",
     "An error occurred, unable to rename the tag." : "Ocurrió un error, no se pudo cambiar el nombre de la etiqueta.",
     "Saving new tag name …" : "Guardando nuevo nombre de etiqueta ...",
     "Set tag" : "Establecer etiqueta",
@@ -422,9 +410,6 @@ OC.L10N.register(
     "Mark as favorite" : "Marcar como favorito",
     "Mark as unread" : "Marcar como no leído",
     "Mark as read" : "Marcar como leído",
-    "Archive message" : "Archivar mensaje",
-    "Delete message" : "Eliminar mensaje",
-    "Message source" : "Origen del mensaje",
     "Unsubscribe via link" : "Cancelar suscripción mediante enlace",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Cancelar la suscripción detendrá todos los mensajes de la lista de correo {sender}",
     "Send unsubscribe email" : "Enviar correo electrónico de cancelación de suscripción",
@@ -452,9 +437,10 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Tren desde {depStation} a {arrStation}",
     "Train" : "Tren",
     "Flag" : "Bandera",
+    "Recipient" : "Destinatario",
     "Operator" : "Operador",
-    "Actions" : "Acciones",
-    "New action" : "Nueva acción",
+    "contains" : "contiene",
+    "matches" : "coincide",
     "Priority" : "Prioridad",
     "Successfully updated config for \"{domain}\"" : "Configuración actualizada con éxito para \"{domain}\"",
     "Error saving config" : "Error al guardar la configuración",
@@ -488,8 +474,6 @@ OC.L10N.register(
     "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail permite a los usuarios acceder a su correo electrónico a través de IMAP. Por razones de seguridad, este acceso solo es posible con una conexión OAuth 2.0 o cuentas de Google que utilizan autenticación de dos factores y contraseñas de aplicaciones.",
     "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Debes registrar un nuevo ID de cliente para una \"aplicación web\" en la consola de Google Cloud. Agrega la URL {url} como URI de redirección autorizado.",
     "Microsoft integration" : "Integración con Microsoft",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft permite a los usuarios acceder a su correo electrónico a través de IMAP. Por razones de seguridad, este acceso solo es posible con una conexión OAuth 2.0.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Debes registrar una nueva aplicación en el portal de Microsoft Azure Active Directory. Agrega la URL {url} como URI de redirección.",
     "Successfully set up anti spam email addresses" : "Direcciones de correo electrónico para informes de spam configuradas con éxito",
     "Error saving anti spam email addresses" : "Error al guardar las direcciones de correo electrónico para informes de spam",
     "Successfully deleted anti spam reporting email" : "Correo electrónico de informe de spam eliminado correctamente",
@@ -556,6 +540,10 @@ OC.L10N.register(
     "Private key (optional)" : "Clave privada (opcional)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "La clave privada solo es necesaria si tienes la intención de enviar correos electrónicos firmados y cifrados usando este certificado.",
     "Submit" : "Enviar",
+    "Group" : "Grupo",
+    "Shared" : "Compartido",
+    "Shares" : "Elementos compartido",
+    "Insert" : "Insertar",
     "Account connected" : "Cuenta conectada",
     "You can close this window" : "Puedes cerrar esta ventana",
     "Connect your mail account" : "Conecta tu cuenta de correo",
@@ -592,6 +580,29 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "No messages in this mailbox" : "No hay mensajes en esta bandeja de entrada",
+    "No trash mailbox configured" : "No se ha configurado una bandeja de papelera",
+    "Draft: " : "Borrador: ",
+    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivo en la configuración de la cuenta",
+    "Could not open mailbox" : "No se pudo abrir el buzón",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexando tus mensajes. Esto puede llevar un poco más de tiempo para buzones más grandes.",
+    "Choose target mailbox" : "Selecciona el buzón de destino",
+    "Show only subscribed mailboxes" : "Mostrar solo buzones suscritos",
+    "Add mailbox" : "Agregar buzón",
+    "Show all subscribed mailboxes" : "Mostrar todos los buzones suscritos",
+    "Show all mailboxes" : "Mostrar todos los buzones",
+    "Collapse mailboxes" : "Colapsar buzones",
+    "Clear mailbox" : "Limpiar buzón",
+    "The mailbox and all messages in it will be deleted." : "Se eliminará el buzón y todos los mensajes en él.",
+    "Delete mailbox" : "Eliminar buzón",
+    "Delete mailbox {name}" : "Eliminar buzón {name}",
+    "Mark all messages of this mailbox as read" : "Marcar todos los mensajes de este buzón como leídos",
+    "Add submailbox" : "Agregar sub-buzón",
+    "Move mailbox" : "Mover buzón",
+    "No sent mailbox configured. Please pick one in the account settings." : "No hay un buzón de envío configurado. Por favor, elige uno en la configuración de la cuenta.",
+    "Search in mailbox" : "Buscar en el correo",
+    "Actions" : "Acciones",
+    "New action" : "Nueva acción"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
