@@ -17,6 +17,10 @@ OC.L10N.register(
     "Drafts are saved in:" : "Los borradores se guardan en:",
     "Sent messages are saved in:" : "Los mensajes enviados se guardan en:",
     "Deleted messages are moved in:" : "Los mensajes eliminados son movidos a:",
+    "Connecting" : "Conectando",
+    "Save" : "Guardar",
+    "Connect" : "Conectar",
+    "Password required" : "Se requiere contraseña",
     "Auto" : "Auto",
     "Name" : "Nombre",
     "Mail address" : "Dirección de correo",
@@ -39,10 +43,6 @@ OC.L10N.register(
     "SMTP Port" : "Puerto SMTP",
     "SMTP User" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
-    "Connecting" : "Conectando",
-    "Save" : "Guardar",
-    "Connect" : "Conectar",
-    "Password required" : "Se requiere contraseña",
     "Account settings" : "Ajustes de la cuenta",
     "Aliases" : "Aliases",
     "Signature" : "Firma",
@@ -60,6 +60,9 @@ OC.L10N.register(
     "Add alias" : "Añadir alias",
     "Create alias" : "Crear alias",
     "Cancel" : "Cancelar",
+    "Put my text to the bottom of a reply instead of on top of it." : "Ponga mi texto al final de la respuesta en vez de encima de ella.",
+    "Could not update preference" : "No se pudo actualizar la preferencia",
+    "Accounts" : "Accounts",
     "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
@@ -67,6 +70,7 @@ OC.L10N.register(
     "Register" : "Registrar",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir a la app recolectar datos sobre sus interacciones. Basándose en estos datos, la app se adaptará mejor a sus preferencias. Estos datos sólo se almacenan localmente.",
     "Trusted senders" : "Remitentes de confianza",
+    "About" : "Acerca",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -78,8 +82,8 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
-    "Put my text to the bottom of a reply instead of on top of it." : "Ponga mi texto al final de la respuesta en vez de encima de ella.",
-    "Could not update preference" : "No se pudo actualizar la preferencia",
+    "Ok" : "Ok",
+    "Message {id} could not be found" : "No se ha podido encontrar el mensaje {id}",
     "From" : "De",
     "Select account" : "Selecciona la cuenta",
     "To" : "Para",
@@ -99,16 +103,15 @@ OC.L10N.register(
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
     "Request a read receipt" : "Solicitar acuse de lectura",
     "Encrypt message with Mailvelope" : "Cifrar el mensaje con Mailvelope",
-    "Message {id} could not be found" : "No se ha podido encontrar el mensaje {id}",
+    "Choose" : "Seleccionar",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Los archivos adjuntos exceden el tamaño permitido de {size}. Por favor comparte a través de  un enlace.","Los archivos adjuntos superan el tamaño permitido de {size}. Por favor envía los archivos mediante un enlace.","Los archivos adjuntos superan el tamaño permitido de {size}. Por favor envía los archivos mediante un enlace."],
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Choose a file to share as a link" : "Selecciona un archivo para compartir como enlace",
-    "Choose" : "Seleccionar",
     "Confirm" : "Confirmar",
     "Plain text" : "Texto simple",
     "Rich text" : "Texto enriquecido",
-    "No messages in this mailbox" : "No hay mensajes en esta bandeja",
+    "No messages in this folder" : "No hay mensajes en esta carpeta",
     "No messages" : "No hay mensajes",
-    "Draft: " : "Borrador:",
     "Unfavorite" : "Desmarcar como favorito",
     "Favorite" : "Favorito",
     "Read" : "Leer",
@@ -124,43 +127,44 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Remove" : "Eliminar",
     "email" : "correo electrónico",
+    "Today" : "Hoy",
     "Other" : "Otro",
     "Forward" : "Adelante",
     "Translate" : "Traducir",
+    "Unnamed" : "Sin nombre",
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
-    "Unnamed" : "Sin nombre",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Move" : "Mover",
-    "Quota" : "Cuota",
-    "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
+    "Folder name" : "Nombre de la carpeta",
+    "Saving" : "Guardando",
+    "Show all folders" : "Mostrar todas las carpetas",
+    "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
+    "Reply" : "Responder",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Está intentando enviar a muchos destinatarios en Para y/o Cc. Considera usar Cco para ocultar las direcciones de los destinatarios.",
     "Error sending your message" : "Error al enviar tu mensaje",
     "Retry" : "Reintentar",
-    "Uploading attachments …" : "Subiendo adjuntos…",
-    "Sending …" : "Enviando ...",
     "Warning sending your message" : "Alerta al enviar su mensaje",
     "Send anyway" : "Enviar de todas formas",
-    "Reply" : "Responder",
-    "No sent mailbox configured. Please pick one in the account settings." : "No hay configurada una bandeja de enviados. Por favor, elija una en la configuración de la cuenta.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Está intentando enviar a muchos destinatarios en Para y/o Cc. Considera usar Cco para ocultar las direcciones de los destinatarios.",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
+    "Clear" : "Limpiar",
     "Date" : "Fecha",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
-    "Clear" : "Limpiar",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
-    "Actions" : "Acciones",
+    "Recipient" : "Destinatario",
+    "matches" : "coincide",
     "Priority" : "Prioridad",
     "Reset" : "Restablecer",
     "Client ID" : "ID del cliente",
@@ -171,6 +175,9 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
+    "Group" : "Grupo",
+    "Shared" : "Compartido",
+    "Shares" : "Elementos compartido",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
@@ -193,6 +200,10 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "No messages in this mailbox" : "No hay mensajes en esta bandeja",
+    "Draft: " : "Borrador:",
+    "No sent mailbox configured. Please pick one in the account settings." : "No hay configurada una bandeja de enviados. Por favor, elija una en la configuración de la cuenta.",
+    "Actions" : "Acciones"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
