@@ -28,6 +28,7 @@ OC.L10N.register(
     "Signature" : "Firma",
     "Go back" : "Regresar",
     "Cancel" : "Cancelar",
+    "Accounts" : "Accounts",
     "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
@@ -44,6 +45,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
+    "Ok" : "Ok",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
@@ -66,6 +68,7 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Remove" : "Eliminar",
     "email" : "correo electrónico",
+    "Today" : "Hoy",
     "Other" : "Otro",
     "Forward" : "Adelante",
     "Translate" : "Traducir",
@@ -78,15 +81,16 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Move" : "Mover",
     "Remove account" : "Eliminar cuenta",
-    "Quota" : "Cuota",
+    "Folder name" : "Nombre de la carpeta",
     "Saving" : "Guardando",
+    "Show all folders" : "Mostrar todas las carpetas",
+    "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
     "Reply" : "Responder",
     "Retry" : "Reintentar",
-    "Sending …" : "Enviando ...",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
@@ -97,7 +101,8 @@ OC.L10N.register(
     "Select tags" : "Selecciona las etiquetas",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
-    "Actions" : "Acciones",
+    "Recipient" : "Destinatario",
+    "matches" : "coincide",
     "Priority" : "Prioridad",
     "Reset" : "Restablecer",
     "Client ID" : "ID del cliente",
@@ -108,6 +113,9 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
+    "Group" : "Grupo",
+    "Shared" : "Compartido",
+    "Shares" : "Elementos compartido",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
@@ -127,6 +135,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "Actions" : "Acciones"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
