@@ -299,6 +299,10 @@ OC.L10N.register(
     "Add internal email or domain" : "Agregar dirección de correo interna o dominio",
     "Itinerary for {type} is not supported yet" : "El itinerario para {type} aún no es soportado",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivado y/o eliminar este mensaje de la carpeta actual",
+    "Last hour" : "Última hora",
+    "Today" : "Hoy",
+    "Last week" : "Semana pasada",
+    "Last month" : "Mes pasado",
     "Loading messages …" : "Cargando mensajes...",
     "Choose target folder" : "Elegir carpeta destino",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
@@ -324,6 +328,7 @@ OC.L10N.register(
     "Move up" : "Mover arriba",
     "Move down" : "Mover abajo",
     "Show all folders" : "Mostrar todas las carpetas",
+    "Collapse folders" : "Compactar carpetas",
     "Loading …" : "Cargando …",
     "Delete folder" : "Eliminar carpeta",
     "Mark all as read" : "Marcar todos como leídos",
@@ -367,6 +372,10 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
+    "Group" : "Grupo",
+    "Shared" : "Compartido",
+    "Shares" : "Elementos compartido",
+    "Insert" : "Insertar",
     "Account connected" : "Cuenta conectada",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
