@@ -134,6 +134,7 @@ OC.L10N.register(
     "Mailto" : "Mailto",
     "Register as application for mail links" : "Erregistratu posta-estekentzako aplikazio bezala",
     "Register" : "Erregistratu",
+    "Shared with me" : "Nirekin partekatuta",
     "Privacy and security" : "Pribatutasuna eta segurtasuna",
     "Data collection consent" : "Datuak biltzeko baimena",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Baimena eman aplikazioari zure interakzioei buruzko datuak biltzeko. Datu horietan oinarrituta, aplikazioa zure hobespenetara egokituko da. Datuak lokalki bakarrik gordeko dira.",
@@ -160,6 +161,7 @@ OC.L10N.register(
     "Search" : "Bilatu",
     "Send" : "Bidali",
     "Refresh" : "Freskatu",
+    "Ok" : "Ados",
     "No certificate" : "Ziurtagiririk ez",
     "Certificate updated" : "Ziurtagiria eguneratu da",
     "Could not update certificate" : "Ezin izan da ziurtagiria eguneratu",
@@ -319,6 +321,10 @@ OC.L10N.register(
     "Add internal email or domain" : "Gehitu barneko helbide elektronikoa edo domeinua",
     "Itinerary for {type} is not supported yet" : "{type} motarentzako ibilbidea ez da onartzen oraindik",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Ez duzu mezu hau artxibo karpetara eramateko eta/edo mezu hau uneko karpetatik ezabatzeko baimenik",
+    "Last hour" : "Azken ordua",
+    "Today" : "Gaur",
+    "Last week" : "Joan den astean",
+    "Last month" : "Joan den hilabetean",
     "Loading messages …" : "Mezuak kargatzen ...",
     "Choose target folder" : "Aukeratu helburuko karpeta",
     "No more submailboxes in here" : "Azpipostontzi gehiagorik ez hemen",
@@ -386,7 +392,7 @@ OC.L10N.register(
     "Move down" : "Eraman behera",
     "Show all subscribed folders" : "Erakutsi harpidetutako karpeta guztiak",
     "Show all folders" : "Erakutsi karpeta guztiak",
-    "Collapse mailboxes" : "Tolestu postontziak",
+    "Collapse folders" : "Bildu karpetak",
     "_{total} message_::_{total} messages_" : ["Mezu {total}","{total} mezu"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} irakurri gabe {total} -etik","{unread} irakurri gabe {total} -etik"],
     "Loading …" : "Kargatzen...",
@@ -703,6 +709,10 @@ OC.L10N.register(
     "Private key (optional)" : "Gako pribatua (aukerakoa)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Gako pribatua beharrezkoa da  soilik ziurtagiri hau erabiliz sinatutako eta enkriptatutako mezu elektronikoak bidaltzeko asmoa baduzu .",
     "Submit" : "Bidali",
+    "Group" : "Taldea",
+    "Shared" : "Partekatuta",
+    "Shares" : "Partekatzeak",
+    "Insert" : "Txertatu",
     "Account connected" : "Kontua konektatuta",
     "You can close this window" : "Leiho hau itxi dezakezu",
     "Connect your mail account" : "Konektatu zure posta kontua",
@@ -755,6 +765,7 @@ OC.L10N.register(
     "Mailbox name" : "Postontziaren izena",
     "Show all subscribed mailboxes" : "Erakutsi harpidetutako postontzi guztiak",
     "Show all mailboxes" : "Erakutsi postontzi guztiak",
+    "Collapse mailboxes" : "Tolestu postontziak",
     "Clear mailbox" : "Garbitu postontzia",
     "The mailbox and all messages in it will be deleted." : "Postontzia eta bertan dauden mezu guztiak ezabatuko dira.",
     "Delete mailbox" : "Ezabatu postontzia",
