@@ -100,6 +100,7 @@ OC.L10N.register(
     "Accounts" : "حساب‌ها",
     "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
     "General" : "عمومی",
+    "Layout" : "چیدمان",
     "List" : "فهرست",
     "Sorting" : "مرتب سازی",
     "Newest" : "Newest",
@@ -107,6 +108,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
     "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
     "Register" : "ثبت‌نام",
+    "Shared with me" : "Shared with me",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
     "Trusted senders" : "Trusted senders",
     "Manage S/MIME certificates" : "Manage S/MIME certificates",
@@ -123,6 +125,7 @@ OC.L10N.register(
     "Search" : "جستجو",
     "Send" : "ارسال",
     "Refresh" : "تازه‌سازی",
+    "Ok" : "باشه",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
     "Could not update certificate" : "Could not update certificate",
@@ -173,6 +176,7 @@ OC.L10N.register(
     "Custom date and time" : "Custom date and time",
     "Enter a date" : "تاریخ را وارد کنید",
     "Choose" : "انتخاب کنید",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["The attachment exceed the allowed attachments size of {size}. Please share the file via link instead.","The attachments exceed the allowed attachments size of {size}. Please share the files via link instead."],
     "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
     "Choose a file to share as a link" : "Choose a file to share as a link",
     "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
@@ -182,7 +186,7 @@ OC.L10N.register(
     "Confirm" : "تائید",
     "Plain text" : "متن ساده",
     "Rich text" : "متن غنی",
-    "No messages in this mailbox" : "No messages in this mailbox",
+    "No messages in this folder" : "هیچ پیامی در این پوشه وجود ندارد",
     "No messages" : "No messages",
     "Blind copy recipients only" : "فقط گیرندگان کپی کور",
     "No subject" : "No subject",
@@ -194,12 +198,10 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Set reminder for this weekend",
     "Next week – {timeLocale}" : "Next week – {timeLocale}",
     "Set reminder for next week" : "Set reminder for next week",
-    "No trash mailbox configured" : "No trash mailbox configured",
     "Could not delete message" : "Could not delete message",
     "Could not archive message" : "Could not archive message",
     "Thread was snoozed" : "Thread was snoozed",
     "Could not snooze thread" : "Could not snooze thread",
-    "Draft: " : "پیش نویس:",
     "Encrypted message" : "Encrypted message",
     "This message is unread" : "This message is unread",
     "Unfavorite" : "ناخوشایند",
@@ -213,7 +215,9 @@ OC.L10N.register(
     "Snooze" : "Snooze",
     "Move thread" : "Move thread",
     "Archive thread" : "Archive thread",
+    "Archive message" : "Archive message",
     "Delete thread" : "Delete thread",
+    "Delete message" : "Delete message",
     "More actions" : "اقدامات بیشتر",
     "Back" : "بازگشت",
     "Set custom snooze" : "Set custom snooze",
@@ -262,12 +266,13 @@ OC.L10N.register(
     "Remove" : "حذف",
     "email" : "ایمیل",
     "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
-    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
-    "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
+    "Last hour" : "Last hour",
+    "Today" : "امروز.",
+    "Last week" : "هفته گذشته",
+    "Last month" : "ماه گذشته",
     "Loading messages …" : "Loading messages …",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
-    "Choose target mailbox" : "Choose target mailbox",
+    "Choose target folder" : "پوشهٔ هدف را انتخاب کنید",
     "No more submailboxes in here" : "No more submailboxes in here",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
     "Important info" : "Important info",
@@ -310,37 +315,29 @@ OC.L10N.register(
     "Moving" : "Moving",
     "Moving thread" : "Moving thread",
     "Moving message" : "Moving message",
-    "Loading …" : "بارگذاری …",
-    "Not supported by the server" : "Not supported by the server",
-    "{usage} of {limit} used" : "{usage} of {limit} used",
     "Remove account" : "حذف حساب کاربری",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider.",
     "Remove {email}" : "Remove {email}",
     "Provisioned account is disabled" : "Provisioned account is disabled",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
-    "Quota" : "سهم",
-    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
-    "Add mailbox" : "Add mailbox",
+    "Folder name" : "نام پوشه",
     "Saving" : "درحال ذخیره",
     "Move up" : "Move up",
     "Move down" : "حرکت به پایین",
-    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
-    "Show all mailboxes" : "Show all mailboxes",
-    "Collapse mailboxes" : "Collapse mailboxes",
+    "Show all folders" : "نمایش همه پوشه ها",
+    "Collapse folders" : "پوشه ها را جمع کنید",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
+    "Loading …" : "بارگذاری …",
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
-    "Clear mailbox" : "Clear mailbox",
-    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
-    "Delete mailbox" : "Delete mailbox",
-    "Delete mailbox {name}" : "Delete mailbox {name}",
+    "Delete folder" : "حذف پوشه",
     "An error occurred, unable to rename the mailbox." : "An error occurred, unable to rename the mailbox.",
     "Mark all as read" : "علامت همه به عنوان خوانده‌شده",
-    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
-    "Add submailbox" : "Add submailbox",
+    "Mark all messages of this folder as read" : "تمام پیام های این پوشه را به عنوان خوانده شده علامت گذاری کنید",
+    "Add subfolder" : "زیر پوشه را اضافه کنید",
     "Rename" : "تغییرنام",
-    "Move mailbox" : "Move mailbox",
+    "Move folder" : "Move folder",
     "Clear cache" : "پاک‌سازی انباره",
     "Clear locally cached data, in case there are issues with synchronization." : "Clear locally cached data, in case there are issues with synchronization.",
     "Subscribed" : "Subscribed",
@@ -353,15 +350,12 @@ OC.L10N.register(
     "Message saved" : "Message saved",
     "Failed to save message" : "Failed to save message",
     "Failed to save draft" : "Failed to save draft",
-    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses.",
     "Message discarded" : "Message discarded",
     "Could not discard message" : "Could not discard message",
     "Minimize composer" : "Minimize composer",
     "Error sending your message" : "خطایی در ارسال پیام شما",
     "Retry" : "تلاش دوباره",
-    "Uploading attachments …" : "درحال بارگذاری پیوستها …",
-    "Sending …" : "در حال ارسال ...",
     "Warning sending your message" : "Warning sending your message",
     "Send anyway" : "Send anyway",
     "Autoresponder off" : "Autoresponder off",
@@ -387,7 +381,6 @@ OC.L10N.register(
     "Show less" : "Show less",
     "Show more" : "Show more",
     "Clear" : "پاک کردن",
-    "Search in mailbox" : "Search in mailbox",
     "Close" : "بسته",
     "Search parameters" : "Search parameters",
     "Body" : "متن",
@@ -414,6 +407,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Your signature is larger than 2 MB. This may affect the performance of your editor.",
     "Save signature" : "ذخیره امضا",
     "Place signature above quoted text" : "Place signature above quoted text",
+    "Message source" : "Message source",
     "An error occurred, unable to rename the tag." : "An error occurred, unable to rename the tag.",
     "Saving new tag name …" : "Saving new tag name …",
     "Set tag" : "Set tag",
@@ -431,7 +425,7 @@ OC.L10N.register(
     "Could not load your message thread" : "Could not load your message thread",
     "The thread doesn't exist or has been deleted" : "The thread doesn't exist or has been deleted",
     "Loading thread" : "Loading thread",
-    "Not found" : "پیدا نشد",
+    "Not found" : "پیدا نشد.",
     "Encrypted & verified " : "Encrypted & verified ",
     "Signature verified" : "Signature verified",
     "Signature unverified " : "Signature unverified ",
@@ -447,9 +441,6 @@ OC.L10N.register(
     "Mark as favorite" : "Mark as favorite",
     "Mark as unread" : "علامت به عنوان خوانده‌نشده",
     "Mark as read" : "علامت به عنوان خوانده‌شده",
-    "Archive message" : "Archive message",
-    "Delete message" : "Delete message",
-    "Message source" : "Message source",
     "Unsubscribe via link" : "Unsubscribe via link",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Unsubscribing will stop all messages from the mailing list {sender}",
     "Send unsubscribe email" : "Send unsubscribe email",
@@ -482,9 +473,9 @@ OC.L10N.register(
     "Train" : "رشته",
     "Flag" : "Flag",
     "Delete filter" : "Delete filter",
-    "Operator" : "Operator",
-    "Actions" : "کنش‌ها",
-    "New action" : "New action",
+    "Operator" : "عملگر",
+    "contains" : "contains",
+    "matches" : "مطابق است",
     "Priority" : "اولویت",
     "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
     "Error saving config" : "Error saving config",
@@ -509,8 +500,6 @@ OC.L10N.register(
     "Gmail integration" : "Gmail integration",
     "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI.",
     "Microsoft integration" : "Microsoft integration",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI.",
     "Successfully set up anti spam email addresses" : "Successfully set up anti spam email addresses",
     "Error saving anti spam email addresses" : "Error saving anti spam email addresses",
     "Successfully deleted anti spam reporting email" : "Successfully deleted anti spam reporting email",
@@ -521,7 +510,7 @@ OC.L10N.register(
     "The original message will be attached as a \"message/rfc822\" attachment." : "The original message will be attached as a \"message/rfc822\" attachment.",
     "\"Mark as Spam\" Email Address" : "\"Mark as Spam\" Email Address",
     "\"Mark Not Junk\" Email Address" : "\"Mark Not Junk\" Email Address",
-    "Reset" : "بازنشاندن",
+    "Reset" : "بازنشانی",
     "Google integration configured" : "Google integration configured",
     "Could not configure Google integration" : "Could not configure Google integration",
     "Google integration unlinked" : "Google integration unlinked",
@@ -543,7 +532,7 @@ OC.L10N.register(
     "Provisioning domain" : "Provisioning domain",
     "Email address template" : "Email address template",
     "IMAP" : "IMAP",
-    "User" : "User",
+    "User" : "کاربر",
     "Host" : "میزبان",
     "Port" : "درگاه",
     "SMTP" : "SMTP",
@@ -566,7 +555,7 @@ OC.L10N.register(
     "S/MIME certificates" : "S/MIME certificates",
     "Certificate name" : "Certificate name",
     "E-mail address" : "آدرس ایمیل",
-    "Valid until" : "متعبر تا",
+    "Valid until" : "معتبر تا",
     "Delete certificate" : "Delete certificate",
     "No certificate imported yet" : "No certificate imported yet",
     "Import certificate" : "Import certificate",
@@ -577,7 +566,11 @@ OC.L10N.register(
     "Private key (optional)" : "Private key (optional)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "The private key is only required if you intend to send signed and encrypted emails using this certificate.",
     "Submit" : "ارسال",
-    "Account connected" : "Account connected",
+    "Group" : "گروه",
+    "Shared" : "به اشتراک گذاشته شده ",
+    "Shares" : "اشتراک گذاری ها",
+    "Insert" : "Insert",
+    "Account connected" : "حساب کاربری متصل شد",
     "You can close this window" : "You can close this window",
     "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
     "To add a mail account, please contact your administrator." : "To add a mail account, please contact your administrator.",
@@ -614,6 +607,28 @@ OC.L10N.register(
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "ادامه دهید%s",
-    "This event is in the past." : "This event is in the past."
+    "No messages in this mailbox" : "No messages in this mailbox",
+    "No trash mailbox configured" : "No trash mailbox configured",
+    "Draft: " : "پیش نویس:",
+    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
+    "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
+    "Choose target mailbox" : "Choose target mailbox",
+    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
+    "Add mailbox" : "Add mailbox",
+    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
+    "Show all mailboxes" : "Show all mailboxes",
+    "Collapse mailboxes" : "Collapse mailboxes",
+    "Clear mailbox" : "Clear mailbox",
+    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
+    "Delete mailbox" : "Delete mailbox",
+    "Delete mailbox {name}" : "Delete mailbox {name}",
+    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
+    "Add submailbox" : "Add submailbox",
+    "Move mailbox" : "Move mailbox",
+    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
+    "Search in mailbox" : "Search in mailbox",
+    "Actions" : "کنش‌ها",
+    "New action" : "New action"
 },
 "nplurals=2; plural=(n > 1);");
