@@ -91,6 +91,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
     "Register" : "Rekisteröidy",
+    "Shared with me" : "Jaettu kanssasi",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
     "Trusted senders" : "Luotetut lähettäjät",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
@@ -108,6 +109,7 @@ OC.L10N.register(
     "Search" : "Etsi",
     "Send" : "Lähetä",
     "Refresh" : "Päivitä",
+    "Ok" : "Ok",
     "No certificate" : "Ei varmennetta",
     "Certificate updated" : "Varmenne päivitetty",
     "Could not update certificate" : "Varmennetta ei voitu päivittää",
@@ -235,6 +237,10 @@ OC.L10N.register(
     "domain" : "domaini",
     "Remove" : "Poista",
     "email" : "sähköposti",
+    "Last hour" : "Viime tunti",
+    "Today" : "Tänään",
+    "Last week" : "Viime viikko",
+    "Last month" : "Viime kuukausi",
     "Loading messages …" : "Ladataan viestejä …",
     "Choose target folder" : "Valitse kohdekansio",
     "Important info" : "Tärkeää tietoa",
@@ -283,7 +289,7 @@ OC.L10N.register(
     "Move down" : "Siirrä alas",
     "Show all subscribed folders" : "Näytä kaikki tilatut kansiot",
     "Show all folders" : "Näytä kaikki kansiot",
-    "Collapse mailboxes" : "Supista postilaatikot",
+    "Collapse folders" : "Supista kansiot",
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
     "Loading …" : "Ladataan…",
@@ -458,6 +464,10 @@ OC.L10N.register(
     "Certificate" : "Varmenne",
     "Private key (optional)" : "Yksityinen avain (valinnainen)",
     "Submit" : "Lähetä",
+    "Group" : "Ryhmä",
+    "Shared" : "Jaettu",
+    "Shares" : "Jaot",
+    "Insert" : "Lisää",
     "Account connected" : "Tili yhdistetty",
     "You can close this window" : "Voit sulkea tämän ikkunan",
     "Connect your mail account" : "Yhdistä sähköpostitilisi",
@@ -501,6 +511,7 @@ OC.L10N.register(
     "Add mailbox" : "Lisää postilaatikko",
     "Show all subscribed mailboxes" : "Näytä kaikki tilatut postilaatikot",
     "Show all mailboxes" : "Näytä kaikki postilaatikot",
+    "Collapse mailboxes" : "Supista postilaatikot",
     "Clear mailbox" : "Tyhjennä postilaatikko",
     "The mailbox and all messages in it will be deleted." : "Tämä postilaatikko ja kaikki sen viestit poistetaan.",
     "Delete mailbox" : "Poista postilaatikko",
