@@ -75,6 +75,7 @@ OC.L10N.register(
     "Search" : "חיפוש",
     "Send" : "שליחה",
     "Refresh" : "רענון",
+    "Ok" : "אישור",
     "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
     "From" : "מאת",
     "Select account" : "בחר חשבון",
@@ -133,6 +134,11 @@ OC.L10N.register(
     "Remove" : "הסרה",
     "email" : "דוא״ל",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
+    "Last hour" : "השעה החולפת",
+    "Today" : "היום",
+    "Yesterday" : "מחר",
+    "Last week" : "שבוע שעבר",
+    "Last month" : "חודש שעבר",
     "Choose target folder" : "נא לבחור תיקיית יעד",
     "Important info" : "מידע חשוב",
     "Other" : "אחר",
@@ -160,7 +166,7 @@ OC.L10N.register(
     "Move down" : "להוריד למטה",
     "Show all subscribed folders" : "להציג את כל התיקיות שבמינוי",
     "Show all folders" : "הצגת כל התיקיות",
-    "Collapse mailboxes" : "צמצום תיבות דוא״ל",
+    "Collapse folders" : "קיווץ תיקיות",
     "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
     "Loading …" : "בטעינה",
@@ -236,6 +242,10 @@ OC.L10N.register(
     "Valid until" : "בתוקף עד",
     "Certificate" : "אישור",
     "Submit" : "שליחה",
+    "Guest" : "אורח",
+    "Group" : "קבוצה",
+    "Shared" : "משותף",
+    "Shares" : "שיתופים",
     "Account connected" : "חשבון מחובר",
     "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
     "All" : "הכול",
@@ -271,6 +281,7 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
     "Add mailbox" : "הוספת תיבת דוא״ל",
     "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
+    "Collapse mailboxes" : "צמצום תיבות דוא״ל",
     "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
     "Delete mailbox" : "מחיקת תיבת דוא״ל",
     "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
