@@ -68,6 +68,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
     "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
     "Register" : "Registriraj se",
+    "Shared with me" : "Dijeljeno sa mnom",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
     "Trusted senders" : "Pouzdani pošiljatelji",
     "About" : "Informacije",
@@ -82,6 +83,7 @@ OC.L10N.register(
     "Search" : "Traži",
     "Send" : "Pošalji",
     "Refresh" : "Osvježi",
+    "Ok" : "U redu",
     "Message {id} could not be found" : "Poruka {id} nije pronađena",
     "From" : "Od",
     "Select account" : "Odaberi račun",
@@ -153,6 +155,9 @@ OC.L10N.register(
     "Remove" : "Ukloni",
     "email" : "e-pošta",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
+    "Last hour" : "Posljednji sat",
+    "Last week" : "Prošli tjedan",
+    "Last month" : "Prošli mjesec",
     "Choose target folder" : "Odaberi ciljnu mapu",
     "No more submailboxes in here" : "Ovdje više nema podsandučića",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
@@ -200,7 +205,7 @@ OC.L10N.register(
     "Move down" : "Premjesti dolje",
     "Show all subscribed folders" : "Prikaži sve pretplaćene mape",
     "Show all folders" : "Prikaži sve mape",
-    "Collapse mailboxes" : "Sakrij sandučiće",
+    "Collapse folders" : "Sakrij mape",
     "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
     "Loading …" : "Učitavanje…",
@@ -346,6 +351,8 @@ OC.L10N.register(
     "Valid until" : "Vrijedi do",
     "Certificate" : "Vjerodajnica",
     "Submit" : "Šalji",
+    "Shared" : "Dijeljeno",
+    "Shares" : "Dijeljeni resursi",
     "Account connected" : "Račun povezan",
     "Connect your mail account" : "Poveži svoj račun e-pošte",
     "All" : "Sve",
@@ -384,6 +391,7 @@ OC.L10N.register(
     "Add mailbox" : "Dodaj sandučić",
     "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
     "Show all mailboxes" : "Prikaži sve sandučiće",
+    "Collapse mailboxes" : "Sakrij sandučiće",
     "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
     "Delete mailbox" : "Izbriši sandučić",
     "Delete mailbox {name}" : "Izbriši sandučić {name}",
