@@ -34,6 +34,7 @@ OC.L10N.register(
     "Comment" : "Commentario",
     "Accept" : "Acceptar",
     "Decline" : "Refusar",
+    "Today" : "Hodie",
     "Other" : "Altere",
     "Unnamed" : "Non nominate",
     "Choose a folder to store the attachment in" : "Selectiona un dossier pro salveguardar le attachamento",
@@ -42,6 +43,7 @@ OC.L10N.register(
     "Folder name" : "Nomine de dossier",
     "Saving" : "Salveguardante",
     "Show all folders" : "Monstrar tote dossiers",
+    "Collapse folders" : "Plicar dossiers",
     "Rename" : "Renominar",
     "Reply" : "Responder",
     "Add" : "Adder",
@@ -56,6 +58,9 @@ OC.L10N.register(
     "Host" : "Hospite",
     "Port" : "Porto",
     "Valid until" : "Valide usque",
+    "Group" : "Gruppo",
+    "Shared" : "Compartite",
+    "Shares" : "Compartimentos",
     "All" : "Tote",
     "Favorites" : "Favoritos",
     "All inboxes" : "Tote cassas de entrata",
