@@ -26,6 +26,7 @@ OC.L10N.register(
     "General" : "Umum",
     "List" : "Daftar",
     "Register" : "Daftar",
+    "Shared with me" : "Dibagikan dengan saya",
     "About" : "Tentang",
     "Keyboard shortcuts" : "Pintasan keyboard",
     "Archive" : "Arsip",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "Search" : "Cari",
     "Send" : "Kirim",
     "Refresh" : "Segarkan",
+    "Ok" : "Oke",
     "Subject" : "Subjek",
     "Upload attachment" : "Unggah lampiran",
     "Choose" : "Pilih",
@@ -52,6 +54,9 @@ OC.L10N.register(
     "Decline" : "Tolak",
     "Remove" : "Buang",
     "email" : "email",
+    "Today" : "Hari ini",
+    "Last week" : "Minggu lalu",
+    "Last month" : "Bulan lalu",
     "Choose target folder" : "Pilih folder target",
     "Other" : "Lainnya",
     "Forward" : "Teruskan",
@@ -100,6 +105,10 @@ OC.L10N.register(
     "Port" : "Port",
     "Valid until" : "Berlaku sampai",
     "Certificate" : "Sertifikat",
+    "Guest" : "Tamu",
+    "Group" : "Grup",
+    "Shared" : "Dibagikan",
+    "Shares" : "Dibagikan",
     "Account connected" : "Akun terhubung",
     "Connect your mail account" : "Hubungkan akun email Anda",
     "All" : "Semua",
