@@ -112,6 +112,7 @@ OC.L10N.register(
     "Mailto" : "Mailto",
     "Register as application for mail links" : "Register as application for mail links",
     "Register" : "Register",
+    "Shared with me" : "Shared with me",
     "Data collection consent" : "Data collection consent",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
     "Trusted senders" : "Trusted senders",
@@ -131,6 +132,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "Send",
     "Refresh" : "Refresh",
+    "Ok" : "Ok",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
     "Could not update certificate" : "Could not update certificate",
@@ -280,6 +282,10 @@ OC.L10N.register(
     "email" : "email",
     "Itinerary for {type} is not supported yet" : "Itinerary for {type} is not supported yet",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
+    "Today" : "დღეს",
+    "Yesterday" : "გუშინ",
+    "Last week" : "Last week",
+    "Last month" : "Last month",
     "Loading messages …" : "Loading messages …",
     "Choose target folder" : "Choose target folder",
     "No more submailboxes in here" : "No more submailboxes in here",
@@ -592,6 +598,10 @@ OC.L10N.register(
     "Private key (optional)" : "Private key (optional)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "The private key is only required if you intend to send signed and encrypted emails using this certificate.",
     "Submit" : "Submit",
+    "Guest" : "Guest",
+    "Group" : "Group",
+    "Shared" : "Shared",
+    "Shares" : "Shares",
     "Account connected" : "Account connected",
     "You can close this window" : "You can close this window",
     "Connect your mail account" : "Connect your mail account",
