@@ -6,6 +6,10 @@ OC.L10N.register(
     "Personal" : "პირადი",
     "Later" : "მოგვიანებით",
     "Mail" : "ფოსტა",
+    "Connecting" : "მყარდება კავშირი",
+    "Save" : "შენახვა",
+    "Connect" : "დაკავშირება",
+    "Password required" : "საჭიროა პაროლი",
     "Name" : "სახელი",
     "Mail address" : "ფოსტის მისამართი",
     "Password" : "პაროლი",
@@ -20,10 +24,6 @@ OC.L10N.register(
     "SMTP Port" : "SMTP პორტი",
     "SMTP User" : "SMTP მომხმარებელი",
     "SMTP Password" : "SMTP პაროლი",
-    "Connecting" : "მყარდება კავშირი",
-    "Save" : "შენახვა",
-    "Connect" : "დაკავშირება",
-    "Password required" : "საჭიროა პაროლი",
     "Aliases" : "სხვანაირი სახელი",
     "Signature" : "ხელმოწერა",
     "Go back" : "უკან დაბრუნება",
@@ -33,6 +33,7 @@ OC.L10N.register(
     "General" : "ზოგადი",
     "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
     "Register" : "რეგისტრაცია",
+    "About" : "ჩვენს შესახებ",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Compose new message" : "ახალი წერილის შედგენა",
     "Newer message" : "უფრო ახალი წერილი",
@@ -44,12 +45,13 @@ OC.L10N.register(
     "Search" : "ძიება",
     "Send" : "გაგზავნა",
     "Refresh" : "განახლება",
+    "Ok" : "კარგი",
     "Select account" : "აირჩიეთ ანგარიში",
     "Subject" : "სათაური",
     "Upload attachment" : "დანართის ატვირთვა",
     "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
-    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
     "Choose" : "აირჩიეთ",
+    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
     "Confirm" : "დადასტურება",
     "Unfavorite" : "რჩეულებიდან ამოშლა",
     "Favorite" : "რჩეული",
@@ -66,40 +68,44 @@ OC.L10N.register(
     "Decline" : "ურაყოფა",
     "Remove" : "წაშლა",
     "email" : "ელ-ფოსტა",
+    "Today" : "დღეს",
     "Other" : "სხვა",
     "Forward" : "წინ",
     "Translate" : "გადათარგმნეთ",
+    "Unnamed" : "უსახელო",
     "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
     "Import into calendar" : "იმპორტი კალენდარში",
     "Download attachment" : "დანართის გადმოწერა",
     "Save to Files" : "შენახვა ფაილებში",
-    "Unnamed" : "უსახელო",
     "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
     "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
     "Move" : "გადატანა",
-    "Quota" : "კვოტა",
-    "Saving" : "მიმდინარეობს შენახვა",
     "Remove account" : "ანგარიშის გაუქმება",
+    "Folder name" : "დირექტორიის სახელი",
+    "Saving" : "მიმდინარეობს შენახვა",
+    "Show all folders" : "ყველა დირექტორიის ჩვენება",
+    "Collapse folders" : "დირექტორიების კოლაფსი",
+    "Delete folder" : "ფოლდერის წაშლა",
     "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
     "Rename" : "სახელის შეცვლა",
     "Clear cache" : "კეშის გასუფთავება",
     "New message" : "ახალი წერილი",
-    "Retry" : "ვცადოთ ახლიდან",
-    "Sending …" : "იგზავნება …",
     "Reply" : "პასუხი",
+    "Retry" : "ვცადოთ ახლიდან",
     "Message" : "წერილი",
     "Copy to clipboard" : "კოპირება ბუფერში",
     "Add" : "დამატება",
+    "Clear" : "გასუფთავება",
     "Close" : "დახურვა",
     "Date" : "თარიღი",
     "Tags" : "ტეგები",
     "Select tags" : "აირჩიეთ ტეგები",
-    "Clear" : "გასუფთავება",
     "Custom" : "ინდივიდუალური",
     "Add tag" : "ტეგის დამატება",
     "Mark as unread" : "წაუკითხავად მონიშვნა",
     "Mark as read" : "წაკითხულად მონიშვნა",
-    "Actions" : "მოქმედებები",
+    "Recipient" : "მიმღები",
+    "matches" : "ემთხვევა",
     "Priority" : "პრიორიტეტი",
     "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
     "Client ID" : "კლიენტის ID",
@@ -110,6 +116,7 @@ OC.L10N.register(
     "Valid until" : "ვარგისია",
     "Certificate" : "სერტიფიკატი",
     "Submit" : "გაგზავნა",
+    "Shared" : "გაზიარებული",
     "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
     "All" : "ყველა",
     "Drafts" : "მონახაზები",
@@ -133,6 +140,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
     "Redirect" : "გადამისამართება",
     "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
-    "Continue to %s" : "%s-ისკენ გაგრძელება"
+    "Continue to %s" : "%s-ისკენ გაგრძელება",
+    "Actions" : "მოქმედებები"
 },
 "nplurals=2; plural=(n!=1);");
