@@ -24,6 +24,7 @@ OC.L10N.register(
     "Select" : "Fren",
     "Comment" : "Commentaire",
     "Remove" : "Kkes",
+    "Today" : "Ass-a",
     "Other" : "Wayeḍ",
     "Forward" : "Avancer",
     "Translate" : "Suqel",
@@ -41,6 +42,8 @@ OC.L10N.register(
     "Mark as unread" : "Creḍ ur yettwaɣra ara",
     "Mark as read" : "Creḍ yettwaɣra",
     "User" : "Aseqdac",
+    "Guest" : "Inebgi",
+    "Group" : "Agraw",
     "All" : "Akk",
     "Favorites" : "Imenyafen",
     "Inbox" : "Tanaka",
