@@ -107,6 +107,7 @@ OC.L10N.register(
     "Search" : "Ieškoti",
     "Send" : "Siųsti",
     "Refresh" : "Įkelti iš naujo",
+    "Ok" : "Gerai",
     "Certificate updated" : "Liudijimas atnaujintas",
     "Could not update certificate" : "Nepavyko atnaujinti liudijimo",
     "{commonName} - Valid until {expiryDate}" : "{commonName} – Galioja iki {expiryDate}",
@@ -154,7 +155,7 @@ OC.L10N.register(
     "An error occurred, unable to delete the tag." : "Įvyko klaida, nepavyko ištrinti žymos.",
     "Plain text" : "Grynasis tekstas",
     "Rich text" : "Raiškusis tekstas",
-    "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
+    "No messages in this folder" : "Šiame aplanke laiškų nėra",
     "No messages" : "Nėra laiškų",
     "No subject" : "Be temos",
     "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
@@ -167,7 +168,6 @@ OC.L10N.register(
     "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
     "Could not delete message" : "Nepavyko ištrinti laiško",
     "Could not archive message" : "Nepavyko archyvuoti laiško",
-    "Draft: " : "Juodraštis: ",
     "Encrypted message" : "Šifruotas laiškas",
     "This message is unread" : "Šis laiškas yra neskaitytas",
     "Unfavorite" : "Nebežymėti kaip mėgstamą",
@@ -209,9 +209,12 @@ OC.L10N.register(
     "Remove" : "Šalinti",
     "email" : "elektroninis paštas",
     "Add internal address" : "Pridėti vidinį adresą",
-    "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
+    "Last hour" : "Paskutinė valanda",
+    "Today" : "Šiandien",
+    "Last week" : "Praeitą savaitę",
+    "Last month" : "Praeitą mėnesį",
     "Loading messages …" : "Įkeliami laiškai…",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
+    "Choose target folder" : "Pasirinkite paskirties aplanką",
     "Important info" : "Svarbi informacija",
     "Other" : "Kita",
     "The sender of this message has asked to be notified when you read this message." : "Šio laiško siuntėjas paprašė, kad jam būtų pranešta, kai perskaitysite šį laišką.",
@@ -243,35 +246,32 @@ OC.L10N.register(
     "Always show images from {domain}" : "Visada rodyti paveikslus iš {domain}",
     "Quoted text" : "Cituojamas tekstas",
     "Move" : "Perkelti",
-    "Loading …" : "Įkeliama…",
-    "Not supported by the server" : "Serveris nepalaiko",
-    "{usage} of {limit} used" : "Panaudota {usage} iš {limit}",
     "Remove account" : "Šalinti paskyrą",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Paskyra {email} ir podėlyje esantys el. pašto duomenys bus pašalinti iš Nextcloud, tačiau nebus pašalinti iš jūsų el. pašto teikėjo puslapio.",
     "Remove {email}" : "Šalinti {email}",
-    "Quota" : "Leidžiamas duomenų kiekis",
-    "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
-    "Add mailbox" : "Pridėti pašto dėžutę",
-    "Mailbox name" : "Pašto dėžutės pavadinimas",
+    "Show only subscribed folders" : "Rodyti tik prenumeruotus aplankus",
+    "Add folder" : "Pridėti aplanką",
+    "Folder name" : "Aplanko pavadinimas",
     "Saving" : "Įrašoma",
     "Move up" : "Pakelti",
     "Move down" : "Nuleisti",
-    "Show all subscribed mailboxes" : "Rodyti visas prenumeruotas pašto dėžutes",
-    "Show all mailboxes" : "Rodyti visas pašto dėžutes",
-    "Collapse mailboxes" : "Suskleisti pašto dėžutes",
+    "Show all subscribed folders" : "Rodyti visus prenumeruotus aplankus",
+    "Show all folders" : "Rodyti visus aplankus",
+    "Collapse folders" : "Suskleisti aplankus",
     "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
+    "Loading …" : "Įkeliama…",
     "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
     "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
-    "Clear mailbox" : "Išvalyti pašto dėžutę",
-    "The mailbox and all messages in it will be deleted." : "Pašto dėžutė ir visi joje esantys laiškai bus ištrinti.",
-    "Delete mailbox" : "Ištrinti pašto dėžutę",
-    "Delete mailbox {name}" : "Ištrinti pašto dėžutę {name}",
+    "The folder and all messages in it will be deleted." : "Aplankas ir visi jame esantys laiškai bus ištrinti.",
+    "Delete folder" : "Ištrinti aplanką",
+    "Delete folder {name}" : "Ištrinti aplanką {name}",
     "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
     "Mark all as read" : "Žymėti visus kaip skaitytus",
-    "Mark all messages of this mailbox as read" : "Žymėti visus laiškus šioje pašto dėžutėje kaip skaitytus",
+    "Mark all messages of this folder as read" : "Žymėti visus laiškus šiame aplanke kaip skaitytus",
+    "Add subfolder" : "Pridėti poaplankį",
     "Rename" : "Pervadinti",
-    "Move mailbox" : "Perkelti pašto dėžutę",
+    "Move folder" : "Perkelti aplanką",
     "Clear cache" : "Išvalyti podėlį",
     "Subscribed" : "Prenumeruotas",
     "Sync in background" : "Sinchronizuoti fone",
@@ -308,7 +308,6 @@ OC.L10N.register(
     "Show less" : "Rodyti mažiau",
     "Show more" : "Rodyti daugiau",
     "Clear" : "Išvalyti",
-    "Search in mailbox" : "Ieškoti pašto dėžutėje",
     "Close" : "Užverti",
     "Date" : "Data",
     "Tags" : "Žymos",
@@ -318,6 +317,7 @@ OC.L10N.register(
     "Signature …" : "Parašas…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Jūsų parašas yra didesnis nei 2 MB. Tai gali paveikti redaktoriaus našumą.",
     "Save signature" : "Įrašyti parašą",
+    "Message source" : "Pirminis laiško kodas",
     "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymos.",
     "Delete tag" : "Ištrinti žymą",
     "Tag name is a hidden system tag" : "Žymos pavadinimas yra paslėpta sistemos žyma",
@@ -337,7 +337,6 @@ OC.L10N.register(
     "Reply to sender only" : "Atsakyti tik siuntėjui",
     "Mark as unread" : "Žymėti kaip neskaitytą",
     "Mark as read" : "Žymėti kaip skaitytą",
-    "Message source" : "Pirminis laiško kodas",
     "Unsubscribe via link" : "Atsisakyti prenumeratos per nuorodą",
     "Unsubscribe via email" : "Atsisakyti prenumeratos per el. paštą",
     "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
@@ -410,6 +409,8 @@ OC.L10N.register(
     "PEM Certificate" : "PEM liudijimas",
     "Certificate" : "Liudijimas",
     "Submit" : "Pateikti",
+    "Shared" : "Bendrinama",
+    "Shares" : "Viešiniai",
     "Account connected" : "Paskyra prijungta",
     "You can close this window" : "Galite užverti šį langą",
     "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
@@ -443,6 +444,23 @@ OC.L10N.register(
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
     "Continue to %s" : "Tęsti į %s",
+    "No messages in this mailbox" : "Šioje pašto dėžutėje laiškų nėra",
+    "Draft: " : "Juodraštis: ",
+    "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
+    "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
+    "Add mailbox" : "Pridėti pašto dėžutę",
+    "Mailbox name" : "Pašto dėžutės pavadinimas",
+    "Show all subscribed mailboxes" : "Rodyti visas prenumeruotas pašto dėžutes",
+    "Show all mailboxes" : "Rodyti visas pašto dėžutes",
+    "Collapse mailboxes" : "Suskleisti pašto dėžutes",
+    "Clear mailbox" : "Išvalyti pašto dėžutę",
+    "The mailbox and all messages in it will be deleted." : "Pašto dėžutė ir visi joje esantys laiškai bus ištrinti.",
+    "Delete mailbox" : "Ištrinti pašto dėžutę",
+    "Delete mailbox {name}" : "Ištrinti pašto dėžutę {name}",
+    "Mark all messages of this mailbox as read" : "Žymėti visus laiškus šioje pašto dėžutėje kaip skaitytus",
+    "Move mailbox" : "Perkelti pašto dėžutę",
+    "Search in mailbox" : "Ieškoti pašto dėžutėje",
     "Actions" : "Veiksmai",
     "New action" : "Naujas veiksmas"
 },
