@@ -55,6 +55,7 @@ OC.L10N.register(
     "Search" : "Meklēt",
     "Send" : "Sūtīt",
     "Refresh" : "Atsvaidzināt",
+    "Ok" : "Labi",
     "From" : "No",
     "Select account" : "Izvēlieties kontu",
     "To" : "Līdz",
@@ -85,6 +86,7 @@ OC.L10N.register(
     "More options" : "Vairāk iespēju",
     "Remove" : "Noņemt",
     "email" : "e-pasts",
+    "Today" : "Šodien",
     "Other" : "Cits",
     "The sender of this message has asked to be notified when you read this message." : "Šī ziņojuma sūtītājs ir norādījis, ka vēlas saņemt paziņojumu par šī ziņojuma izlasīšanu.",
     "Forward" : "Turpināt",
@@ -92,7 +94,7 @@ OC.L10N.register(
     "View source" : "Skatīt avotu",
     "Unnamed" : "Nenosaukts",
     "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
-    "Import into calendar" : "Importēt kalendārā",
+    "Import into calendar" : "Ievietot kalendārā",
     "Download attachment" : "Lejupielādēt pielikumu",
     "Save to Files" : "Saglabāt uz Datnes",
     "Save all to Files" : "Saglabāt visu uz Datnes",
@@ -137,7 +139,7 @@ OC.L10N.register(
     "Operator" : "Operators",
     "contains" : "saturs",
     "matches" : "atbilst",
-    "Priority" : "Prioritāte",
+    "Priority" : "Svarīgums",
     "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
     "Reset" : "Atiestatīt",
     "Client ID" : "Klienta ID",
@@ -147,6 +149,9 @@ OC.L10N.register(
     "Valid until" : "Derīgs līdz",
     "Certificate" : "Sertifikāts",
     "Submit" : "Iesniegt",
+    "Group" : "Grupa",
+    "Shared" : "Koplietots",
+    "Shares" : "Koplietots",
     "Account connected" : "Konts sasaistīts",
     "You can close this window" : "Šo logu var aizvērt.",
     "Connect your mail account" : "Pievienot savu e-pasta kontu",
