@@ -15,6 +15,9 @@ OC.L10N.register(
     "You are reaching your mailbox quota limit for {account_email}" : "Го достигнувате лимитот на квотата на вашето поштенско сандаче за {account_email}",
     "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Во моментов користите {percentage} од складиштето на вашето поштенско сандаче. Направете простор со бришење на непотребните е-пораки.",
     "Mails" : "Е-пошта пораки",
+    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "Испраќачот: %1$s не е во адресарот, но името на испраќачот: %2$s е во адресарот со адресата: %3$s",
+    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "Испраќачот: %1$s не е во адресарот, но името на испраќачот: %2$s е во адресарот со адресата: %3$s",
+    "Sent date is in the future" : "Датумот на испраќање е во иднина",
     "💌 A mail app for Nextcloud" : "💌 Апликација за електронска пошта за Nextcloud",
     "Your session has expired. The page will be reloaded." : "Сесијата истече. Страната ќе биде повторно вчитана.",
     "Drafts are saved in:" : "Шаблоните се зачувани во:",
@@ -82,17 +85,39 @@ OC.L10N.register(
     "Add alias" : "Додади псевдоним",
     "Create alias" : "Креирај алијас",
     "Cancel" : "Откажи",
+    "Search in the body of messages in priority Inbox" : "Барај во пораката во приоритетното сандаче",
+    "Activate" : "Активирај",
+    "Put my text to the bottom of a reply instead of on top of it." : "Стави го мојот текст на дното од одговорот наместо врз него.",
+    "Mark as important" : "Ознали како важна",
+    "Use internal addresses" : "Користи внатрешни адреси",
     "Could not update preference" : "Неможе да се ажурираат параметрите",
     "Mail settings" : "Параметри за е-пошта",
     "Accounts" : "Сметки",
     "Add mail account" : "Додади е-пошта сметка",
+    "Settings for:" : "Параметри за:",
     "General" : "Општо",
+    "Layout" : "Распоред",
+    "List" : "Листа",
+    "Vertical split" : "Вертикална поделба",
+    "Horizontal split" : "Хоризонтална поделба",
+    "Sorting" : "Сортирање",
+    "Newest" : "Најнови",
+    "Oldest" : "Најстари",
+    "Search in body" : "Барај по пораката",
+    "Reply text position" : "Позиција на одговорот",
+    "Gravatar settings" : "Параметри за Gravatar ",
     "Use Gravatar and favicon avatars" : "Користете Граватар и Фавикон аватари",
     "Register as application for mail links" : "Регистрирај како апликација за отварање на е-пошта линкови ",
     "Register" : "Регистрирај се",
+    "Privacy and security" : "Приватност и безбедност",
+    "Data collection consent" : "Согласност за собирање податоци",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
     "Trusted senders" : "Доверливи испраќачи",
+    "Internal addresses" : "Внатрешни адреси",
+    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Означете ги надворешните е-адреси со овозможување на оваа функција, управувајте со вашите внатрешни адреси и домени за да се осигурате дека препознаените контакти остануваат необележани.",
+    "Manage S/MIME certificates" : "Управувај со S/MIME серификатите",
     "About" : "За",
+    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Оваа апликација го вклучува CKEditor, уредник со отворен код. Copyright © CKEditor contributors. Лиценцирано под GPLv2.",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Compose new message" : "Состави нова порака",
     "Newer message" : "Понови пораки",
@@ -104,11 +129,13 @@ OC.L10N.register(
     "Search" : "Барај",
     "Send" : "Прати",
     "Refresh" : "Освежи",
+    "Ok" : "Во ред",
     "No certificate" : "Нема сертификат",
     "Certificate updated" : "Сертификатот е ажуриран",
     "Could not update certificate" : "Неможе да се ажурира сертификатот",
     "{commonName} - Valid until {expiryDate}" : "{commonName} - Валиден до {expiryDate}",
     "Select an alias" : "Избери алијас",
+    "Select certificates" : "Избери сертификати",
     "Update Certificate" : "Ажурирај сертификат",
     "Encrypt with S/MIME and send later" : "Шифрирај со S/MIME и испрати ја подоцна",
     "Encrypt with S/MIME and send" : "Шифрирај со S/MIME и испрати",
@@ -153,6 +180,7 @@ OC.L10N.register(
     "Custom date and time" : "Одреден датум и време",
     "Enter a date" : "Внеси датум",
     "Choose" : "Избери",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прилогот ја надминува најголемата дозволена големина за прилози од {size}. Споделете го прилогот со линк.","Прилозите ја надминуваат најголемата дозволена големина за прилози од {size}. Споделете ги прилозите со линк."],
     "Choose a file to add as attachment" : "Избери датотека за да додадете прилог",
     "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
     "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
@@ -160,7 +188,7 @@ OC.L10N.register(
     "Confirm" : "Потврди",
     "Plain text" : "Обичен текст",
     "Rich text" : "Богат текст",
-    "No messages in this mailbox" : "Нема пораки во ова сандаче",
+    "No messages in this folder" : "Нема пораки во оваа папка",
     "No messages" : "Нема пораки",
     "Blind copy recipients only" : "Само приматели на слепи копии",
     "No subject" : "Нема наслов",
@@ -170,9 +198,7 @@ OC.L10N.register(
     "Set reminder for tomorrow" : "Постави потсетник за утре",
     "Set reminder for this weekend" : "Постави потсетник за овој викенд",
     "Set reminder for next week" : "Постави потсетник за наредната недела",
-    "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
     "Could not delete message" : "Неможе да се избрише пораката",
-    "Draft: " : "Шаблон:",
     "This message is unread" : "Оваа порака не е прочитана",
     "Favorite" : "Омилени",
     "Unread" : "Непрочитана",
@@ -181,6 +207,7 @@ OC.L10N.register(
     "Mark not spam" : "Од-означи СПАМ",
     "Mark as spam" : "Означи како СПАМ",
     "Edit tags" : "Удери ознаки",
+    "Delete message" : "Избриши порака",
     "More actions" : "Повеќе акции",
     "Back" : "Назад",
     "Edit as new message" : "Измени како нова порака",
@@ -193,6 +220,7 @@ OC.L10N.register(
     "_Mark {number} as important_::_Mark {number} as important_" : ["Означи {number} како важна","Означи {number} како важни"],
     "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Означи {number} како неважна","Означи {number} како неважни"],
     "_Unselect {number}_::_Unselect {number}_" : ["Од-означи {number}","Од-означи {number}"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Означи {number} како спам","Означи {number} како спам"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препрати како прилог","Препрати {number} како прилозиt"],
     "Report this bug" : "Пријави грешка",
     "Event created" : "Создаден е настан",
@@ -210,15 +238,18 @@ OC.L10N.register(
     "Accept" : "Прифати",
     "Decline" : "Одбиј",
     "More options" : "Повеќе опции ",
+    "Could not remove internal address {sender}" : "Неможе да се острани внатрешната адреса {sender}",
+    "Could not add internal address {address}" : "Неможе да се додаде внатрешната адреса {address}",
     "individual" : "индивидуално",
     "domain" : "домен",
     "Remove" : "Отстрани ",
     "email" : "е-пошта",
+    "Add internal address" : "Додади внатрешна адреса",
+    "Add internal email or domain" : "Додади внатрешна е-пошта или домен",
     "Itinerary for {type} is not supported yet" : "Итинерар за {type} сеуште не е поддржан",
-    "Could not open mailbox" : "Неможе да се отвори сандачето",
+    "Today" : "Денес",
     "Loading messages …" : "Вчитување пораки ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексирање на пораките. Ова може да трае многу долго за големи сандачиња.",
-    "Choose target mailbox" : "Изберете дојдовно сандаче",
+    "Choose target folder" : "Избери папка",
     "No more submailboxes in here" : "Нема повеќе подсандачиња тука",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Пораките автоматски ќе бидат означени како важни врз основа на кои пораки сте комуницирале или сте ги означиле како важни. На почетокот можеби ќе треба рачно да ја менувате важноста да го научите системот, но тоа ќе се подобрува со текот на времето.",
     "Important info" : "Важна информација",
@@ -253,34 +284,35 @@ OC.L10N.register(
     "Move" : "Премести",
     "Moving" : "Преместува",
     "Moving message" : "Преместување порака",
-    "Loading …" : "Се вчитува…",
-    "Not supported by the server" : "Не е поддржано од серверот",
-    "{usage} of {limit} used" : "Искористено {usage} од {limit}",
+    "Used quota: {quota}% ({limit})" : "Искористен простор: {quota}% ({limit})",
+    "Used quota: {quota}%" : "Искористен простор: {quota}%",
     "Remove account" : "Отстрани сметка",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Сметката за {email} и зачуваните податоци ќе бидат избришани, но нема да бидат избришани од провајдерот на електронската пошта.",
     "Remove {email}" : "Одстрани {email}",
-    "Quota" : "Квота",
-    "Show only subscribed mailboxes" : "Прикажи само претплатени сандачиња",
-    "Add mailbox" : "Додади сандаче",
+    "Show only subscribed folders" : "Прикажи само претплатени папки",
+    "Add folder" : "Додади папка",
+    "Folder name" : "Име на папка",
     "Saving" : "Зачувува",
     "Move up" : "Помести горе",
     "Move down" : "Помести доле",
-    "Show all subscribed mailboxes" : "Прикажи ги сите сандачиња со претплата",
-    "Show all mailboxes" : "Прикажи ги сите сандачиња",
-    "Collapse mailboxes" : "Сокриј сандачиња",
+    "Show all subscribed folders" : "Прикажи ги сите претплатени папки",
+    "Show all folders" : "Прикажи ги сите папки",
+    "Collapse folders" : "Сокриј ги папките",
     "_{total} message_::_{total} messages_" : ["{total} порака","{total} пораки"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитани од {total}"],
+    "Loading …" : "Се вчитува…",
     "Clear mailbox {name}" : "Исчисти сандаче {name}",
-    "Clear mailbox" : "Исчисти сандаче",
-    "The mailbox and all messages in it will be deleted." : "Сандачето и сеите пораки во него ќе бидат избришани.",
-    "Delete mailbox" : "Избриши сандаче",
-    "Delete mailbox {name}" : "Избриши сандаче {name}",
+    "The folder and all messages in it will be deleted." : "Папката и сите пораки во неа ќе бидат избришани.",
+    "Delete folder" : "Избриши папка",
+    "Delete folder {name}" : "Избриши папка {name}",
     "An error occurred, unable to rename the mailbox." : "Настана грешка, неможе да се промени името на сандачето.",
+    "Please wait 10 minutes before repairing again" : "Почекајте 10 минути пред повторно да поправите",
     "Mark all as read" : "Означи ги сите како прочитани",
-    "Mark all messages of this mailbox as read" : "Означи ги како прочитани сите пораки од ова сандаче ",
-    "Add submailbox" : "Додади подсандаче",
+    "Mark all messages of this folder as read" : "Означи ги сите пораки во оваа папка како прочитани",
+    "Add subfolder" : "Додади подпапка",
     "Rename" : "Преименувај",
-    "Move mailbox" : "Премести сандаче",
+    "Move folder" : "Премести папка",
+    "Repair folder" : "Поправи папка",
     "Clear cache" : "Избриши го кешот",
     "Clear locally cached data, in case there are issues with synchronization." : "Исчистете ги локално зачуваните податоци, во случај да има проблеми со синхронизацијата.",
     "Subscribed" : "Претплатени",
@@ -290,15 +322,15 @@ OC.L10N.register(
     "Edit message" : "Уреди порака",
     "Draft" : "Шаблон",
     "Reply" : "Одговор",
-    "No sent mailbox configured. Please pick one in the account settings." : "Нема сандаче за испратени пораки. Изберете сандаче во параметрите на сметката.",
+    "Message saved" : "Пораката е зачувана",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Се обидувате да испратите до многу примачи во До и/или Cc. Можете да користите Bcc за да ги скриете адресите на примачите.",
     "Message discarded" : "Пораката е отфрлена",
     "Could not discard message" : "Неможе да се отфрли порака",
     "Error sending your message" : "Грешка при испраќање на пораката",
     "Retry" : "Обидете се повторно",
-    "Uploading attachments …" : "Прикачување на прилог ...",
-    "Sending …" : "Испраќам ...",
     "Send anyway" : "Испрати секако",
+    "Welcome to {productName} Mail" : "Добредојдовте во {productName} е-пошта",
+    "Start writing a message by clicking below or select an existing message to display its contents" : "Започнете да пишувате порака со кликнување подолу или изберете постоечка порака за да ја прикажете нејзината содржина",
     "Autoresponder off" : "Исклучен автоматски одговор",
     "Autoresponder on" : "Вклучен автоматски одговор",
     "First day" : "Прв ден",
@@ -318,7 +350,6 @@ OC.L10N.register(
     "Show less" : "Помалку",
     "Show more" : "Прикажи повеќе",
     "Clear" : "Исчисти",
-    "Search in mailbox" : "Барај во сандачето",
     "Close" : "Затвори",
     "Search parameters" : "Параметри за пребарување",
     "Date" : "Датум",
@@ -342,6 +373,7 @@ OC.L10N.register(
     "Signature …" : "Потпис ...",
     "Save signature" : "Зачувај потпис",
     "Place signature above quoted text" : "Постави го потписот над цитираниот текст",
+    "Message source" : "Извор на пораката",
     "An error occurred, unable to rename the tag." : "Настана грешка, неможе да се преименува ознака.",
     "Saving new tag name …" : "Зачувување на ново име на ознака ...",
     "Tag name is a hidden system tag" : "Името на ознаката е сокриена системска ознака",
@@ -358,8 +390,6 @@ OC.L10N.register(
     "Mark as favorite" : "Означи како омилена",
     "Mark as unread" : "Означи како непрочитано",
     "Mark as read" : "Означи како прочитано",
-    "Delete message" : "Избриши порака",
-    "Message source" : "Извор на пораката",
     "Untitled event" : "Неименуван настан",
     "(organizer)" : "(organizer)",
     "Import into {calendar}" : "Увези во {calendar}",
@@ -371,8 +401,7 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
     "Train" : "Воз",
     "Flag" : "Знаме",
-    "Actions" : "Акции",
-    "New action" : "Нова акција",
+    "matches" : "се совпаѓа",
     "Priority" : "Приоритет",
     "Mail app" : "Апликација Електронска пошта",
     "The mail app allows users to read mails on their IMAP accounts." : "Апликацијата за електронска пошта дозволува на корисниците да ги читаат својте пораки од IMAP сметки.",
@@ -395,10 +424,26 @@ OC.L10N.register(
     "Save Config" : "Зачувај конфигурација",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% и %EMAIL% ќе биде заменето со корнички ID и e-po[ta",
     "With the settings above, the app will create account settings in the following way:" : "Со овие параметри, апликацијата ќе креира сметки:",
+    "Failed to import the certificate. Please check the password." : "Неуспешно увезување на сертификат. Проверете ја лозинката.",
+    "Certificate imported successfully" : "Сертификатот е успешно увезен",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Неуспешно увезување на сертификат. Проверете дали приватниот клуч се совпаѓа со сертификатот и не е заштитен со лозинка.",
+    "Failed to import the certificate" : "Неуспешен увоз на сертификат",
+    "S/MIME certificates" : "S/MIME сертификати",
+    "Certificate name" : "Име на сертификатот",
     "E-mail address" : "Е-пошта адреса",
     "Valid until" : "Валиден до",
+    "Delete certificate" : "Избриши сертификат",
+    "No certificate imported yet" : "Сеуште нема увезено сертификат",
+    "Import certificate" : "Увези сертификат",
+    "Import S/MIME certificate" : "Увези S/MIME сертификат",
+    "PKCS #12 Certificate" : "PKCS #12 Сертификат",
+    "PEM Certificate" : "PEM Сертификат",
     "Certificate" : "Сертификат",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Приватниот клуч е потребен само ако планирате да испраќате потпишани и шифрирани е-пораки користејќи го овој сертификат.",
     "Submit" : "Испрати",
+    "Group" : "Група",
+    "Shared" : "Споделено",
+    "Shares" : "Споделувања",
     "Account connected" : "Сметката е поврзана",
     "You can close this window" : "Можете да го затворите овој прозорец",
     "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
@@ -419,6 +464,7 @@ OC.L10N.register(
     "Discard unsaved changes" : "Отфрли ги назачуваните промени",
     "Keep editing message" : "Продолжи со уредување на порака",
     "Attachments were not copied. Please add them manually." : "Пролозите на се копирани. Додадете ги рачно.",
+    "Sending message…" : "Испраќање на порака ...",
     "Message sent" : "Пораката е испратена",
     "Could not send message" : "Неможе да се испрати порака",
     "Could not load {tag}{name}{endtag}" : "Неможе да се вчита {tag}{name}{endtag}",
@@ -433,6 +479,28 @@ OC.L10N.register(
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
     "Continue to %s" : "Продолжи до %s",
-    "This event is in the past." : "Овој настан е во минатото."
+    "No messages in this mailbox" : "Нема пораки во ова сандаче",
+    "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
+    "Draft: " : "Шаблон:",
+    "Could not open mailbox" : "Неможе да се отвори сандачето",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексирање на пораките. Ова може да трае многу долго за големи сандачиња.",
+    "Choose target mailbox" : "Изберете дојдовно сандаче",
+    "Show only subscribed mailboxes" : "Прикажи само претплатени сандачиња",
+    "Add mailbox" : "Додади сандаче",
+    "Show all subscribed mailboxes" : "Прикажи ги сите сандачиња со претплата",
+    "Show all mailboxes" : "Прикажи ги сите сандачиња",
+    "Collapse mailboxes" : "Сокриј сандачиња",
+    "Clear mailbox" : "Исчисти сандаче",
+    "The mailbox and all messages in it will be deleted." : "Сандачето и сеите пораки во него ќе бидат избришани.",
+    "Delete mailbox" : "Избриши сандаче",
+    "Delete mailbox {name}" : "Избриши сандаче {name}",
+    "Mark all messages of this mailbox as read" : "Означи ги како прочитани сите пораки од ова сандаче ",
+    "Add submailbox" : "Додади подсандаче",
+    "Move mailbox" : "Премести сандаче",
+    "Repair mailbox" : "Поправи сандаче",
+    "No sent mailbox configured. Please pick one in the account settings." : "Нема сандаче за испратени пораки. Изберете сандаче во параметрите на сметката.",
+    "Search in mailbox" : "Барај во сандачето",
+    "Actions" : "Акции",
+    "New action" : "Нова акција"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
