@@ -22,6 +22,7 @@ OC.L10N.register(
     "Signature" : "Гарын үсэг",
     "Go back" : "Буцах",
     "Cancel" : "болиулах",
+    "Accounts" : "Accounts",
     "Add mail account" : "шуудангийн хаяг нэмэх",
     "General" : "Ерөнхий",
     "List" : "Жагсаалт",
@@ -30,6 +31,7 @@ OC.L10N.register(
     "Search" : "Хайх",
     "Send" : "илгээх",
     "Refresh" : "Сэргээх",
+    "Ok" : "За",
     "Select account" : "Аккаунт сонгох",
     "Subject" : "Сэдэв",
     "Add attachment from Files" : "Файлаас хавсралт нэмэх",
@@ -45,6 +47,9 @@ OC.L10N.register(
     "Decline" : "Зөвшөөрөхгүй",
     "Remove" : "Устгах",
     "email" : "цахим шуудан",
+    "Today" : "өнөөдөр",
+    "Yesterday" : "Өчигдөр",
+    "Choose target folder" : "Зорилтот хавтасыг сонгох",
     "Other" : "Бусад",
     "Forward" : "дамжих",
     "Translate" : "Орчуулга",
@@ -54,27 +59,29 @@ OC.L10N.register(
     "Save all to Files" : "бүх файлыг хадгалах",
     "The images have been blocked to protect your privacy." : " таны хувийн нууцыг хамгаалахын тулд дүрсийг хаасан байна.",
     "Move" : "Зөөх",
-    "Loading …" : "Уншиж байна...",
     "Remove account" : "Аккаунт устгах",
-    "Quota" : " хувь хэмжээ",
+    "Folder name" : "Хавтасны нэр",
     "Saving" : "хадгаламж",
+    "Show all folders" : "Бүх хавтас харуулах",
+    "Loading …" : "Уншиж байна...",
     "Rename" : "Нэрлэнэ үү",
     "New message" : "шинэ зурвас",
     "Reply" : "хариулт",
     "Retry" : "Дахин оролдох",
-    "Sending …" : "илгээмж",
     "Add" : "нэмэх",
     "Date" : "Он сар өдөр",
     "Tags" : "Tag-үүд",
     "Custom" : "Дурын",
-    "Actions" : "Үйл ажиллагаа",
+    "Recipient" : "Хүлээн авагч",
+    "matches" : "тохируулах",
     "Reset" : "тохируулах",
     "Client ID" : "Хэрэглэгчийн ID",
-    "User" : "Хэрэглэгч",
     "Host" : "хост",
     "Port" : "порт",
     "Certificate" : "Гэрчилгээ",
     "Submit" : "мэдэгдэх",
+    "Shared" : "Түгээсэн",
+    "Shares" : "Түгээлтүүд",
     "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
     "All" : "бүх",
     "Drafts" : "ноорог",
@@ -83,6 +90,7 @@ OC.L10N.register(
     "Junk" : "хэрэггүй",
     "Sent" : "илгээсэн",
     "Trash" : "хог",
-    "Error loading message" : "алдаатай ачааллах зурвас"
+    "Error loading message" : "алдаатай ачааллах зурвас",
+    "Actions" : "Үйл ажиллагаа"
 },
 "nplurals=2; plural=(n != 1);");
