@@ -19,6 +19,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "Send",
     "Refresh" : "Last inn på nytt",
+    "Ok" : "Greitt",
     "Choose" : "Vel",
     "Favorite" : "Favoritt",
     "Back" : "Tilbake",
@@ -27,6 +28,8 @@ OC.L10N.register(
     "Select" : "Vel",
     "Comment" : "Kommentér",
     "Remove" : "Fjern",
+    "Today" : "I dag",
+    "Yesterday" : "I går",
     "Other" : "Anna",
     "Move" : "Move",
     "Folder name" : "Katalognavn",
@@ -45,6 +48,10 @@ OC.L10N.register(
     "Host" : "Tenar",
     "Port" : "Port",
     "Certificate" : "Sertifikat",
+    "Guest" : "Gjest",
+    "Group" : "Gruppe",
+    "Shared" : "Delt",
+    "Shares" : "Delingar",
     "All" : "Alle",
     "Favorites" : "Favorit",
     "Sent" : "Sendt",
