@@ -118,11 +118,13 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Używaj awatarów Gravatar i favicon",
     "Register as application for mail links" : "Zarejestruj się jako aplikacja do linków pocztowych",
     "Register" : "Zarejestruj się",
+    "Shared with me" : "Udostępnione dla mnie",
     "Data collection consent" : "Zgoda na zbieranie danych",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Zezwól aplikacji na zbieranie danych o Twoich interakcjach. Na podstawie tych danych aplikacja dostosuje się do Twoich preferencji. Dane będą przechowywane tylko lokalnie.",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Zezwalaj aplikacji na zbieranie danych o Twoich interakcjach. Na podstawie tych danych aplikacja dostosuje się do Twoich preferencji. Dane będą przechowywane tylko lokalnie.",
     "Trusted senders" : "Zaufani nadawcy",
     "Manage S/MIME certificates" : "Zarządzaj certyfikatami S/MIME",
     "Looking for a way to encrypt your emails?" : "Szukasz sposobu na szyfrowanie wiadomości e-mail?",
+    "Install Mailvelope browser extension" : "Zainstaluj rozszerzenie przeglądarki Mailvelope",
     "Assistance features" : "Asystent",
     "About" : "O aplikacji",
     "Keyboard shortcuts" : "Skróty klawiaturowe",
@@ -136,6 +138,7 @@ OC.L10N.register(
     "Search" : "Szukaj",
     "Send" : "Wyślij",
     "Refresh" : "Odśwież",
+    "Ok" : "OK",
     "Certificate updated" : "Aktualizacja certyfikatu",
     "Select an alias" : "Wybierz alias",
     "Select certificates" : "Wybierz certyfikat",
@@ -177,6 +180,7 @@ OC.L10N.register(
     "Custom date and time" : "Własna data i godzina",
     "Enter a date" : "Wpisz datę",
     "Choose" : "Wybierz",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Załącznik przekracza dozwolony rozmiar załączników z {size}. Zamiast tego udostępnij plik za pośrednictwem linku.","Załączniki przekraczają dozwolony rozmiar załączników z {size}. Zamiast tego udostępnij pliki za pośrednictwem linku.","Załączniki przekraczają dozwolony rozmiar załączników z {size}. Zamiast tego udostępnij pliki za pośrednictwem linku.","Załączniki przekraczają dozwolony rozmiar załączników z {size}. Zamiast tego udostępnij pliki za pośrednictwem linku."],
     "Choose a file to add as attachment" : "Wybierz plik, aby dodać jako załącznik",
     "Choose a file to share as a link" : "Wybierz plik do udostępnienia przez link",
     "_{count} attachment_::_{count} attachments_" : ["{count} załącznik","{count} załączniki","{count} załączników","{count} załączników"],
@@ -184,7 +188,6 @@ OC.L10N.register(
     "Confirm" : "Potwierdź",
     "Plain text" : "Zwykły tekst",
     "Rich text" : "Tekst sformatowany",
-    "No messages in this mailbox" : "Brak wiadomości w skrzynce pocztowej",
     "No messages" : "Brak wiadomości",
     "Blind copy recipients only" : "Tylko dla niewidocznych kopii",
     "No subject" : "Brak tematu",
@@ -196,10 +199,8 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Ustaw przypomnienie na ten weekend",
     "Next week – {timeLocale}" : "Następny tydzień – {timeLocale}",
     "Set reminder for next week" : "Ustaw przypomnienie na przyszły tydzień",
-    "No trash mailbox configured" : "Nie skonfigurowano skrzynki pocztowej dla kosza",
     "Could not delete message" : "Nie udało się usunąć wiadomości",
     "Could not archive message" : "Nie udało się zarchiwizować wiadomości",
-    "Draft: " : "Wersja robocza:",
     "Encrypted message" : "Zaszyfrowana wiadomość",
     "This message is unread" : "Ta wiadomość jest nieprzeczytana",
     "Unfavorite" : "Nie ulubione",
@@ -212,7 +213,9 @@ OC.L10N.register(
     "Edit tags" : "Edytuj etykiety",
     "Move thread" : "Przenieś wątek",
     "Archive thread" : "Wątek archiwalny",
+    "Archive message" : "Przenieś wiadomość do archiwum",
     "Delete thread" : "Usuń wątek",
+    "Delete message" : "Usuń wiadomość",
     "More actions" : "Więcej akcji",
     "Back" : "Poprzednia",
     "Edit as new message" : "Edytuj jako nową wiadomość",
@@ -256,16 +259,17 @@ OC.L10N.register(
     "Decline" : "Odrzuć",
     "Tentatively accept" : "Wstępnie zaakceptuj",
     "More options" : "Więcej opcji",
-    "This event is in the past." : "To wydarzenie już minęło.",
     "individual" : "indywidualny",
     "domain" : "domena",
     "Remove" : "Usuń",
     "email" : "e-mail",
     "Itinerary for {type} is not supported yet" : "Trasa dla {type} nie jest jeszcze obsługiwana",
-    "Could not open mailbox" : "Nie można otworzyć skrzynki pocztowej",
+    "Last hour" : "Ostatnia godzina",
+    "Today" : "Dzisiaj",
+    "Last week" : "W zeszłym tygodniu",
+    "Last month" : "W zeszłym miesiącu",
     "Loading messages …" : "Wczytywanie wiadomości…",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksowanie wiadomości. W przypadku większych skrzynek pocztowych może to potrwać trochę dłużej.",
-    "Choose target mailbox" : "Wybierz docelową skrzynkę pocztową",
+    "Choose target folder" : "Wybierz katalog docelowy",
     "No more submailboxes in here" : "Nie ma więcej skrzynek podrzędnych",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Wiadomości będą automatycznie oznaczane jako ważne na podstawie wiadomości, z którymi wchodziłeś w interakcję lub które oznaczałeś jako ważne. Na początku być może trzeba będzie ręcznie zmienić ważność dla uczenia systemu, ale z czasem będzie się poprawiać.",
     "Follow up" : "Follow up",
@@ -315,39 +319,34 @@ OC.L10N.register(
     "Moving" : "przenoszenie",
     "Moving thread" : "Przenoszenie wątku",
     "Moving message" : "Przenoszenie wiadomości",
-    "Loading …" : "Wczytywanie…",
-    "Not supported by the server" : "Niewspierany przez serwer",
-    "{usage} of {limit} used" : "Użyto {usage} z {limit}",
     "Remove account" : "Usuń konto",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Konto dla {email} i zapisane w pamięci podręcznej dane e-mail zostaną usunięte z Nextcloud, ale pozostaną nadal u dostawcy poczty e-mail.",
     "Remove {email}" : "Usuń {email}",
     "Provisioned account is disabled" : "Zabezpieczone konto jest wyłączone",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Zaloguj się przy użyciu hasła, aby włączyć to konto. Bieżąca sesja korzysta z uwierzytelniania bez hasła, m.in. SSO lub WebAuthn.",
-    "Quota" : "Limit",
-    "Show only subscribed mailboxes" : "Pokaż tylko subskrybowane skrzynki pocztowe",
-    "Add mailbox" : "Dodaj skrzynkę pocztową",
-    "Mailbox name" : "Nazwa skrzynki ",
+    "Show only subscribed folders" : "Pokaż tylko subskrybowane foldery",
+    "Add folder" : "Dodaj katalog",
+    "Folder name" : "Nazwa katalogu",
     "Saving" : "Zapisywanie",
     "Move up" : "Przenieś wyżej",
     "Move down" : "Przenieś niżej",
-    "Show all subscribed mailboxes" : "Pokaż wszystkie subskrybowane skrzynki pocztowe",
-    "Show all mailboxes" : "Pokaż wszystkie skrzynki pocztowe",
-    "Collapse mailboxes" : "Zwiń skrzynki pocztowe",
+    "Show all subscribed folders" : "Pokaż wszystkie subskrybowane foldery",
+    "Show all folders" : "Pokaż wszystkie foldery",
+    "Collapse folders" : "Zwiń foldery",
     "_{total} message_::_{total} messages_" : ["{total} wiadomość","{total} wiadomości","{total} wiadomości","{total} wiadomości"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nieprzeczytana z {total}","{unread} nieprzeczytane z {total}","{unread} nieprzeczytanych z {total}","{unread} nieprzeczytanych z {total}"],
+    "Loading …" : "Wczytywanie…",
     "All messages in mailbox will be deleted." : "Wszystkie wiadomości w skrzynce pocztowej zostaną usunięte.",
     "Clear mailbox {name}" : "Wyczyść skrzynkę pocztową {name}",
-    "Clear mailbox" : "Wyczyść skrzynkę pocztową",
-    "The mailbox and all messages in it will be deleted." : "Skrzynka pocztowa i wszystkie zawarte w niej wiadomości zostaną usunięte.",
-    "Delete mailbox" : "Usuń skrzynkę pocztową",
-    "Delete mailbox {name}" : "Usuń skrzynkę pocztową {name}",
+    "The folder and all messages in it will be deleted." : "Folder i wszystkie zawarte w nim wiadomości zostaną usunięte.",
+    "Delete folder" : "Usuń katalog",
+    "Delete folder {name}" : "Usuń folder {name}",
     "An error occurred, unable to rename the mailbox." : "Wystąpił błąd, nie można zmienić nazwy skrzynki pocztowej.",
     "Mark all as read" : "Oznacz wszystkie jako przeczytane",
-    "Mark all messages of this mailbox as read" : "Oznacz wszystkie wiadomości w tej skrzynce pocztowej jako przeczytane",
-    "Add submailbox" : "Dodaj skrzynkę podrzędną",
+    "Mark all messages of this folder as read" : "Oznacz wszystkie wiadomości w tym folderze jako przeczytane",
+    "Add subfolder" : "Dodaj podfolder",
     "Rename" : "Zmień nazwę",
-    "Move mailbox" : "Przenieś skrzynkę",
-    "Repair mailbox" : "Napraw skrzynkę",
+    "Move folder" : "Przenieś katalog",
     "Clear cache" : "Wyczyść pamięć podręczną",
     "Clear locally cached data, in case there are issues with synchronization." : "Wyczyść lokalnie buforowane dane, w przypadku problemów z synchronizacją.",
     "Subscribed" : "Zasubskrybowano",
@@ -362,14 +361,11 @@ OC.L10N.register(
     "Failed to save draft" : "Nie udało się zapisać szkicu",
     "attachment" : "załącznik",
     "attached" : "załączono",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nie skonfigurowano żadnej skrzynki pocztowej dla wysyłanych wiadomości. Wybierz którąś w ustawieniach konta.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Próbujesz wysłać do wielu odbiorców w Do i/lub DW. Rozważ użycie UDW, aby ukryć adresy odbiorców.",
     "Message discarded" : "Wiadomość odrzucona",
     "Could not discard message" : "Nie udało się odrzucić wiadomości",
     "Error sending your message" : "Błąd podczas wysyłania wiadomości",
     "Retry" : "Powtórz",
-    "Uploading attachments …" : "Wysyłanie załączników…",
-    "Sending …" : "Wysyłanie…",
     "Warning sending your message" : "Ostrzeżenie podczas wysyłania wiadomości",
     "Send anyway" : "Wyślij mimo to",
     "Autoresponder off" : "Automatyczna wiadomość zwrotna wyłączona",
@@ -396,7 +392,6 @@ OC.L10N.register(
     "Show less" : "Pokaż mniej",
     "Show more" : "Pokaż więcej",
     "Clear" : "Wyczyść ",
-    "Search in mailbox" : "Szukaj w skrzynce pocztowej",
     "Close" : "Zamknij",
     "Search parameters" : "Wyszukaj parametry",
     "Body" : "Treść",
@@ -419,6 +414,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Twój podpis jest większy niż 2 MB. Może to wpłynąć na wydajność Twojego edytora.",
     "Save signature" : "Zapisz podpis",
     "Place signature above quoted text" : "Umieść podpis nad cytowanym tekstem",
+    "Message source" : "Źródło wiadomości",
     "An error occurred, unable to rename the tag." : "Wystąpił błąd, nie można zmienić nazwy etykiety.",
     "Saving new tag name …" : "Zapisywanie nowej nazwy etykiety…",
     "Delete tag" : "Usuń etykiety",
@@ -441,9 +437,6 @@ OC.L10N.register(
     "Mark as favorite" : "Oznacz jako nieulubione",
     "Mark as unread" : "Oznacz jako nieprzeczytane",
     "Mark as read" : "Oznacz jako przeczytane",
-    "Archive message" : "Przenieś wiadomość do archiwum",
-    "Delete message" : "Usuń wiadomość",
-    "Message source" : "Źródło wiadomości",
     "The message could not be translated" : "Nie udało się przetłumaczyć wiadomości",
     "Translation copied to clipboard" : "Tłumaczenie skopiowane do schowka",
     "Translation could not be copied" : "Nie można skopiować tłumaczenia",
@@ -467,9 +460,10 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Pociąg z {depStation} do {arrStation}",
     "Train" : "Pociąg",
     "Flag" : "Flaga",
+    "Recipient" : "Odbiorca",
     "Operator" : "Operator",
-    "Actions" : "Akcje",
-    "New action" : "Nowa akcja",
+    "contains" : "zawiera",
+    "matches" : "pasuje",
     "Priority" : "Priorytet",
     "Successfully updated config for \"{domain}\"" : "Pomyślnie zaktualizowano konfigurację dla \"{domain}\"",
     "Error saving config" : "Błąd podczas zapisywania konfiguracji",
@@ -503,8 +497,6 @@ OC.L10N.register(
     "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail umożliwia użytkownikom dostęp do poczty e-mail za pośrednictwem protokołu IMAP. Ze względów bezpieczeństwa dostęp ten jest możliwy tylko za pomocą połączenia OAuth 2.0 lub kont Google korzystających z uwierzytelniania dwuskładnikowego i haseł do aplikacji.",
     "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Musisz zarejestrować nowy ID klienta dla \"Aplikacji internetowej\" w konsoli Google Cloud. Dodaj adres URL {url} jako identyfikator URI autoryzowanego przekierowania.",
     "Microsoft integration" : "Integracja Microsoft",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Firma Microsoft umożliwia użytkownikom dostęp do poczty e-mail za pośrednictwem protokołu IMAP. Ze względów bezpieczeństwa dostęp ten jest możliwy tylko przy połączeniu OAuth 2.0.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Musisz zarejestrować nową aplikację w portalu Microsoft Azure Active Directory. Dodaj adres URL {url} jako URI przekierowania.",
     "Successfully set up anti spam email addresses" : "Pomyślnie skonfigurowane antyspamowe adresy e-mail",
     "Error saving anti spam email addresses" : "Błąd podczas zapisywania antyspamowych adresów e-mail",
     "Successfully deleted anti spam reporting email" : "Pomyślnie usunięto e-mail z raportami antyspamowymi",
@@ -520,7 +512,7 @@ OC.L10N.register(
     "Could not configure Google integration" : "Nie można skonfigurować integracji Google",
     "Google integration unlinked" : "Odłączono integrację z Google",
     "Could not unlink Google integration" : "Nie można odłączyć integracji Google",
-    "Client ID" : "ID klienta",
+    "Client ID" : "Identyfikator klienta",
     "Client secret" : "Tajny klucz klienta",
     "Unlink" : "Odłącz",
     "Microsoft integration configured" : "Skonfigurowano integrację Microsoft",
@@ -563,6 +555,10 @@ OC.L10N.register(
     "Import S/MIME certificate" : "Importuj certyfikat S/MIME",
     "Certificate" : "Certyfikat",
     "Submit" : "Wyślij",
+    "Group" : "Grupa",
+    "Shared" : "Udostępnione",
+    "Shares" : "Udostępnienia",
+    "Insert" : "wstaw",
     "Account connected" : "Połączono z kontem",
     "You can close this window" : "Możesz zamknąć okno",
     "Connect your mail account" : "Podłącz konto pocztowe",
@@ -581,6 +577,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nowa wiadomość\nod {from}","%n nowe wiadomości \nod {from}","%n nowych wiadomości \nod {from}","%n nowych wiadomości \nod {from}"],
     "Nextcloud Mail" : "Poczta Nextcloud",
+    "Discard changes" : "Odrzuć zmiany",
     "Attachments were not copied. Please add them manually." : "Załączniki nie zostały skopiowane. Dodaj je ręcznie.",
     "Message sent" : "Wiadomość wysłana",
     "Could not send message" : "Nie udało się wysłać wiadomości",
@@ -595,6 +592,30 @@ OC.L10N.register(
     "Redirect" : "Przekieruj",
     "The link leads to %s" : "Link prowadzi do %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
-    "Continue to %s" : "Kontynuuj do %s"
+    "Continue to %s" : "Kontynuuj do %s",
+    "No messages in this mailbox" : "Brak wiadomości w skrzynce pocztowej",
+    "No trash mailbox configured" : "Nie skonfigurowano skrzynki pocztowej dla kosza",
+    "Draft: " : "Wersja robocza:",
+    "Could not open mailbox" : "Nie można otworzyć skrzynki pocztowej",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksowanie wiadomości. W przypadku większych skrzynek pocztowych może to potrwać trochę dłużej.",
+    "Choose target mailbox" : "Wybierz docelową skrzynkę pocztową",
+    "Show only subscribed mailboxes" : "Pokaż tylko subskrybowane skrzynki pocztowe",
+    "Add mailbox" : "Dodaj skrzynkę pocztową",
+    "Mailbox name" : "Nazwa skrzynki ",
+    "Show all subscribed mailboxes" : "Pokaż wszystkie subskrybowane skrzynki pocztowe",
+    "Show all mailboxes" : "Pokaż wszystkie skrzynki pocztowe",
+    "Collapse mailboxes" : "Zwiń skrzynki pocztowe",
+    "Clear mailbox" : "Wyczyść skrzynkę pocztową",
+    "The mailbox and all messages in it will be deleted." : "Skrzynka pocztowa i wszystkie zawarte w niej wiadomości zostaną usunięte.",
+    "Delete mailbox" : "Usuń skrzynkę pocztową",
+    "Delete mailbox {name}" : "Usuń skrzynkę pocztową {name}",
+    "Mark all messages of this mailbox as read" : "Oznacz wszystkie wiadomości w tej skrzynce pocztowej jako przeczytane",
+    "Add submailbox" : "Dodaj skrzynkę podrzędną",
+    "Move mailbox" : "Przenieś skrzynkę",
+    "Repair mailbox" : "Napraw skrzynkę",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nie skonfigurowano żadnej skrzynki pocztowej dla wysyłanych wiadomości. Wybierz którąś w ustawieniach konta.",
+    "Search in mailbox" : "Szukaj w skrzynce pocztowej",
+    "Actions" : "Akcje",
+    "New action" : "Nowa akcja"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
