@@ -64,6 +64,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Imprea Gravatar e avatar favicon",
     "Register as application for mail links" : "Registra comente aplicatzione pro is ligòngios de posta",
     "Register" : "Registra",
+    "Shared with me" : "Cumpartzidos cun megus",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permite a s'aplicatzione de regòllere datos subra is interatziones tuas. In sa base de custos datos, s'aplicatziones s'at a adatare a is preferèntzias tuas. Is datos ant a èssere archiviados in manera locale isceti. ",
     "Trusted senders" : "Imbiantes afidàbiles",
     "About" : "In contu de",
@@ -78,6 +79,7 @@ OC.L10N.register(
     "Search" : "Chirca",
     "Send" : "Imbia",
     "Refresh" : "Agiorna",
+    "Ok" : "AB",
     "Message {id} could not be found" : "Su messàgiu {id} no s'est pòdidu agatare",
     "From" : "Dae",
     "Select account" : "Seletziona contu",
@@ -151,6 +153,10 @@ OC.L10N.register(
     "email" : "posta eletrònica",
     "Add internal address" : "Agiunghe indiritzu internu",
     "Itinerary for {type} is not supported yet" : "S'itineràriu pro {type} no est ancora suportadu",
+    "Last hour" : "Ùrtima ora",
+    "Today" : "Oe ",
+    "Yesterday" : "Cras",
+    "Last week" : "Sa chida passada",
     "Choose target folder" : "Sèbera cartella de destinatzione",
     "No more submailboxes in here" : "Non b'at àteras suta-cartellas inoghe",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Is messàgios s'ant a marcare in manera automàtica comente importantes in sa base de is messàgios cun is chi as tènnidu interatziones o chi si sunt marcados comente importantes. Fortzis a su cumintzu as a dèpere cambiare a manu s'importàntzia pro ddu imparare a su sistema, ma at a megiorare in su tempus.",
@@ -194,7 +200,6 @@ OC.L10N.register(
     "Saving" : "Sarvende",
     "Move up" : "Tràmuda fache a susu",
     "Move down" : "Tràmuda fache a bàsciu",
-    "Collapse mailboxes" : "Istringhe is casellas de posta",
     "_{total} message_::_{total} messages_" : ["{total} messàgios","{total} messàgios"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non lèghidos de {total}","{unread} unread of {total}"],
     "Loading …" : "Carrrighende …",
@@ -316,6 +321,10 @@ OC.L10N.register(
     "E-mail address" : "Indiritzu de posta eletrònica",
     "Certificate" : "Tzertificadu",
     "Submit" : "Imbia",
+    "Guest" : "Persone invitada",
+    "Group" : "Grupu",
+    "Shared" : "Cumpartziduras",
+    "Shares" : "Cumpartziduras",
     "Account connected" : "Contu collegadu",
     "Connect your mail account" : "Connete·ti a su contu de posta tuo",
     "All" : "Totu",
@@ -354,6 +363,7 @@ OC.L10N.register(
     "Add mailbox" : "Agiunghe casella de posta",
     "Show all subscribed mailboxes" : "Mustra totu is casellas de posta sutascritas",
     "Show all mailboxes" : "Mustra totu is casellas de posta",
+    "Collapse mailboxes" : "Istringhe is casellas de posta",
     "The mailbox and all messages in it will be deleted." : "Sa casella de posta e is messàgios chi cuntenet ant a èssere cantzellados.",
     "Delete mailbox" : "Cantzella casella de posta",
     "Delete mailbox {name}" : "Cantzella casella de posta {name}",
