@@ -30,6 +30,7 @@ OC.L10N.register(
     "Accept" : "පිළිගන්න",
     "Decline" : "ප්‍රතික්ෂේප",
     "Remove" : "ඉවත් කරන්න",
+    "Today" : "අද",
     "Other" : "වෙනත්",
     "Translate" : "පරිවර්තනය",
     "Remove account" : "ගිණුම ඉවත් කරන්න",
@@ -47,6 +48,7 @@ OC.L10N.register(
     "User" : "පරිශීලක",
     "Host" : " ධාරකය",
     "Certificate" : "සහතිකය",
+    "Shares" : "බෙදාගැනීම්",
     "All" : "සියල්ල",
     "Favorites" : "ප්‍රියතම",
     "Actions" : "ක්‍රියාමාර්ග"
