@@ -22,6 +22,26 @@ OC.L10N.register(
     "Deleted messages are moved in:" : "Izbrisana sporočila so premaknjena v:",
     "Archived messages are moved in:" : "Arhivirana sporočila so premaknjena v:",
     "Junk messages are saved in:" : "Neželena sporočila se shranjujejo v:",
+    "Connecting" : "Poteka vzpostavljanje povezave ...",
+    "Reconnect Google account" : "Ponovno poveži račun Google.",
+    "Sign in with Google" : "Prijava z računom Google",
+    "Save" : "Shrani",
+    "Connect" : "Poveži",
+    "Looking up configuration" : "Poteka preverjanje nastavitev",
+    "Checking mail host connectivity" : "Preverjanje povezljivosti poštnega stražnika",
+    "Configuration discovery failed. Please use the manual settings" : "Pridobivanje podatkov nastavitev je spodletelo. Vnesti jih je treba ročno.",
+    "Password required" : "Zahtevano je geslo",
+    "Testing authentication" : "Poteka overjanje podatkov",
+    "Awaiting user consent" : "Čakanje na odziv uporabnika",
+    "Account created. Please follow the pop-up instructions to link your Google account" : "Račun je ustvarjen. Za povezavo Googlovega računa sledite navodilom.",
+    "Loading account" : "Poteka nalaganje računa",
+    "Account updated" : "Račun je posodobljen",
+    "IMAP server is not reachable" : "Strežnik IMAP ni dosegljiv",
+    "SMTP server is not reachable" : "Strežnik SMTP ni dosegljiv",
+    "IMAP username or password is wrong" : "Uporabniško ime ali geslo IMAP je neveljavno",
+    "SMTP username or password is wrong" : "Uporabniško ime ali geslo SMTP je neveljavno",
+    "IMAP connection failed" : "Povezava IMAP je spodletela",
+    "SMTP connection failed" : "Povezava SMTP je spodletela",
     "Auto" : "Samodejno",
     "Name" : "Ime",
     "Mail address" : "Elektronski naslov",
@@ -45,26 +65,6 @@ OC.L10N.register(
     "SMTP User" : "Uporabnik SMTP",
     "SMTP Password" : "Geslo SMTP",
     "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Za pravilno delovanje poštnega računa Google je treba omogočiti dvostopenjsko overitev in določiti geslo za program.",
-    "Connecting" : "Poteka vzpostavljanje povezave ...",
-    "Reconnect Google account" : "Ponovno poveži račun Google.",
-    "Sign in with Google" : "Prijava z računom Google",
-    "Save" : "Shrani",
-    "Connect" : "Poveži",
-    "Looking up configuration" : "Poteka preverjanje nastavitev",
-    "Checking mail host connectivity" : "Preverjanje povezljivosti poštnega stražnika",
-    "Configuration discovery failed. Please use the manual settings" : "Pridobivanje podatkov nastavitev je spodletelo. Vnesti jih je treba ročno.",
-    "Password required" : "Zahtevano je geslo",
-    "Testing authentication" : "Poteka overjanje podatkov",
-    "Awaiting user consent" : "Čakanje na odziv uporabnika",
-    "Account created. Please follow the pop-up instructions to link your Google account" : "Račun je ustvarjen. Za povezavo Googlovega računa sledite navodilom.",
-    "Loading account" : "Poteka nalaganje računa",
-    "Account updated" : "Račun je posodobljen",
-    "IMAP server is not reachable" : "Strežnik IMAP ni dosegljiv",
-    "SMTP server is not reachable" : "Strežnik SMTP ni dosegljiv",
-    "IMAP username or password is wrong" : "Uporabniško ime ali geslo IMAP je neveljavno",
-    "SMTP username or password is wrong" : "Uporabniško ime ali geslo SMTP je neveljavno",
-    "IMAP connection failed" : "Povezava IMAP je spodletela",
-    "SMTP connection failed" : "Povezava SMTP je spodletela",
     "Account settings" : "Nastavitve računa",
     "Aliases" : "Vzdevki",
     "Signature" : "Podpis",
@@ -74,7 +74,6 @@ OC.L10N.register(
     "Default folders" : "Privzete mape",
     "Filters" : "Filtri",
     "Mail server" : "Poštni strežnik",
-    "Mailbox search" : "Iskanje po poštnem predalu",
     "Update alias" : "Posodobi vzdevek",
     "Rename alias" : "Preimenuj vzdevek",
     "Show update alias form" : "Pokaži obrazec za posodobitev vzdevka",
@@ -85,6 +84,8 @@ OC.L10N.register(
     "Add alias" : "Dodaj vzdevek",
     "Create alias" : "Ustvari vzdevek",
     "Cancel" : "Prekliči",
+    "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad.",
+    "Could not update preference" : "Lastnosti ni mogoče posodobiti",
     "Mail settings" : "Nastavitve pošte",
     "Accounts" : "Računi",
     "Add mail account" : "Dodaj račun elektronske pošte",
@@ -97,11 +98,13 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
     "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
     "Register" : "Vpis računa",
+    "Shared with me" : "V souporabi z mano",
     "Data collection consent" : "Strinjanje z zbiranjem podatkov",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
     "Trusted senders" : "Zaupanja vredni pošiljatelji",
     "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME",
     "Looking for a way to encrypt your emails?" : "Ali iščete način za šifriranje elektronskih sporočil?",
+    "About" : "O meni",
     "Keyboard shortcuts" : "Tipkovne bližnjice",
     "Compose new message" : "Novo sporočilo",
     "Newer message" : "Novejše sporočilo",
@@ -113,14 +116,22 @@ OC.L10N.register(
     "Search" : "Iskanje",
     "Send" : "Pošlji",
     "Refresh" : "Osveži",
-    "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad.",
-    "Could not update preference" : "Lastnosti ni mogoče posodobiti",
-    "Select an alias" : "Izbor vzdevka",
-    "Update Certificate" : "Posodobi potrdilo",
+    "Ok" : "Sprejemljivo",
     "No certificate" : "Ni potrdil",
     "Certificate updated" : "Potrdilo je posodobljeno",
     "Could not update certificate" : "Potrdila ni mogoče posodobiti",
     "{commonName} - Valid until {expiryDate}" : "{commonName} – veljavnost do {expiryDate}",
+    "Select an alias" : "Izbor vzdevka",
+    "Update Certificate" : "Posodobi potrdilo",
+    "Encrypt with S/MIME and send later" : "Šifriraj z S/MIME in pošlji kasneje",
+    "Encrypt with S/MIME and send" : "Šifriraj z S/MIME in pošlji",
+    "Encrypt with Mailvelope and send later" : "Šifriraj z Mailvelope in pošlji kasneje",
+    "Encrypt with Mailvelope and send" : "Šifriraj z Mailvelope in pošlji",
+    "Send later" : "Pošlji kasneje",
+    "Message {id} could not be found" : "Sporočila {id} ni mogoče najti.",
+    "Turn off formatting" : "Onemogoči oblikovanje",
+    "Turn off and remove formatting" : "Onemogoči in odstrani oblikovanje",
+    "Keep formatting" : "Ohrani oblikovanje",
     "From" : "Od",
     "Select account" : "Izbor računa",
     "To" : "Za",
@@ -144,7 +155,6 @@ OC.L10N.register(
     "Upload attachment" : "Pošlji prilogo",
     "Add attachment from Files" : "Dodaj prilogo iz Datotek",
     "Smart picker" : "Pametni izbirnik",
-    "Send later" : "Pošlji kasneje",
     "Request a read receipt" : "Zahtevaj povratnico",
     "Sign message with S/MIME" : "Podpiši sporočila z S/MIME",
     "Encrypt message with S/MIME" : "Šifriraj z S/MIME",
@@ -155,25 +165,29 @@ OC.L10N.register(
     "Monday morning" : "Ponedeljek zjutraj",
     "Custom date and time" : "Datum in čas po meri",
     "Enter a date" : "Vpis datuma ...",
-    "Encrypt with S/MIME and send later" : "Šifriraj z S/MIME in pošlji kasneje",
-    "Encrypt with S/MIME and send" : "Šifriraj z S/MIME in pošlji",
-    "Encrypt with Mailvelope and send later" : "Šifriraj z Mailvelope in pošlji kasneje",
-    "Encrypt with Mailvelope and send" : "Šifriraj z Mailvelope in pošlji",
-    "Message {id} could not be found" : "Sporočila {id} ni mogoče najti.",
-    "Turn off formatting" : "Onemogoči oblikovanje",
-    "Turn off and remove formatting" : "Onemogoči in odstrani oblikovanje",
-    "Keep formatting" : "Ohrani oblikovanje",
+    "Choose" : "Izbor",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Velikost priloge presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave."],
     "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
     "Choose a file to share as a link" : "Izberite datoteko, ki jo želite dati v skupno rabo kot povezavo",
-    "Choose" : "Izbor",
     "_{count} attachment_::_{count} attachments_" : ["{count} priloga","{count} prilogi","{count} priloge","{count} prilog"],
     "Untitled message" : "Nenaslovljeno sporočilo",
     "Confirm" : "Potrdi",
     "Plain text" : "Besedilno",
     "Rich text" : "Obogateno besedilo",
-    "No messages in this mailbox" : "V poštnem predalu ni sporočil.",
+    "No messages in this folder" : "V tej mapi ni sporočil",
     "No messages" : "Ni sporočil",
-    "Draft: " : "Osnutek:",
+    "Blind copy recipients only" : "Le prejemniki skrite kopije",
+    "No subject" : "Ni zadeve",
+    "Later today – {timeLocale}" : "Danes – {timeLocale}",
+    "Set reminder for later today" : "Nastavi opomnik za danes",
+    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
+    "Set reminder for tomorrow" : "Nastavi opomnik za jutri",
+    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
+    "Set reminder for this weekend" : "Nastavi opomnik za ta teden",
+    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
+    "Set reminder for next week" : "Nastavi opomnik za naslednji teden",
+    "Could not delete message" : "Sporočila ni mogoče izbrisati",
+    "Could not archive message" : "Ni mogoče arhivirati sporočila",
     "Encrypted message" : "Šifrirano sporočilo",
     "This message is unread" : "To sporočilo še ni bilo prebrano",
     "Unfavorite" : "Odstrani oznako priljubljeno",
@@ -186,22 +200,15 @@ OC.L10N.register(
     "Edit tags" : "Uredi oznake",
     "Move thread" : "Premakni nit",
     "Archive thread" : "Nit arhiva",
+    "Archive message" : "Arhiviraj sporočilo",
     "Delete thread" : "Izbriši nit",
+    "Delete message" : "Izbriši sporočilo",
     "More actions" : "Več dejanj",
     "Back" : "Nazaj",
     "Edit as new message" : "Uredi kot novo sporočilo",
     "Create event" : "Ustvari dogodek",
     "Create task" : "Ustvari nalogo",
     "Download message" : "Prejmi sporočilo",
-    "Blind copy recipients only" : "Le prejemniki skrite kopije",
-    "No subject" : "Ni zadeve",
-    "Set reminder for later today" : "Nastavi opomnik za danes",
-    "Set reminder for tomorrow" : "Nastavi opomnik za jutri",
-    "Set reminder for this weekend" : "Nastavi opomnik za ta teden",
-    "Set reminder for next week" : "Nastavi opomnik za naslednji teden",
-    "No trash mailbox configured" : "Ni nastavljenega poštne mape za smeti",
-    "Could not delete message" : "Sporočila ni mogoče izbrisati",
-    "Could not archive message" : "Ni mogoče arhivirati sporočila",
     "Load more" : "Naloži več",
     "_Mark {number} read_::_Mark {number} read_" : ["Označi {number} sporočilo kot prebrano","Označi {number} sporočili kot prebrani","Označi {number} sporočila kot prebrana","Označi {number} sporočil kot prebrana"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} sporočilo kot neprebrano","Označi {number} sporočili kot neprebrani","Označi {number} sporočila kot neprebrana","Označi {number} sporočil kot neprebrana"],
@@ -211,12 +218,18 @@ OC.L10N.register(
     "_Move {number} thread_::_Move {number} threads_" : ["Premakni {number} nit sporočil","Premakni {number} niti sporočil","Premakni {number} niti sporočil","Premakni {number} niti sporočil"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Posreduj {number} sporočilo kot prilogo","Posreduj {number} sporočili kot prilogo","Posreduj {number} sporočila kot prilogo","Posreduj {number} sporočil kot prilogo"],
     "Report this bug" : "Pošlji poročilo o hrošču",
+    "Event created" : "Dogodek je ustvarjen",
+    "Could not create event" : "Ni mogoče ustvariti dogodka",
     "All day" : "Ves dan",
     "Select calendar" : "Izbor koledarja",
     "Description" : "Opis",
     "Create" : "Ustvari",
-    "Event created" : "Dogodek je ustvarjen",
-    "Could not create event" : "Ni mogoče ustvariti dogodka",
+    "This event was updated" : "Dogodek je posodobljen",
+    "{attendeeName} accepted your invitation" : "{attendeeName} sprejme povabilo",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} pogojno sprejme vabilo",
+    "{attendeeName} declined your invitation" : "{attendeeName} zavrne povabilo",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} se odzove na povabilo",
+    "Failed to save your participation status" : "Shranjevanje stanja udeležbe je spodletelo",
     "You accepted this invitation" : "Povabilo ste sprejeli",
     "You tentatively accepted this invitation" : "Vabilo ste sprejeli pogojno",
     "You declined this invitation" : "Povabilo ste zavrnili",
@@ -230,30 +243,25 @@ OC.L10N.register(
     "Decline" : "Zavrni",
     "Tentatively accept" : "Pogojno sprejmi",
     "More options" : "Več možnosti",
-    "This event is in the past." : "Dogodek je v preteklosti",
-    "This event was updated" : "Dogodek je posodobljen",
-    "{attendeeName} accepted your invitation" : "{attendeeName} sprejme povabilo",
-    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} pogojno sprejme vabilo",
-    "{attendeeName} declined your invitation" : "{attendeeName} zavrne povabilo",
-    "{attendeeName} reacted to your invitation" : "{attendeeName} se odzove na povabilo",
-    "Failed to save your participation status" : "Shranjevanje stanja udeležbe je spodletelo",
+    "individual" : "posamično",
     "domain" : "domena",
     "Remove" : "Odstrani",
     "email" : "elektronska pošta",
-    "individual" : "posamično",
     "Itinerary for {type} is not supported yet" : "{type} – vrsta prevoza še ni podprta",
-    "Could not open mailbox" : "Ni mogoče odpreti poštnega predala",
+    "Last hour" : "Zadnja ura",
+    "Today" : "Danes",
+    "Last week" : "Zadnji teden",
+    "Last month" : "Zadnji mesec",
     "Loading messages …" : "Poteka nalaganje sporočil ...",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Poteka ustvarjanje kazala sporočil. Opravilo je lahko dolgotrajno pri velikih poštnih predalih.",
-    "Choose target mailbox" : "Izbor ciljnega poštnega predala",
+    "Choose target folder" : "Izbor ciljne mape",
     "No more submailboxes in here" : "V tem predalu ni drugih predalov",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Sporočila bodo samodejno označena kot pomembna na podlagi do sedaj označenih takih sporočil. V začetku bo verjetno treba kakšno označiti še ročno, a se bo sistem s časom izboljševal.",
     "Important info" : "Pomembno",
     "Other" : "Drugo",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Sporočila bodo samodejno označena kot pomembna na podlagi do sedaj označenih takih sporočil. V začetku bo verjetno treba kakšno označiti še ročno, a se bo sistem s časom izboljševal.",
+    "Could not send mdn" : "Sporočila ni mogoče poslati",
     "The sender of this message has asked to be notified when you read this message." : "Pošiljatelj želi biti obveščen, ko preberete to sporočilo.",
     "Notify the sender" : "Obvesti pošiljatelja",
     "You sent a read confirmation to the sender of this message." : "Poslali ste potrditev pošiljatelju tega sporočila.",
-    "Could not send mdn" : "Sporočila ni mogoče poslati",
     "Forward" : "Posreduj",
     "Move message" : "Premakni sporočilo",
     "Translate" : "Prevedi",
@@ -261,12 +269,12 @@ OC.L10N.register(
     "View source" : "Pokaži kode sporočila",
     "Download thread data for debugging" : "Prejmi podatke niti za razhroščevanje",
     "Message body" : "Telo sporočila",
+    "Unnamed" : "Neimenovano",
+    "Embedded message" : "Vstavljeno sporočilo",
     "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje priloge",
     "Import into calendar" : "Uvozi v koledar",
     "Download attachment" : "Prejmi prilogo",
     "Save to Files" : "Shrani v Datoteke",
-    "Unnamed" : "Neimenovano",
-    "Embedded message" : "Vstavljeno sporočilo",
     "View fewer attachments" : "Pokaži manj prilog",
     "Choose a folder to store the attachments in" : "Izbor mape za shranjevanje priloge",
     "Save all to Files" : "Shrani vse v Datoteke",
@@ -283,57 +291,52 @@ OC.L10N.register(
     "Moving" : "Premikanje",
     "Moving thread" : "Poteka premikanje niti ...",
     "Moving message" : "Poteka premikanje sporočila ...",
+    "Remove account" : "Odstrani račun",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} in podatki tega računa v predpomnilniku bodo odstranjeni iz oblaka Nextcloud, ne pa tudi iz poštnega računa pri ponudniku storitve.",
+    "Remove {email}" : "Odstrani {email}",
     "Provisioned account is disabled" : "Povezan račun je onemogočen",
-    "Quota" : "Količinska omejitev",
-    "Show only subscribed mailboxes" : "Pokaži le naročene poštne predale",
-    "Add mailbox" : "Dodaj poštni predal",
+    "Show only subscribed folders" : "Pokaži le naročene mape",
+    "Add folder" : "Dodaj mapo",
+    "Folder name" : "Ime mape",
     "Saving" : "Poteka shranjevanje ...",
     "Move up" : "Premakni višje",
     "Move down" : "Premakni navzdol",
-    "Remove account" : "Odstrani račun",
+    "Show all subscribed folders" : "Pokaži vse naročene mape",
+    "Show all folders" : "Pokaži vse mape",
+    "Collapse folders" : "Zloži mape",
+    "_{total} message_::_{total} messages_" : ["{total} sporočilo","{total} sporočili","{total} sporočila","{total} sporočil"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neprebrano od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebranih od skupno {total}"],
     "Loading …" : "Poteka nalaganje …",
-    "Not supported by the server" : "Opravilo na strežniku ni podprto",
-    "{usage} of {limit} used" : "Uporabljeno je {usage} od {limit} prostora.",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} in podatki tega računa v predpomnilniku bodo odstranjeni iz oblaka Nextcloud, ne pa tudi iz poštnega računa pri ponudniku storitve.",
-    "Remove {email}" : "Odstrani {email}",
-    "Show all subscribed mailboxes" : "Pokaži vse naročene poštne predale",
-    "Show all mailboxes" : "Pokaži vse poštne predale",
-    "Collapse mailboxes" : "Skrči poštne predale",
+    "All messages in mailbox will be deleted." : "Vsa sporočila v poštnem predalu bodo izbrisana.",
+    "Clear mailbox {name}" : "Počisti poštni predal {name}",
+    "The folder and all messages in it will be deleted." : "Mapa in vsa sporočila bodo izbrisana.",
+    "Delete folder" : "Izbriši mapo",
+    "Delete folder {name}" : "Izbriši mapo {name}",
+    "An error occurred, unable to rename the mailbox." : "Prišlo je do napake; poštnega predala ni mogoče preimenovati.",
     "Mark all as read" : "Označi vse kot prebrano",
-    "Mark all messages of this mailbox as read" : "Označi vsa sporočila v tej mapi kot prebrana",
-    "Add submailbox" : "Dodaj podrejeni poštni predal",
+    "Mark all messages of this folder as read" : "Označi vsa sporočila v tej mapi kot prebrana",
+    "Add subfolder" : "Dodaj podmapo",
     "Rename" : "Preimenuj",
-    "Move mailbox" : "Premakni poštni predal",
+    "Move folder" : "Premakni mapo",
     "Clear cache" : "Počisti predpomnilnik",
     "Clear locally cached data, in case there are issues with synchronization." : "Počisti krajevno predpomnjena sporočila, v primeru morebitnih težav z usklajevanjem.",
     "Subscribed" : "Naročeno",
     "Sync in background" : "Uskladi v ozadju",
-    "Clear mailbox" : "Počisti poštni predal",
-    "Delete mailbox" : "Izbriši poštni predal",
-    "All messages in mailbox will be deleted." : "Vsa sporočila v poštnem predalu bodo izbrisana.",
-    "Clear mailbox {name}" : "Počisti poštni predal {name}",
-    "The mailbox and all messages in it will be deleted." : "Poštni predal in vsa vključena sporočila bodo izbrisana.",
-    "Delete mailbox {name}" : "Izbriši poštni predal {name}",
-    "An error occurred, unable to rename the mailbox." : "Prišlo je do napake; poštnega predala ni mogoče preimenovati.",
-    "_{total} message_::_{total} messages_" : ["{total} sporočilo","{total} sporočili","{total} sporočila","{total} sporočil"],
     "Outbox" : "Odhodna pošta",
     "New message" : "Novo sporočilo",
-    "Error sending your message" : "Prošlo je do napake med pošiljanjem sporočila",
-    "Retry" : "Poskusi  znova",
-    "Uploading attachments …" : "Poteka pošiljanje prilog ...",
-    "Sending …" : "Poteka pošiljanje ...",
-    "Warning sending your message" : "Opozorilo pred pošiljanjem sporočila",
-    "Send anyway" : "Pošlji vseeno",
     "Edit message" : "Uredi sporočilo",
     "Draft" : "Osnutek",
     "Reply" : "Odgovori",
     "Message saved" : "Sporočilo je shranjeno",
     "Failed to save message" : "Shranjevanje sporočila je spodletelo",
     "Failed to save draft" : "Shranjevanje osnutka je spodletelo",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ni določenega predala za pošiljanje. Izberite ga med nastavitvami računa.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Poskušate poslati prevelikemu številu naslovnikov in prejemnikov kopije sporočila. Razmislite o uporabi skrite kopije za izbrane naslove.",
     "Message discarded" : "Sporočilo je izbrisano",
     "Could not discard message" : "Sporočila ni mogoče zavreči",
+    "Error sending your message" : "Prošlo je do napake med pošiljanjem sporočila",
+    "Retry" : "Poskusi  znova",
+    "Warning sending your message" : "Opozorilo pred pošiljanjem sporočila",
+    "Send anyway" : "Pošlji vseeno",
     "First day" : "Prvi dan",
     "Last day (optional)" : "Zadnji dan (izbirno)",
     "Message" : "Sporočilo",
@@ -341,17 +344,17 @@ OC.L10N.register(
     "Could not open outbox" : "Ni mogoče odpreti odhodnega predala",
     "Message could not be sent" : "Sporočila ni mogoče poslati",
     "Message deleted" : "Sporočilo je izbrisano",
+    "Copied email address to clipboard" : "Elektronski naslov je kopiran v odložišče",
+    "Could not copy email address to clipboard" : "Elektronskega naslova ni mogoče kopirati v odložišče",
     "Contacts with this address" : "Stiki s tem naslovom",
     "Add to Contact" : "Dodaj k stiku",
     "New Contact" : "Nov stik",
     "Copy to clipboard" : "Kopiraj v odložišče",
     "Contact name …" : "Ime stika …",
     "Add" : "Dodaj",
-    "Copied email address to clipboard" : "Elektronski naslov je kopiran v odložišče",
-    "Could not copy email address to clipboard" : "Elektronskega naslova ni mogoče kopirati v odložišče",
     "Show less" : "Pokaži manj",
     "Show more" : "Pokaži več",
-    "Search in mailbox" : "Preišči poštni predal",
+    "Clear" : "Počisti",
     "Close" : "Zapri",
     "Search parameters" : "Poišči parametre",
     "Body" : "Besedilo",
@@ -367,49 +370,49 @@ OC.L10N.register(
     "Marked as" : "Označeno kot",
     "Has attachments" : "Vsebuje prilogo",
     "Last 7 days" : "Zadnjih 7 dni",
-    "Clear" : "Počisti",
     "Sieve Port" : "Vrata Sieve",
     "Custom" : "Po meri",
     "Sieve User" : "Uporabnik Sieve",
     "Sieve Password" : "Geslo Sieve",
     "Save sieve settings" : "Shrani nastavitve sieve",
-    "Save sieve script" : "Shrani skript sieve",
     "The syntax seems to be incorrect:" : "Skladnja je videti nepravilna:",
+    "Save sieve script" : "Shrani skript sieve",
     "Signature …" : "Podpis ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Nastavljen podpis je večji od 2 MB. Velikost lahko vpliva na delovanje urejevalnika.",
     "Save signature" : "Shrani podpis",
     "Place signature above quoted text" : "Postavi podpis nad navedeno besedilo.",
+    "Message source" : "Vir sporočila",
+    "An error occurred, unable to rename the tag." : "Prišlo je do napake, oznake ni mogoče preimenovati.",
     "Saving new tag name …" : "Poteka shranjevanje imena oznake ...",
     "Delete tag" : "Izbriši oznako",
     "Set tag" : "Nastavi oznako",
     "Unset tag" : "Odstrani oznako",
-    "An error occurred, unable to rename the tag." : "Prišlo je do napake, oznake ni mogoče preimenovati.",
-    "Add default tags" : "Dodaj privzete oznake",
-    "Add tag" : "Dodaj oznako",
-    "Saving tag …" : "Poteka shranjevanje ozake ...",
     "Tag name is a hidden system tag" : "Ime oznake je skrita sistemska oznaka",
     "Tag already exists" : "Oznaka že obstaja",
     "An error occurred, unable to create the tag." : "Prišlo je do napake, oznake ni mogoče ustvariti.",
-    "No calendars with task list support" : "Koledar s podporo seznama nalog",
+    "Add default tags" : "Dodaj privzete oznake",
+    "Add tag" : "Dodaj oznako",
+    "Saving tag …" : "Poteka shranjevanje ozake ...",
     "Task created" : "Naloga je ustvarjena",
     "Could not create task" : "Naloge ni mogoče ustvariti",
-    "Loading thread" : "Poteka nalaganje niti",
-    "Not found" : "Ni mogoče najti",
+    "No calendars with task list support" : "Koledar s podporo seznama nalog",
     "Could not load your message thread" : "Ni mogoče naložiti niti sporočil",
     "The thread doesn't exist or has been deleted" : "Nit ne obstaja ali pa je bila izbrisana",
-    "Unsubscribe" : "Prekliči naročnino",
+    "Loading thread" : "Poteka nalaganje niti",
+    "Not found" : "Predmeta ni mogoče najti",
+    "Encrypted & verified " : "Šifrirano in overjeno",
+    "Signature verified" : "Podpis je overjen",
+    "Signature unverified " : "Podpis ni overjen",
     "Reply all" : "Odgovori vsem",
+    "Unsubscribe" : "Prekliči naročnino",
     "Reply to sender only" : "Odgovori le pošiljatelju",
     "Mark as unfavorite" : "Odstrani oznako priljubljeno",
     "Mark as favorite" : "Označi kot priljubljeno",
     "Mark as unread" : "Označi kot neprebrano",
     "Mark as read" : "Označi kot prebrano",
-    "Archive message" : "Arhiviraj sporočilo",
-    "Delete message" : "Izbriši sporočilo",
-    "Message source" : "Vir sporočila",
-    "Encrypted & verified " : "Šifrirano in overjeno",
-    "Signature verified" : "Podpis je overjen",
-    "Signature unverified " : "Podpis ni overjen",
+    "The message could not be translated" : "Sporočila ni mogoče prevesti",
+    "Translation copied to clipboard" : "Prevod je kopiran v odložišče",
+    "Translation could not be copied" : "Prevoda ni mogoče kopirati!",
     "Translate message" : "Prevedi sporočilo",
     "Source language to translate from" : "Izvorni jezik za prevod",
     "Translate from" : "Prevedi iz",
@@ -417,26 +420,33 @@ OC.L10N.register(
     "Translate to" : "Prevedi v",
     "Translating" : "Poteka prevajanje",
     "Copy translated text" : "Kopiraj prevedeno besedilo",
-    "The message could not be translated" : "Sporočila ni mogoče prevesti",
-    "Translation copied to clipboard" : "Prevod je kopiran v odložišče",
-    "Translation could not be copied" : "Prevoda ni mogoče kopirati!",
-    "No senders are trusted at the moment." : "Ni še zavedenih zaupanja vrednih pošiljateljev.",
     "Could not remove trusted sender {sender}" : "Ni mogoče odstraniti zanesljivega pošiljatelja {sender}",
-    "(organizer)" : " (skliče dogodek)",
+    "No senders are trusted at the moment." : "Ni še zavedenih zaupanja vrednih pošiljateljev.",
     "Untitled event" : "Neimenovan dogodek",
+    "(organizer)" : " (skliče dogodek)",
     "Import into {calendar}" : "Uvozi v koledar {calendar}",
     "Event imported into {calendar}" : "Dogodek je uvožen v koledar {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} iz {depAirport} na letališče {arrAirport}",
     "Airplane" : "Letalo",
     "Reservation {id}" : "Rezervacija {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} iz {depAirport} na letališče {arrAirport}",
-    "Train" : "Vlak",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} v {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} v {arrStation}",
+    "Train" : "Vlak",
     "Flag" : "Zastavica",
+    "Recipient" : "Prejemnik",
     "Delete filter" : "Izbriši filter",
     "Operator" : "Operator",
-    "Actions" : "Dejanja",
+    "contains" : "vsebuje",
+    "matches" : "se sklada z",
     "Priority" : "Prednost",
+    "Successfully updated config for \"{domain}\"" : "Nastavitve za domeno »{domain}« so uspešno posodobljene.",
+    "Error saving config" : "Napaka shranjevanja nastavitev",
+    "Saved config for \"{domain}\"" : "Nastavitve za domeno »{domain}« so shranjene.",
+    "Could not save provisioning setting" : "Ni mogoče shraniti nastavitev povezovanja",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Uspešno je zaključeno povezovanje {count} računa.","Uspešno je zaključeno povezovanje {count} računov.","Uspešno je zaključeno povezovanje {count} računov.","Uspešno je zaključeno povezovanje {count} računov."],
+    "There was an error when provisioning accounts." : "Prišlo je do napake med povezovanjem računov.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Brisanje in odstranjevanje povezovanja računov za »{domain}« je uspešno končano.",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Napaka pri brisanju in odstranjevanju povezovanja računov za »{domain}«",
     "Mail app" : "Program Pošta",
     "The mail app allows users to read mails on their IMAP accounts." : "Program Mail omogoča uporabnikom branje sporočil z računov IMAP.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Na tem mestu so zbrane nastavitve celotnega okolja. Uporabniške nastavitve so v posameznem programu (spodnji levi kot).",
@@ -453,14 +463,6 @@ OC.L10N.register(
     "Anti Spam Service" : "Storitve proti neželeni pošti",
     "You can set up an anti spam service email address here." : "Določiti je mogoče elektronski naslov za storitve neželenih sporočil.",
     "Gmail integration" : "Združevalnik Gmail",
-    "Successfully updated config for \"{domain}\"" : "Nastavitve za domeno »{domain}« so uspešno posodobljene.",
-    "Error saving config" : "Napaka shranjevanja nastavitev",
-    "Saved config for \"{domain}\"" : "Nastavitve za domeno »{domain}« so shranjene.",
-    "Could not save provisioning setting" : "Ni mogoče shraniti nastavitev povezovanja",
-    "There was an error when provisioning accounts." : "Prišlo je do napake med povezovanjem računov.",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Brisanje in odstranjevanje povezovanja računov za »{domain}« je uspešno končano.",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Napaka pri brisanju in odstranjevanju povezovanja računov za »{domain}«",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Uspešno je zaključeno povezovanje {count} računa.","Uspešno je zaključeno povezovanje {count} računov.","Uspešno je zaključeno povezovanje {count} računov.","Uspešno je zaključeno povezovanje {count} računov."],
     "Anti Spam" : "Anti Spam",
     "\"Mark as Spam\" Email Address" : "Označi sporočila z elektronskega naslova kot »Neželena sporočila«",
     "\"Mark Not Junk\" Email Address" : "Označi sporočila z elektronskega naslova kot »Niso neželena sporočila«",
@@ -488,6 +490,7 @@ OC.L10N.register(
     "Save Config" : "Shrani nastavitve",
     "Unprovision & Delete Config" : "Odstrani povezavo in izbriši nastavitve",
     "With the settings above, the app will create account settings in the following way:" : "Z zgornjo nastavitvijo bo ustvarjen račun s podatki:",
+    "Failed to import the certificate" : "Uvažanje potrdila je spodletelo",
     "S/MIME certificates" : "Potrdila S/MIME",
     "Certificate name" : "Ime potrdila",
     "E-mail address" : "Naslov elektronske pošte",
@@ -501,13 +504,12 @@ OC.L10N.register(
     "Certificate" : "Potrdilo",
     "Private key (optional)" : "Zasebni ključ (izbirno)",
     "Submit" : "Pošlji",
-    "Failed to import the certificate" : "Uvažanje potrdila je spodletelo",
+    "Group" : "Skupina",
+    "Shared" : "V souporabi",
+    "Shares" : "V souporabi",
+    "Insert" : "Vstavi",
     "Account connected" : "Račun je povezan",
     "Connect your mail account" : "Povežite svoj elektronski račun",
-    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
-    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
-    "Later today – {timeLocale}" : "Danes – {timeLocale}",
     "All" : "Vse",
     "Drafts" : "Osnutki",
     "Favorites" : "Priljubljene",
@@ -539,6 +541,27 @@ OC.L10N.register(
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi do %s",
     "Continue to %s" : "Nadaljuj na %s",
-    "Unselect" : "Odstrani izbor"
+    "Mailbox search" : "Iskanje po poštnem predalu",
+    "No messages in this mailbox" : "V poštnem predalu ni sporočil.",
+    "No trash mailbox configured" : "Ni nastavljenega poštne mape za smeti",
+    "Draft: " : "Osnutek:",
+    "Could not open mailbox" : "Ni mogoče odpreti poštnega predala",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Poteka ustvarjanje kazala sporočil. Opravilo je lahko dolgotrajno pri velikih poštnih predalih.",
+    "Choose target mailbox" : "Izbor ciljnega poštnega predala",
+    "Show only subscribed mailboxes" : "Pokaži le naročene poštne predale",
+    "Add mailbox" : "Dodaj poštni predal",
+    "Show all subscribed mailboxes" : "Pokaži vse naročene poštne predale",
+    "Show all mailboxes" : "Pokaži vse poštne predale",
+    "Collapse mailboxes" : "Skrči poštne predale",
+    "Clear mailbox" : "Počisti poštni predal",
+    "The mailbox and all messages in it will be deleted." : "Poštni predal in vsa vključena sporočila bodo izbrisana.",
+    "Delete mailbox" : "Izbriši poštni predal",
+    "Delete mailbox {name}" : "Izbriši poštni predal {name}",
+    "Mark all messages of this mailbox as read" : "Označi vsa sporočila v tej mapi kot prebrana",
+    "Add submailbox" : "Dodaj podrejeni poštni predal",
+    "Move mailbox" : "Premakni poštni predal",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ni določenega predala za pošiljanje. Izberite ga med nastavitvami računa.",
+    "Search in mailbox" : "Preišči poštni predal",
+    "Actions" : "Dejanja"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
