@@ -6,6 +6,10 @@ OC.L10N.register(
     "Personal" : "Personale",
     "Later" : "Më vonë",
     "Mail" : "Posta",
+    "Connecting" : "Duke u lidhur",
+    "Save" : "Ruaj",
+    "Connect" : "Lidhu",
+    "Password required" : "Kërkohet fjalëkalimi",
     "Name" : "Emri",
     "Mail address" : "Adresa e postës elektronike",
     "Password" : "Fjalëkalimi",
@@ -20,10 +24,6 @@ OC.L10N.register(
     "SMTP Port" : "Porta SMTP",
     "SMTP User" : "Përdoruesi i SMTP",
     "SMTP Password" : "Fjalëkalimi SMTP",
-    "Connecting" : "Duke u lidhur",
-    "Save" : "Ruaj",
-    "Connect" : "Lidhu",
-    "Password required" : "Kërkohet fjalëkalimi",
     "Aliases" : "Emërtimet",
     "Signature" : "Nënshkrimi",
     "Go back" : "Shko prapa",
@@ -32,6 +32,7 @@ OC.L10N.register(
     "Add mail account" : "Shto llogarinë e postës elektronike",
     "General" : "Të përgjithshme",
     "Register" : "Regjistrohu",
+    "About" : "Rreth",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Newer message" : "Mesazhe më të reja",
     "Older message" : "Mesazhe më të vjetra",
@@ -42,12 +43,13 @@ OC.L10N.register(
     "Search" : "Kërko",
     "Send" : "Dërgo",
     "Refresh" : "Rifresko",
+    "Ok" : "Në rregull",
     "Select account" : "Përzgjidhni llogari",
     "Subject" : "Temë",
     "Upload attachment" : "Ngarko bashkëngjitje",
     "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
-    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
     "Choose" : "Zgjidhni",
+    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
     "Confirm" : "Konfirmo",
     "Unfavorite" : "Jo i/e preferuar",
     "Favorite" : "I/E Preferuar",
@@ -64,42 +66,46 @@ OC.L10N.register(
     "Decline" : "Refuzo",
     "Remove" : "Hiq",
     "email" : "postë elektronike",
+    "Today" : "Sot",
     "Other" : "Tjetër",
     "Forward" : "Përpara",
     "Translate" : "Përkthe",
+    "Unnamed" : "E paemër",
     "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
     "Import into calendar" : "Importo në kalendar",
     "Download attachment" : "Shkarko bashkëlidhjen",
     "Save to Files" : "Ruaje te Skedarët",
-    "Unnamed" : "E paemër",
     "Save all to Files" : "Ruaji të gjitha te Dosjet",
     "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
     "Move" : "Zhvendos",
-    "Quota" : "Kuotë",
-    "Saving" : "Duke u ruajtur!",
     "Remove account" : "Fshij llogarinë",
+    "Folder name" : "Emër dosjeje",
+    "Saving" : "Duke u ruajtur!",
+    "Show all folders" : "Shfaqi krejt dosjet",
+    "Collapse folders" : "Tkurri dosjet",
+    "Delete folder" : "Fshije dosjen",
     "Mark all as read" : "Shënoji krejt si të lexuar",
     "Rename" : "Riemërtoje",
     "Clear cache" : "Pastroje fshehtinën",
     "New message" : "Mesazh i ri",
-    "Retry" : "Riprovoni",
-    "Sending …" : "Po dërgohet …",
     "Reply" : "Përgjigju",
+    "Retry" : "Riprovoni",
     "Message" : "Mesazh",
     "Copy to clipboard" : "Kopjo në dërrasë ",
     "Add" : "Shto",
+    "Clear" : "Pastro",
     "Close" : "Mbylleni",
     "Date" : "Data",
     "Tags" : "Etiketat",
     "Select tags" : "Përzgjidh etiketat",
-    "Clear" : "Pastro",
     "Custom" : "E përshtatur",
     "Delete tag" : "Fshi etiketën",
-    "Add tag" : "Shto etiketim",
     "Tag already exists" : "Etiketa ekziston",
+    "Add tag" : "Shto etiketim",
     "Mark as unread" : "Shënoje si të palexuar",
     "Mark as read" : "Shënoje si të lexuar",
-    "Actions" : "Veprimet",
+    "Recipient" : "Marrës",
+    "matches" : "përputhje",
     "Priority" : "Përparësi",
     "Reset" : "Rivendos",
     "Client ID" : "ID klienti",
@@ -110,6 +116,9 @@ OC.L10N.register(
     "Valid until" : "E vlefshme deri më",
     "Certificate" : "Çertifikata",
     "Submit" : "Dërgo",
+    "Group" : "Grup",
+    "Shared" : "Ndarë",
+    "Shares" : "Shpërndarje",
     "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
     "Drafts" : "Skica",
@@ -128,6 +137,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
     "Redirect" : "Ridrejtoje",
     "The link leads to %s" : "Lidhja shpie te %s",
-    "Continue to %s" : "Vazhdo te %s"
+    "Continue to %s" : "Vazhdo te %s",
+    "Actions" : "Veprimet"
 },
 "nplurals=2; plural=(n != 1);");
