@@ -17,6 +17,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "Pošalji",
     "Refresh" : "Osveži",
+    "Ok" : "Ok",
     "Select account" : "Označite nalog",
     "Choose" : "Odaberi",
     "Favorite" : "Omiljene",
@@ -27,12 +28,16 @@ OC.L10N.register(
     "Select" : "Obeleži",
     "Comment" : "Komentar",
     "Remove" : "Ukloni",
+    "Today" : "Danas",
+    "Yesterday" : "јуче",
+    "Last month" : "Prošlog meseca",
     "Other" : "Ostali",
     "Forward" : "Prosledi",
     "Translate" : "Prevedi",
     "Move" : "Premesti",
-    "Loading …" : "Učitavanje...",
     "Remove account" : "Ukloni nalog",
+    "Folder name" : "Naziv fascikle",
+    "Loading …" : "Učitavanje...",
     "Mark all as read" : "Označi sve kao pročitano",
     "Rename" : "Preimenuj",
     "Clear cache" : "Očisti keš",
@@ -43,8 +48,10 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Oznake",
     "Not found" : "Nije nađeno",
-    "User" : "User",
+    "User" : "Korisnik",
+    "Shared" : "Deljeno",
     "All" : "Sve",
-    "Favorites" : "Omiljene"
+    "Favorites" : "Omiljene",
+    "Continue to %s" : "Nastavi na %s"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
