@@ -29,6 +29,7 @@ OC.L10N.register(
     "Search" : "ค้นหา",
     "Send" : "ส่ง",
     "Refresh" : "รีเฟรช",
+    "Ok" : "ตกลง",
     "Choose" : "เลือก",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
     "Confirm" : "ยืนยัน",
@@ -43,6 +44,10 @@ OC.L10N.register(
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
     "Remove" : "ลบออก",
+    "Today" : "วันนี้",
+    "Yesterday" : "เมื่อวาน",
+    "Last week" : "สัปดาห์ที่แล้ว",
+    "Last month" : "เดือนที่แล้ว",
     "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
     "Other" : "อื่น ๆ",
     "Forward" : "ส่งต่อ",
@@ -55,6 +60,7 @@ OC.L10N.register(
     "Folder name" : "ชื่อโฟลเดอร์",
     "Saving" : "กำลังบันทึก",
     "Show all folders" : "แสดงโฟลเดอร์ทั้งหมด",
+    "Collapse folders" : "ยุบโฟลเดอร์",
     "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
     "Rename" : "เปลี่ยนชื่อ",
     "Clear cache" : "ล้างแคช",
@@ -79,6 +85,9 @@ OC.L10N.register(
     "Valid until" : "ใช้ได้จนถึง",
     "Certificate" : "ใบรับรอง",
     "Submit" : "ส่ง",
+    "Group" : "กลุ่ม",
+    "Shared" : "ถูกแชร์",
+    "Shares" : "การแชร์",
     "Account connected" : "เชื่อมต่อบัญชีแล้ว",
     "All" : "ทั้งหมด",
     "Drafts" : "ฉบับร่าง",
