@@ -134,6 +134,7 @@ OC.L10N.register(
     "Mailto" : "Mailto",
     "Register as application for mail links" : "خەت ئۇلانمىسىغا ئىلتىماس قىلىڭ",
     "Register" : "تىزىملىتىڭ",
+    "Shared with me" : "مەن بىلەن ئورتاقلاشتى",
     "Privacy and security" : "مەخپىيەتلىك ۋە بىخەتەرلىك",
     "Data collection consent" : "ئۇچۇر توپلاش ئىجازەتنامىسى",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "بۇ دېتالنىڭ ئۆز-ئارا تەسىرلىشىڭىزگە مۇناسىۋەتلىك ئۇچۇرلارنى توپلىشىغا يول قويۇڭ. بۇ سانلىق مەلۇماتلارغا ئاساسەن ، ئەپ سىزنىڭ مايىللىقىڭىزغا ماسلىشىدۇ. بۇ سانلىق مەلۇماتلار پەقەت يەرلىكتە ساقلىنىدۇ.",
@@ -159,6 +160,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "يوللا",
     "Refresh" : "يېڭىلا",
+    "Ok" : "جەزملە",
     "No certificate" : "گۇۋاھنامە يوق",
     "Certificate updated" : "گۇۋاھنامە يېڭىلاندى",
     "Could not update certificate" : "گۇۋاھنامىنى يېڭىلىيالمىدى",
@@ -303,6 +305,11 @@ OC.L10N.register(
     "Add internal email or domain" : "ئىچكى ئېلېكترونلۇق خەت ياكى دائىرە قوشۇڭ",
     "Itinerary for {type} is not supported yet" : "{type} نىڭ لىنىيىسى تېخىچە قوللىمايدۇ",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "بۇ ئۇچۇرنى ئارخىپ قىسقۇچقا يۆتكەش ۋە / ياكى بۇ ھۆججەتنى نۆۋەتتىكى ھۆججەت قىسقۇچتىن ئۆچۈرۈشكە بولمايدۇ",
+    "Last hour" : "ئالدىنقى سائەت",
+    "Today" : "بۈگۈن",
+    "Yesterday" : "تۈنۈگۈن",
+    "Last week" : "ئالدىنقى ھەپتە",
+    "Last month" : "ئالدىنقى ئاي",
     "Loading messages …" : "ئۇچۇرلارنى يۈكلەۋاتىدۇ…",
     "Choose target folder" : "نىشان ھۆججەت قىسقۇچىنى تاللاڭ",
     "No more submailboxes in here" : "بۇ يەردە باشقا خەت ساندۇقى يوق",
@@ -676,6 +683,11 @@ OC.L10N.register(
     "Private key (optional)" : "شەخسىي ئاچقۇچ (ئىختىيارى)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "ئەگەر بۇ گۇۋاھنامە ئارقىلىق ئىمزا قويۇلغان ۋە مەخپىيلەشتۈرۈلگەن ئېلېكترونلۇق خەت ئەۋەتمەكچى بولسىڭىز ، شەخسىي ئاچقۇچ تەلەپ قىلىنىدۇ.",
     "Submit" : "يوللاڭ",
+    "Guest" : "مېھمان",
+    "Group" : "گۇرۇپپا",
+    "Shared" : "ئورتاقلاشتى",
+    "Shares" : "Shares",
+    "Insert" : "قىستۇر",
     "Account connected" : "ھېسابات ئۇلاندى",
     "You can close this window" : "بۇ كۆزنەكنى ياپالايسىز",
     "Connect your mail account" : "خەت ساندۇقىڭىزنى ئۇلاڭ",
