@@ -69,6 +69,7 @@ OC.L10N.register(
     "Search" : "Tìm",
     "Send" : "Gởi",
     "Refresh" : "Làm mới",
+    "Ok" : "Đồng ý",
     "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
     "From" : "Từ",
     "Select account" : "Chọn tài khoản",
@@ -88,19 +89,17 @@ OC.L10N.register(
     "Encrypt message with Mailvelope" : "Mã hóa thư bằng Mailvelope",
     "Enter a date" : "Nhập ngày",
     "Choose" : "Chọn",
+    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Các tệp đính kèm vượt quá kích thước được cho phép là {size}. Thay vào đó, hãy chia sẻ các tệp qua liên kết."],
     "Choose a file to add as attachment" : "Chọn một tệp để thêm dưới dạng tệp đính kèm",
     "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
     "Confirm" : "Xác nhận",
-    "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
     "No messages" : "Không có tin nhắn",
     "Blind copy recipients only" : "Chỉ người nhận bản sao ẩn",
     "Later today – {timeLocale}" : "Sau này - {timeLocale}",
     "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
     "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
     "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
-    "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
     "Could not delete message" : "Không thể xóa tin nhắn",
-    "Draft: " : "Bản nháp: ",
     "Favorite" : "Ưa thích",
     "Read" : "Đọc",
     "Mark not spam" : "Đánh dấu không phải là thư rác",
@@ -131,9 +130,11 @@ OC.L10N.register(
     "Remove" : "Xóa",
     "email" : "Thư điện tử",
     "Itinerary for {type} is not supported yet" : "Hành trình cho {type} chưa được hỗ trợ",
-    "Could not open mailbox" : "Không thể mở hộp thư",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
-    "Choose target mailbox" : "Chọn hộp thư mục tiêu",
+    "Today" : "Hôm nay",
+    "Yesterday" : "Hôm qua",
+    "Last week" : "Tuần trước",
+    "Last month" : "Tháng trước",
+    "Choose target folder" : "Chọn thư mục đích",
     "No more submailboxes in here" : "Không còn hộp thư con nào ở đây",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Tin nhắn sẽ tự động được đánh dấu là quan trọng dựa trên những tin nhắn bạn đã tương tác hoặc được đánh dấu là quan trọng. Lúc đầu, bạn có thể phải thay đổi thủ công tầm quan trọng để dạy hệ thống, nhưng nó sẽ cải thiện theo thời gian.",
     "Important info" : "Thông tin quan trọng",
@@ -165,30 +166,19 @@ OC.L10N.register(
     "Quoted text" : "Văn bản được trích dẫn",
     "Move" : "Dịch chuyển",
     "Moving" : "Di chuyển",
-    "Loading …" : "Đang tải...",
-    "Not supported by the server" : "Không được máy chủ hỗ trợ",
-    "{usage} of {limit} used" : "Đã sử dụng {use} trong tổng số {limit}",
     "Remove account" : "Xóa tài khoản",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tài khoản cho {email} và dữ liệu email đã lưu trong bộ nhớ cache sẽ bị xóa khỏi vWorkspace, nhưng không bị xóa khỏi nhà cung cấp dịch vụ email của bạn.",
     "Remove {email}" : "Xóa {email}",
-    "Quota" : "Hạn ngạch",
-    "Show only subscribed mailboxes" : "Chỉ hiển thị các hộp thư đã đăng ký",
-    "Add mailbox" : "Thêm hộp thư",
+    "Folder name" : "Tên thư mục",
     "Saving" : "Tiết kiệm",
     "Move up" : "Di chuyển lên",
     "Move down" : "Di chuyển xuống",
-    "Show all subscribed mailboxes" : "Hiển thị tất cả các hộp thư đã đăng ký",
-    "Show all mailboxes" : "Hiển thị tất cả các hộp thư",
-    "Collapse mailboxes" : "Thu gọn hộp thư",
     "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} thư chưa đọc trong tổng số {total} thư"],
-    "The mailbox and all messages in it will be deleted." : "Hộp thư và tất cả thư trong đó sẽ bị xóa.",
-    "Delete mailbox" : "Xóa hộp thư",
-    "Delete mailbox {name}" : "Xóa hộp thư {name}",
+    "Loading …" : "Đang tải...",
+    "Delete folder" : "Xoá thư mục",
     "An error occurred, unable to rename the mailbox." : "Đã xảy ra lỗi, không thể đổi tên hộp thư.",
     "Mark all as read" : "Đánh dấu tất cả như đã ",
-    "Mark all messages of this mailbox as read" : "Đánh dấu tất cả các thư của hộp thư này là đã đọc",
-    "Add submailbox" : "Thêm hộp thư con",
     "Rename" : "Đổi tên",
     "Clear cache" : "Xóa bộ nhớ ",
     "Clear locally cached data, in case there are issues with synchronization." : "Xóa dữ liệu được lưu trong bộ nhớ cache cục bộ, trong trường hợp có sự cố với đồng bộ hóa.",
@@ -196,11 +186,8 @@ OC.L10N.register(
     "Sync in background" : "Đồng bộ trong nền",
     "New message" : "Tin nhắn mới",
     "Reply" : "Trả lời",
-    "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
     "Error sending your message" : "Lỗi khi gửi tin nhắn",
     "Retry" : "Thử lại",
-    "Uploading attachments …" : "Đang tải lên các tệp đính kèm …",
-    "Sending …" : "Đang gửi …",
     "Contacts with this address" : "Liên hệ với địa chỉ này",
     "Add to Contact" : "Thêm liên hệ",
     "New Contact" : "ĐỊa chỉ liên hệ mới",
@@ -222,6 +209,7 @@ OC.L10N.register(
     "Save sieve script" : "Lưu sieve script",
     "Signature …" : "Chữ ký …",
     "Save signature" : "Lưu chữ ký",
+    "Message source" : "Nguồn tin nhắn",
     "Tag already exists" : "Thẻ đã tồn tại",
     "Add tag" : "Thêm nhãn",
     "Could not load your message thread" : "Không thể tải chuỗi tin nhắn của bạn",
@@ -229,7 +217,6 @@ OC.L10N.register(
     "Reply to sender only" : "Chỉ trả lời người gửi",
     "Mark as unread" : "Đánh dấu là chưa đọc",
     "Mark as read" : "Đánh dấu đã đọc",
-    "Message source" : "Nguồn tin nhắn",
     "Could not remove trusted sender {sender}" : "Không thể xóa người gửi đáng tin cậy {sender}",
     "No senders are trusted at the moment." : "Không có người gửi nào được tin cậy vào lúc này.",
     "Untitled event" : "Sự kiện không tiêu đề",
@@ -242,8 +229,10 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} từ {depStation} đến {arrStation}",
     "Train from {depStation} to {arrStation}" : "Đi tàu từ {depStation} đến {arrStation}",
     "Train" : "Tàu hỏa",
+    "Recipient" : "Người nhận",
     "Delete filter" : "Xóa bộ lọc ",
-    "Actions" : "Hành động",
+    "contains" : "chứa",
+    "matches" : "so sánh",
     "Mail app" : "Ứng dụng thư",
     "The mail app allows users to read mails on their IMAP accounts." : "Ứng dụng thư cho phép người dùng đọc thư trên tài khoản IMAP của họ.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Tại đây bạn có thể tìm thấy các cài đặt cho toàn phiên bản. Cài đặt người dùng cụ thể được tìm thấy trong chính ứng dụng (góc dưới bên trái).",
@@ -261,7 +250,10 @@ OC.L10N.register(
     "E-mail address" : "Địa chỉ email",
     "Valid until" : "Có hiệu lực đến",
     "Certificate" : "Chứng chỉ",
-    "Submit" : "Gửi đi",
+    "Submit" : "Gửi",
+    "Group" : "Nhóm",
+    "Shared" : "Đã chia sẻ",
+    "Shares" : "Chia sẻ",
     "Account connected" : "Tài khoản đã được kết nối",
     "Connect your mail account" : "Kết nối tài khoản thư của bạn",
     "All" : "Tất cả",
@@ -288,6 +280,24 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Nhấp vào đây nếu bạn không được chuyển hướng tự động trong vòng vài giây tới",
     "Redirect" : "Chuyển hướng",
     "The link leads to %s" : "Liên kết dẫn đến %s",
-    "Continue to %s" : "Tiếp tục %s"
+    "Continue to %s" : "Tiếp tục %s",
+    "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
+    "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
+    "Draft: " : "Bản nháp: ",
+    "Could not open mailbox" : "Không thể mở hộp thư",
+    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
+    "Choose target mailbox" : "Chọn hộp thư mục tiêu",
+    "Show only subscribed mailboxes" : "Chỉ hiển thị các hộp thư đã đăng ký",
+    "Add mailbox" : "Thêm hộp thư",
+    "Show all subscribed mailboxes" : "Hiển thị tất cả các hộp thư đã đăng ký",
+    "Show all mailboxes" : "Hiển thị tất cả các hộp thư",
+    "Collapse mailboxes" : "Thu gọn hộp thư",
+    "The mailbox and all messages in it will be deleted." : "Hộp thư và tất cả thư trong đó sẽ bị xóa.",
+    "Delete mailbox" : "Xóa hộp thư",
+    "Delete mailbox {name}" : "Xóa hộp thư {name}",
+    "Mark all messages of this mailbox as read" : "Đánh dấu tất cả các thư của hộp thư này là đã đọc",
+    "Add submailbox" : "Thêm hộp thư con",
+    "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
+    "Actions" : "Hành động"
 },
 "nplurals=1; plural=0;");
