@@ -151,9 +151,16 @@ class MessageApiController extends OCSController {
 		$message->setType(LocalMessage::TYPE_OUTGOING);
 		$message->setAccountId($accountId);
 		$message->setSubject($subject);
-		$message->setBody($body);
+		if ($isHtml) {
+			$message->setBodyPlain(null);
+			$message->setBodyHtml($body);
+			$message->setHtml(true);
+		} else {
+			$message->setBodyPlain($body);
+			$message->setBodyHtml(null);
+			$message->setHtml(false);
+		}
 		$message->setEditorBody($body);
-		$message->setHtml($isHtml);
 		$message->setSendAt($this->time->getTime());
 		$message->setType(LocalMessage::TYPE_OUTGOING);
 
@@ -168,7 +175,7 @@ class MessageApiController extends OCSController {
 		}
 
 		$recipients = array_merge($to, $cc, $bcc);
-		foreach($recipients	as $recipient) {
+		foreach ($recipients as $recipient) {
 			if (!is_array($recipient)) {
 				return new DataResponse('Recipient address must be an array.', Http::STATUS_BAD_REQUEST);
 			}
@@ -292,7 +299,7 @@ class MessageApiController extends OCSController {
 
 		$json['rawUrl'] = $this->urlGenerator->linkToOCSRouteAbsolute('mail.messageApi.getRaw', ['id' => $id]);
 
-		if(!$loadBody) {
+		if (!$loadBody) {
 			return new DataResponse($json, Http::STATUS_PARTIAL_CONTENT);
 		}
 
@@ -427,7 +434,7 @@ class MessageApiController extends OCSController {
 	private function handleAttachments(): array {
 		$fileAttachments = $this->request->getUploadedFile('attachments');
 		$hasAttachments = isset($fileAttachments['name']);
-		if(!$hasAttachments) {
+		if (!$hasAttachments) {
 			return [];
 		}
 
