@@ -3,30 +3,9 @@
 declare(strict_types=1);
 
 /**
- * @author Alexander Weidinger <alexwegoo@gmail.com>
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @author Christoph Wurst <wurst.christoph@gmail.com>
- * @author Jakob Sack <jakob@owncloud.org>
- * @author Jan-Christoph Borchardt <hey@jancborchardt.net>
- * @author Lukas Reschke <lukas@owncloud.com>
- * @author Thomas Imbreckx <zinks@iozero.be>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Richard Steinmetz <richard@steinmetz.cloud>
- *
- * Mail
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2014-2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 namespace OCA\Mail\Controller;
@@ -49,12 +28,14 @@ use OCA\Mail\Http\TrapError;
 use OCA\Mail\IMAP\IMAPClientFactory;
 use OCA\Mail\Model\SmimeData;
 use OCA\Mail\Service\AccountService;
+use OCA\Mail\Service\AiIntegrations\AiIntegrationsService;
 use OCA\Mail\Service\ItineraryService;
 use OCA\Mail\Service\SmimeService;
 use OCA\Mail\Service\SnoozeService;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\ContentSecurityPolicy;
 use OCP\AppFramework\Http\JSONResponse;
 use OCP\AppFramework\Http\Response;
@@ -71,6 +52,7 @@ use OCP\Lock\LockedException;
 use Psr\Log\LoggerInterface;
 use function array_map;
 
+#[OpenAPI(scope: OpenAPI::SCOPE_IGNORE)]
 class MessagesController extends Controller {
 	private AccountService $accountService;
 	private IMailManager $mailManager;
@@ -90,6 +72,7 @@ class MessagesController extends Controller {
 	private IDkimService $dkimService;
 	private IUserPreferences $preferences;
 	private SnoozeService $snoozeService;
+	private AiIntegrationsService $aiIntegrationService;
 
 	public function __construct(string $appName,
 		IRequest $request,
@@ -110,7 +93,8 @@ class MessagesController extends Controller {
 		IMAPClientFactory $clientFactory,
 		IDkimService $dkimService,
 		IUserPreferences $preferences,
-		SnoozeService $snoozeService) {
+		SnoozeService $snoozeService,
+		AiIntegrationsService $aiIntegrationService) {
 		parent::__construct($appName, $request);
 		$this->accountService = $accountService;
 		$this->mailManager = $mailManager;
@@ -130,6 +114,7 @@ class MessagesController extends Controller {
 		$this->dkimService = $dkimService;
 		$this->preferences = $preferences;
 		$this->snoozeService = $snoozeService;
+		$this->aiIntegrationService = $aiIntegrationService;
 	}
 
 	/**
@@ -139,6 +124,8 @@ class MessagesController extends Controller {
 	 * @param int $cursor
 	 * @param string $filter
 	 * @param int|null $limit
+	 * @param string $view returns messages in requested view ('singleton' or 'threaded')
+	 * @param string|null $v Cache buster version to guarantee unique urls (will trigger HTTP caching if set)
 	 *
 	 * @return JSONResponse
 	 *
@@ -147,9 +134,11 @@ class MessagesController extends Controller {
 	 */
 	#[TrapError]
 	public function index(int $mailboxId,
-		int $cursor = null,
-		string $filter = null,
-		int $limit = null): JSONResponse {
+		?int $cursor = null,
+		?string $filter = null,
+		?int $limit = null,
+		?string $view = null,
+		?string $v = null): JSONResponse {
 		try {
 			$mailbox = $this->mailManager->getMailbox($this->currentUserId, $mailboxId);
 			$account = $this->accountService->find($this->currentUserId, $mailbox->getAccountId());
@@ -158,18 +147,26 @@ class MessagesController extends Controller {
 		}
 
 		$this->logger->debug("loading messages of mailbox <$mailboxId>");
+		$sort = $this->preferences->getPreference($this->currentUserId, 'sort-order', 'newest') === 'newest' ? IMailSearch::ORDER_NEWEST_FIRST : IMailSearch::ORDER_OLDEST_FIRST;
 
-		$order = $this->preferences->getPreference($this->currentUserId, 'sort-order', 'newest') === 'newest' ? 'DESC': 'ASC';
-		return new JSONResponse(
-			$this->mailSearch->findMessages(
-				$account,
-				$mailbox,
-				$order,
-				$filter === '' ? null : $filter,
-				$cursor,
-				$limit
-			)
+		$view = $view === 'singleton' ? IMailSearch::VIEW_SINGLETON : IMailSearch::VIEW_THREADED;
+
+		$messages = $this->mailSearch->findMessages(
+			$account,
+			$mailbox,
+			$sort,
+			$filter === '' ? null : $filter,
+			$cursor,
+			$limit,
+			$this->currentUserId,
+			$view
 		);
+
+		$response = new JSONResponse($messages);
+		if ($v !== null && $v !== '') {
+			$response->cacheFor(7 * 24 * 3600, false, true);
+		}
+		return $response;
 	}
 
 	/**
@@ -591,9 +588,9 @@ class MessagesController extends Controller {
 				$client->logout();
 			}
 
-			$htmlResponse = $plain ?
-				HtmlResponse::plain($html) :
-				HtmlResponse::withResizer(
+			$htmlResponse = $plain
+				? HtmlResponse::plain($html)
+				: HtmlResponse::withResizer(
 					$html,
 					$this->nonceManager->getNonce(),
 					$this->urlGenerator->getAbsoluteURL(
@@ -697,7 +694,7 @@ class MessagesController extends Controller {
 
 		foreach ($attachments as $attachment) {
 			$fileName = $attachment->getName();
-			$fh = fopen("php://temp", 'r+');
+			$fh = fopen('php://temp', 'r+');
 			fputs($fh, $attachment->getContent());
 			$size = $attachment->getSize();
 			rewind($fh);
@@ -887,6 +884,34 @@ class MessagesController extends Controller {
 		return new JSONResponse();
 	}
 
+	/**
+	 * @NoAdminRequired
+	 *
+	 * @param int $messageId
+	 *
+	 * @return JSONResponse
+	 */
+	#[TrapError]
+	public function smartReply(int $messageId):JSONResponse {
+		try {
+			$message = $this->mailManager->getMessage($this->currentUserId, $messageId);
+			$mailbox = $this->mailManager->getMailbox($this->currentUserId, $message->getMailboxId());
+			$account = $this->accountService->find($this->currentUserId, $mailbox->getAccountId());
+		} catch (DoesNotExistException $e) {
+			return new JSONResponse([], Http::STATUS_FORBIDDEN);
+		}
+		try {
+			$replies = array_values($this->aiIntegrationService->getSmartReply($account, $mailbox, $message, $this->currentUserId));
+		} catch (ServiceException $e) {
+			$this->logger->error('Smart reply failed: ' . $e->getMessage(), [
+				'exception' => $e,
+			]);
+			return new JSONResponse([], Http::STATUS_NO_CONTENT);
+		}
+		return new JSONResponse($replies);
+
+	}
+
 	/**
 	 * @param int $id
 	 * @param array $attachment
