@@ -10,6 +10,7 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Controller;
 
+use OCA\Contacts\Event\LoadContactsOcaApiEvent;
 use OCA\Mail\AppInfo\Application;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Contracts\IUserPreferences;
@@ -42,8 +43,6 @@ use OCP\IUserSession;
 use OCP\TextProcessing\FreePromptTaskType;
 use OCP\TextProcessing\SummaryTaskType;
 use OCP\User\IAvailabilityCoordinator;
-use Psr\Container\ContainerExceptionInterface;
-use Psr\Container\ContainerInterface;
 use Psr\Log\LoggerInterface;
 use Throwable;
 use function class_exists;
@@ -69,7 +68,7 @@ class PageController extends Controller {
 	private SmimeService $smimeService;
 	private AiIntegrationsService $aiIntegrationsService;
 	private IUserManager $userManager;
-	private ?IAvailabilityCoordinator $availabilityCoordinator;
+	private IAvailabilityCoordinator $availabilityCoordinator;
 	private ClassificationSettingsService $classificationSettingsService;
 	private InternalAddressService $internalAddressService;
 
@@ -79,22 +78,22 @@ class PageController extends Controller {
 		IConfig $config,
 		AccountService $accountService,
 		AliasesService $aliasesService,
-		?string          $UserId,
-		IUserSession     $userSession,
+		?string $UserId,
+		IUserSession $userSession,
 		IUserPreferences $preferences,
-		IMailManager     $mailManager,
-		TagMapper        $tagMapper,
-		IInitialState    $initialStateService,
-		LoggerInterface  $logger,
-		OutboxService    $outboxService,
+		IMailManager $mailManager,
+		TagMapper $tagMapper,
+		IInitialState $initialStateService,
+		LoggerInterface $logger,
+		OutboxService $outboxService,
 		IEventDispatcher $dispatcher,
 		ICredentialStore $credentialStore,
-		SmimeService     $smimeService,
+		SmimeService $smimeService,
 		AiIntegrationsService $aiIntegrationsService,
 		IUserManager $userManager,
-		ContainerInterface $container,
 		ClassificationSettingsService $classificationSettingsService,
-		InternalAddressService $internalAddressService, ) {
+		InternalAddressService $internalAddressService,
+		IAvailabilityCoordinator $availabilityCoordinator) {
 		parent::__construct($appName, $request);
 
 		$this->urlGenerator = $urlGenerator;
@@ -116,13 +115,7 @@ class PageController extends Controller {
 		$this->userManager = $userManager;
 		$this->classificationSettingsService = $classificationSettingsService;
 		$this->internalAddressService = $internalAddressService;
-
-		// TODO: inject directly if support for nextcloud < 28 is dropped
-		try {
-			$this->availabilityCoordinator = $container->get(IAvailabilityCoordinator::class);
-		} catch (ContainerExceptionInterface) {
-			$this->availabilityCoordinator = null;
-		}
+		$this->availabilityCoordinator = $availabilityCoordinator;
 	}
 
 	/**
@@ -187,6 +180,11 @@ class PageController extends Controller {
 			$this->preferences->getPreference($this->currentUserId, 'internal-addresses', false)
 		);
 
+		$this->initialStateService->provideInitialState(
+			'smime-sign-aliases',
+			json_decode($this->preferences->getPreference($this->currentUserId, 'smime-sign-aliases', '[]'), true, 512, JSON_THROW_ON_ERROR) ?? []
+		);
+
 		$this->initialStateService->provideInitialState(
 			'sort-order',
 			$this->preferences->getPreference($this->currentUserId, 'sort-order', 'newest')
@@ -204,19 +202,20 @@ class PageController extends Controller {
 		);
 
 		$user = $this->userSession->getUser();
-		$response = new TemplateResponse($this->appName, 'index',
-			[
-				'attachment-size-limit' => $this->config->getSystemValue('app.mail.attachment-size-limit', 0),
-				'app-version' => $this->config->getAppValue('mail', 'installed_version'),
-				'external-avatars' => $this->preferences->getPreference($this->currentUserId, 'external-avatars', 'true'),
-				'layout-mode' => $this->preferences->getPreference($this->currentUserId, 'layout-mode', 'vertical-split'),
-				'reply-mode' => $this->preferences->getPreference($this->currentUserId, 'reply-mode', 'top'),
-				'collect-data' => $this->preferences->getPreference($this->currentUserId, 'collect-data', 'true'),
-				'search-priority-body' => $this->preferences->getPreference($this->currentUserId, 'search-priority-body', 'false'),
-				'start-mailbox-id' => $this->preferences->getPreference($this->currentUserId, 'start-mailbox-id'),
-				'tag-classified-messages' => $this->classificationSettingsService->isClassificationEnabled($this->currentUserId) ? 'true' : 'false',
-				'follow-up-reminders' => $this->preferences->getPreference($this->currentUserId, 'follow-up-reminders', 'true'),
-			]);
+		$response = new TemplateResponse($this->appName, 'index');
+		$this->initialStateService->provideInitialState('preferences', [
+			'attachment-size-limit' => $this->config->getSystemValue('app.mail.attachment-size-limit', 0),
+			'app-version' => $this->config->getAppValue('mail', 'installed_version'),
+			'external-avatars' => $this->preferences->getPreference($this->currentUserId, 'external-avatars', 'true'),
+			'layout-mode' => $this->preferences->getPreference($this->currentUserId, 'layout-mode', 'vertical-split'),
+			'layout-message-view' => $this->preferences->getPreference($this->currentUserId, 'layout-message-view', $this->config->getAppValue('mail', 'layout_message_view', 'threaded')),
+			'reply-mode' => $this->preferences->getPreference($this->currentUserId, 'reply-mode', 'top'),
+			'collect-data' => $this->preferences->getPreference($this->currentUserId, 'collect-data', 'true'),
+			'search-priority-body' => $this->preferences->getPreference($this->currentUserId, 'search-priority-body', 'false'),
+			'start-mailbox-id' => $this->preferences->getPreference($this->currentUserId, 'start-mailbox-id'),
+			'tag-classified-messages' => $this->classificationSettingsService->isClassificationEnabled($this->currentUserId) ? 'true' : 'false',
+			'follow-up-reminders' => $this->preferences->getPreference($this->currentUserId, 'follow-up-reminders', 'true'),
+		]);
 		$this->initialStateService->provideInitialState(
 			'prefill_displayName',
 			$this->userManager->getDisplayName($this->currentUserId),
@@ -286,6 +285,11 @@ class PageController extends Controller {
 			$this->aiIntegrationsService->isLlmProcessingEnabled() && $this->aiIntegrationsService->isLlmAvailable(SummaryTaskType::class)
 		);
 
+		$this->initialStateService->provideInitialState(
+			'llm_translation_enabled',
+			$this->aiIntegrationsService->isLlmProcessingEnabled() && $this->aiIntegrationsService->isTaskAvailable('core:text2text:translate')
+		);
+
 		$this->initialStateService->provideInitialState(
 			'llm_freeprompt_available',
 			$this->aiIntegrationsService->isLlmProcessingEnabled() && $this->aiIntegrationsService->isLlmAvailable(FreePromptTaskType::class)
@@ -307,17 +311,20 @@ class PageController extends Controller {
 			),
 		);
 
-		if ($this->availabilityCoordinator !== null) {
-			$this->initialStateService->provideInitialState(
-				'enable-system-out-of-office',
-				$this->availabilityCoordinator->isEnabled(),
-			);
-		}
+		$this->initialStateService->provideInitialState(
+			'enable-system-out-of-office',
+			$this->availabilityCoordinator->isEnabled(),
+		);
 
 		$csp = new ContentSecurityPolicy();
 		$csp->addAllowedFrameDomain('\'self\'');
 		$response->setContentSecurityPolicy($csp);
 		$this->dispatcher->dispatchTyped(new RenderReferenceEvent());
+
+		if (class_exists(LoadContactsOcaApiEvent::class)) {
+			$this->dispatcher->dispatchTyped(new LoadContactsOcaApiEvent());
+		}
+
 		return $response;
 	}
 
