@@ -69,6 +69,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	private bool $isEncrypted;
 	private bool $isSigned;
 	private bool $signatureIsValid;
+	private bool $isPgpMimeEncrypted;
 
 	public function __construct(int $uid,
 		string $messageId,
@@ -98,7 +99,8 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		bool $isEncrypted,
 		bool $isSigned,
 		bool $signatureIsValid,
-		Html $htmlService) {
+		Html $htmlService,
+		bool $isPgpMimeEncrypted) {
 		$this->messageId = $uid;
 		$this->realMessageId = $messageId;
 		$this->flags = $flags;
@@ -128,6 +130,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		$this->isSigned = $isSigned;
 		$this->signatureIsValid = $signatureIsValid;
 		$this->htmlService = $htmlService;
+		$this->isPgpMimeEncrypted = $isPgpMimeEncrypted;
 	}
 
 	public static function generateMessageId(): string {
@@ -145,6 +148,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 * @deprecated  Seems unused
 	 * @return array
 	 */
+	#[\Override]
 	public function getFlags(): array {
 		return [
 			'seen' => in_array(Horde_Imap_Client::FLAG_SEEN, $this->flags),
@@ -167,6 +171,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function setFlags(array $flags) {
 		// TODO: implement
 		throw new Exception('Not implemented');
@@ -184,6 +189,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		return $this->dispositionNotificationTo;
 	}
 
+	#[\Override]
 	public function getFrom(): AddressList {
 		return $this->from;
 	}
@@ -195,10 +201,12 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function setFrom(AddressList $from) {
 		throw new Exception('IMAP message is immutable');
 	}
 
+	#[\Override]
 	public function getTo(): AddressList {
 		return $this->to;
 	}
@@ -210,10 +218,12 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function setTo(AddressList $to) {
 		throw new Exception('IMAP message is immutable');
 	}
 
+	#[\Override]
 	public function getCC(): AddressList {
 		return $this->cc;
 	}
@@ -225,10 +235,12 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function setCC(AddressList $cc) {
 		throw new Exception('IMAP message is immutable');
 	}
 
+	#[\Override]
 	public function getBCC(): AddressList {
 		return $this->bcc;
 	}
@@ -240,14 +252,17 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function setBcc(AddressList $bcc) {
 		throw new Exception('IMAP message is immutable');
 	}
 
+	#[\Override]
 	public function getMessageId(): string {
 		return $this->realMessageId;
 	}
 
+	#[\Override]
 	public function getSubject(): string {
 		return $this->subject;
 	}
@@ -259,6 +274,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function setSubject(string $subject) {
 		throw new Exception('IMAP message is immutable');
 	}
@@ -276,7 +292,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		$mailBody = $this->plainMessage;
 		$data = $this->jsonSerialize();
 
-		if($this->hasHtmlMessage && $loadBody) {
+		if ($this->hasHtmlMessage && $loadBody) {
 			$data['body'] = $this->getHtmlBody($id);
 		}
 
@@ -290,12 +306,13 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		[$mailBody, $signature] = $this->htmlService->parseMailBody($mailBody);
 		$data['signature'] = $signature;
 		$data['attachments'] = array_merge($this->attachments, $this->inlineAttachments);
-		if($loadBody) {
+		if ($loadBody) {
 			$data['body'] = $mailBody;
 		}
 		return $data;
 	}
 
+	#[\Override]
 	#[ReturnTypeWillChange]
 	public function jsonSerialize() {
 		return [
@@ -317,6 +334,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 			'isOneClickUnsubscribe' => $this->isOneClickUnsubscribe,
 			'unsubscribeMailto' => $this->unsubscribeMailto,
 			'scheduling' => $this->scheduling,
+			'isPgpMimeEncrypted' => $this->isPgpMimeEncrypted,
 		];
 	}
 
@@ -348,6 +366,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		return $this->plainMessage;
 	}
 
+	#[\Override]
 	public function getContent(): string {
 		return $this->getPlainBody();
 	}
@@ -355,6 +374,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	/**
 	 * @return void
 	 */
+	#[\Override]
 	public function setContent(string $content) {
 		throw new Exception('IMAP message is immutable');
 	}
@@ -362,6 +382,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	/**
 	 * @return Horde_Mime_Part[]
 	 */
+	#[\Override]
 	public function getAttachments(): array {
 		throw new Exception('not implemented');
 	}
@@ -372,6 +393,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function addRawAttachment(string $name, string $content): void {
 		throw new Exception('IMAP message is immutable');
 	}
@@ -382,6 +404,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function addEmbeddedMessageAttachment(string $name, string $content): void {
 		throw new Exception('IMAP message is immutable');
 	}
@@ -391,6 +414,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function addAttachmentFromFiles(File $file) {
 		throw new Exception('IMAP message is immutable');
 	}
@@ -401,6 +425,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function addLocalAttachment(LocalAttachment $attachment, ISimpleFile $file) {
 		throw new Exception('IMAP message is immutable');
 	}
@@ -408,6 +433,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	/**
 	 * @return string|null
 	 */
+	#[\Override]
 	public function getInReplyTo() {
 		throw new Exception('not implemented');
 	}
@@ -417,6 +443,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function setInReplyTo(string $id) {
 		throw new Exception('not implemented');
 	}
@@ -424,6 +451,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	/**
 	 * @return AddressList
 	 */
+	#[\Override]
 	public function getReplyTo(): AddressList {
 		return $this->replyTo;
 	}
@@ -435,6 +463,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 *
 	 * @return void
 	 */
+	#[\Override]
 	public function setReplyTo(AddressList $replyTo) {
 		throw new Exception('IMAP message is immutable');
 	}
@@ -459,6 +488,10 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		return $this->isOneClickUnsubscribe;
 	}
 
+	public function isPgpMimeEncrypted(): bool {
+		return $this->isPgpMimeEncrypted;
+	}
+
 	/**
 	 * Cast all values from an IMAP message into the correct DB format
 	 *
@@ -498,8 +531,8 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		$msg->setFlagSeen(in_array(Horde_Imap_Client::FLAG_SEEN, $flags, true));
 		$msg->setFlagForwarded(in_array(Horde_Imap_Client::FLAG_FORWARDED, $flags, true));
 		$msg->setFlagJunk(
-			in_array(Horde_Imap_Client::FLAG_JUNK, $flags, true) ||
-			in_array('junk', $flags, true)
+			in_array(Horde_Imap_Client::FLAG_JUNK, $flags, true)
+			|| in_array('junk', $flags, true)
 		);
 		$msg->setFlagNotjunk(in_array(Horde_Imap_Client::FLAG_NOTJUNK, $flags, true) || in_array('nonjunk', $flags, true));// While this is not a standard IMAP Flag, Thunderbird uses it to mark "not junk"
 		// @todo remove this as soon as possible @link https://github.com/nextcloud/mail/issues/25
