@@ -3,23 +3,9 @@
 declare(strict_types=1);
 
 /**
- * @author Tahaa Karim <tahaalibra@gmail.com>
- * @author Richard Steinmetz <richard@steinmetz.cloud>
- *
- * Mail
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 namespace OCA\Mail\Service;
@@ -61,6 +47,16 @@ class AliasesService {
 		return $this->aliasMapper->find($aliasId, $currentUserId);
 	}
 
+	/**
+	 * @param string $aliasEmail
+	 * @param string $userId
+	 * @return Alias
+	 * @throws DoesNotExistException
+	 */
+	public function findByAliasAndUserId(string $aliasEmail, string $userId): Alias {
+		return $this->aliasMapper->findByAlias($aliasEmail, $userId);
+	}
+
 	/**
 	 * @param string $userId
 	 * @param int $accountId
