@@ -3,30 +3,39 @@
 declare(strict_types=1);
 
 /**
- * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2020-2024 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Mail\Service\Classification;
 
+use Closure;
 use Horde_Imap_Client;
 use OCA\Mail\Account;
-use OCA\Mail\Db\Classifier;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Db\MailboxMapper;
 use OCA\Mail\Db\Message;
 use OCA\Mail\Db\MessageMapper;
 use OCA\Mail\Exception\ClassifierTrainingException;
 use OCA\Mail\Exception\ServiceException;
+use OCA\Mail\Model\Classifier;
+use OCA\Mail\Model\ClassifierPipeline;
 use OCA\Mail\Service\Classification\FeatureExtraction\CompositeExtractor;
+use OCA\Mail\Service\Classification\FeatureExtraction\IExtractor;
 use OCA\Mail\Support\PerformanceLogger;
+use OCA\Mail\Support\PerformanceLoggerTask;
 use OCP\AppFramework\Db\DoesNotExistException;
+use Psr\Container\ContainerExceptionInterface;
+use Psr\Container\ContainerInterface;
 use Psr\Log\LoggerInterface;
-use Rubix\ML\Classifiers\GaussianNB;
+use Rubix\ML\Classifiers\KNearestNeighbors;
 use Rubix\ML\CrossValidation\Reports\MulticlassBreakdown;
 use Rubix\ML\Datasets\Labeled;
 use Rubix\ML\Datasets\Unlabeled;
 use Rubix\ML\Estimator;
+use Rubix\ML\Kernels\Distance\Manhattan;
+use Rubix\ML\Learner;
+use Rubix\ML\Persistable;
 use RuntimeException;
 use function array_column;
 use function array_combine;
@@ -64,12 +73,12 @@ class ImportanceClassifier {
 	/**
 	 * @var string label for data sets that are classified as important
 	 */
-	private const LABEL_IMPORTANT = 'i';
+	public const LABEL_IMPORTANT = 'i';
 
 	/**
 	 * @var string label for data sets that are classified as not important
 	 */
-	private const LABEL_NOT_IMPORTANT = 'ni';
+	public const LABEL_NOT_IMPORTANT = 'ni';
 
 	/**
 	 * The minimum number of important messages. Without those the unsupervised
@@ -81,7 +90,7 @@ class ImportanceClassifier {
 	/**
 	 * The maximum number of data sets to train the classifier with
 	 */
-	private const MAX_TRAINING_SET_SIZE = 1000;
+	private const MAX_TRAINING_SET_SIZE = 300;
 
 	/** @var MailboxMapper */
 	private $mailboxMapper;
@@ -89,9 +98,6 @@ class ImportanceClassifier {
 	/** @var MessageMapper */
 	private $messageMapper;
 
-	/** @var CompositeExtractor */
-	private $extractor;
-
 	/** @var PersistenceService */
 	private $persistenceService;
 
@@ -101,22 +107,40 @@ class ImportanceClassifier {
 	/** @var ImportanceRulesClassifier */
 	private $rulesClassifier;
 
-	private LoggerInterface $logger;
+	private ContainerInterface $container;
 
 	public function __construct(MailboxMapper $mailboxMapper,
 		MessageMapper $messageMapper,
-		CompositeExtractor $extractor,
 		PersistenceService $persistenceService,
 		PerformanceLogger $performanceLogger,
 		ImportanceRulesClassifier $rulesClassifier,
-		LoggerInterface $logger) {
+		ContainerInterface $container) {
 		$this->mailboxMapper = $mailboxMapper;
 		$this->messageMapper = $messageMapper;
-		$this->extractor = $extractor;
 		$this->persistenceService = $persistenceService;
 		$this->performanceLogger = $performanceLogger;
 		$this->rulesClassifier = $rulesClassifier;
-		$this->logger = $logger;
+		$this->container = $container;
+	}
+
+	private static function createDefaultEstimator(): KNearestNeighbors {
+		// A meta estimator was trained on the same data multiple times to average out the
+		// variance of the trained model.
+		// Parameters were chosen from the best configuration across 100 runs.
+		// Both variance (spread) and f1 score were considered.
+		// Note: Lower k values yield slightly higher f1 scores but show higher variances.
+		return new KNearestNeighbors(15, true, new Manhattan());
+	}
+
+	/**
+	 * @throws ServiceException If the extractor is not available
+	 */
+	private function createExtractor(): CompositeExtractor {
+		try {
+			return $this->container->get(CompositeExtractor::class);
+		} catch (ContainerExceptionInterface $e) {
+			throw new ServiceException('Default extractor is not available', 0, $e);
+		}
 	}
 
 	private function filterMessageHasSenderEmail(Message $message): bool {
@@ -124,22 +148,24 @@ class ImportanceClassifier {
 	}
 
 	/**
-	 * Train an account's classifier of important messages
-	 *
-	 * Train a classifier based on a user's existing messages to be able to derive
-	 * importance markers for new incoming messages.
-	 *
-	 * To factor in (server-side) filtering into multiple mailboxes, the algorithm
-	 * will not only look for messages in the inbox but also other non-special
-	 * mailboxes.
-	 *
-	 * To prevent memory exhaustion, the process will only load a fixed maximum
-	 * number of messages per account.
+	 * Build a data set for training an importance classifier.
 	 *
 	 * @param Account $account
+	 * @param IExtractor $extractor
+	 * @param LoggerInterface $logger
+	 * @param PerformanceLoggerTask|null $perf
+	 * @param bool $shuffle
+	 * @return array|null Returns null if there are not enough messages to train
 	 */
-	public function train(Account $account, LoggerInterface $logger): void {
-		$perf = $this->performanceLogger->start('importance classifier training');
+	public function buildDataSet(
+		Account $account,
+		IExtractor $extractor,
+		LoggerInterface $logger,
+		?PerformanceLoggerTask $perf = null,
+		bool $shuffle = false,
+	): ?array {
+		$perf ??= $this->performanceLogger->start('build data set for importance classifier training');
+
 		$incomingMailboxes = $this->getIncomingMailboxes($account);
 		$logger->debug('found ' . count($incomingMailboxes) . ' incoming mailbox(es)');
 		$perf->step('find incoming mailboxes');
@@ -160,30 +186,128 @@ class ImportanceClassifier {
 		$logger->debug('found ' . count($messages) . ' messages of which ' . count($importantMessages) . ' are important');
 		if (count($importantMessages) < self::COLD_START_THRESHOLD) {
 			$logger->info('not enough messages to train a classifier');
-			$perf->end();
-			return;
+			return null;
 		}
 		$perf->step('find latest ' . self::MAX_TRAINING_SET_SIZE . ' messages');
 
-		$dataSet = $this->getFeaturesAndImportance($account, $incomingMailboxes, $outgoingMailboxes, $messages);
-		$perf->step('extract features from messages');
+		$dataSet = $this->getFeaturesAndImportance($account, $incomingMailboxes, $outgoingMailboxes, $messages, $extractor);
+		if ($shuffle) {
+			shuffle($dataSet);
+		}
+
+		return $dataSet;
+	}
+
+	/**
+	 * Train an account's classifier of important messages
+	 *
+	 * Train a classifier based on a user's existing messages to be able to derive
+	 * importance markers for new incoming messages.
+	 *
+	 * To factor in (server-side) filtering into multiple mailboxes, the algorithm
+	 * will not only look for messages in the inbox but also other non-special
+	 * mailboxes.
+	 *
+	 * To prevent memory exhaustion, the process will only load a fixed maximum
+	 * number of messages per account.
+	 *
+	 * @param Account $account
+	 * @param LoggerInterface $logger
+	 * @param ?Closure $estimator Returned instance should at least implement Learner, Estimator and Persistable. If null, the default estimator will be used.
+	 * @param bool $shuffleDataSet Shuffle the data set before training
+	 * @param bool $persist Persist the trained classifier to use it for message classification
+	 *
+	 * @return ClassifierPipeline|null The validation estimator, persisted estimator (if `$persist` === true) or null in case none was trained
+	 *
+	 * @throws ServiceException
+	 */
+	public function train(
+		Account $account,
+		LoggerInterface $logger,
+		?Closure $estimator = null,
+		bool $shuffleDataSet = false,
+		bool $persist = true,
+	): ?ClassifierPipeline {
+		$perf = $this->performanceLogger->start('importance classifier training');
+
+		$extractor = $this->createExtractor();
+		$dataSet = $this->buildDataSet($account, $extractor, $logger, $perf, $shuffleDataSet);
+		if ($dataSet === null) {
+			return null;
+		}
+
+		return $this->trainWithCustomDataSet(
+			$account,
+			$logger,
+			$dataSet,
+			$extractor,
+			$estimator,
+			$perf,
+			$persist,
+		);
+	}
+
+	/**
+	 * Train a classifier using a custom data set.
+	 *
+	 * @param Account $account
+	 * @param LoggerInterface $logger
+	 * @param array $dataSet Training data set built by buildDataSet()
+	 * @param CompositeExtractor $extractor Extractor used to extract the given data set
+	 * @param ?Closure $estimator Returned instance should at least implement Learner, Estimator and Persistable. If null, the default estimator will be used.
+	 * @param PerformanceLoggerTask|null $perf Optionally reuse a performance logger task
+	 * @param bool $persist Persist the trained classifier to use it for message classification
+	 *
+	 * @return ClassifierPipeline|null The validation estimator, persisted estimator (if `$persist` === true) or null in case none was trained
+	 *
+	 * @throws ServiceException
+	 */
+	private function trainWithCustomDataSet(
+		Account $account,
+		LoggerInterface $logger,
+		array $dataSet,
+		CompositeExtractor $extractor,
+		?Closure $estimator,
+		?PerformanceLoggerTask $perf = null,
+		bool $persist = true,
+	): ?ClassifierPipeline {
+		$perf ??= $this->performanceLogger->start('importance classifier training');
+		$estimator ??= self::createDefaultEstimator(...);
 
 		/**
 		 * How many of the most recent messages are excluded from training?
 		 */
 		$validationThreshold = max(
 			5,
-			(int)(count($dataSet) * 0.1)
+			(int)(count($dataSet) * 0.2)
 		);
 		$validationSet = array_slice($dataSet, 0, $validationThreshold);
 		$trainingSet = array_slice($dataSet, $validationThreshold);
-		$logger->debug('data set split into ' . count($trainingSet) . ' training and ' . count($validationSet) . ' validation sets with ' . count($trainingSet[0]['features'] ?? []) . ' dimensions');
+
+		$validationSetImportantCount = 0;
+		$trainingSetImportantCount = 0;
+		foreach ($validationSet as $data) {
+			if ($data['label'] === self::LABEL_IMPORTANT) {
+				$validationSetImportantCount++;
+			}
+		}
+		foreach ($trainingSet as $data) {
+			if ($data['label'] === self::LABEL_IMPORTANT) {
+				$trainingSetImportantCount++;
+			}
+		}
+
+		$logger->debug('data set split into ' . count($trainingSet) . ' (' . self::LABEL_IMPORTANT . ': ' . $trainingSetImportantCount . ') training and ' . count($validationSet) . ' (' . self::LABEL_IMPORTANT . ': ' . $validationSetImportantCount . ') validation sets with ' . count($trainingSet[0]['features'] ?? []) . ' dimensions');
+
 		if ($validationSet === [] || $trainingSet === []) {
 			$logger->info('not enough messages to train a classifier');
 			$perf->end();
-			return;
+			return null;
 		}
-		$validationEstimator = $this->trainClassifier($trainingSet);
+
+		/** @var Learner&Estimator&Persistable $validationEstimator */
+		$validationEstimator = $estimator();
+		$this->trainClassifier($validationEstimator, $validationSet);
 		try {
 			$classifier = $this->validateClassifier(
 				$validationEstimator,
@@ -196,19 +320,31 @@ class ImportanceClassifier {
 				'exception' => $e,
 			]);
 			$perf->end();
-			return;
+			return null;
 		}
 		$perf->step('train and validate classifier with training and validation sets');
 
-		$estimator = $this->trainClassifier($dataSet);
-		$perf->step('train classifier with full data set');
+		if (!$persist) {
+			return new ClassifierPipeline($validationEstimator, $extractor);
+		}
 
-		$classifier->setAccountId($account->getId());
+		/** @var Learner&Estimator&Persistable $persistedEstimator */
+		$persistedEstimator = $estimator();
+		$this->trainClassifier($persistedEstimator, $dataSet);
+		$perf->step('train classifier with full data set');
 		$classifier->setDuration($perf->end());
-		$this->persistenceService->persist($classifier, $estimator);
-		$logger->debug("classifier {$classifier->getId()} persisted");
+		$classifier->setAccountId($account->getId());
+		$classifier->setEstimator(get_class($persistedEstimator));
+		$classifier->setPersistenceVersion(PersistenceService::VERSION);
+
+		$this->persistenceService->persist($account, $persistedEstimator, $extractor);
+		$logger->debug("Classifier for account {$account->getId()} persisted", [
+			'classifier' => $classifier,
+		]);
+		return new ClassifierPipeline($persistedEstimator, $extractor);
 	}
 
+
 	/**
 	 * @param Account $account
 	 *
@@ -259,17 +395,20 @@ class ImportanceClassifier {
 	private function getFeaturesAndImportance(Account $account,
 		array $incomingMailboxes,
 		array $outgoingMailboxes,
-		array $messages): array {
-		$this->extractor->prepare($account, $incomingMailboxes, $outgoingMailboxes, $messages);
+		array $messages,
+		IExtractor $extractor): array {
+		$extractor->prepare($account, $incomingMailboxes, $outgoingMailboxes, $messages);
 
-		return array_map(function (Message $message) {
+		return array_map(static function (Message $message) use ($extractor) {
 			$sender = $message->getFrom()->first();
 			if ($sender === null) {
 				throw new RuntimeException('This should not happen');
 			}
 
+			$features = $extractor->extract($message);
+
 			return [
-				'features' => $this->extractor->extract($message),
+				'features' => $features,
 				'label' => $message->getFlagImportant() ? self::LABEL_IMPORTANT : self::LABEL_NOT_IMPORTANT,
 				'sender' => $sender->getEmail(),
 			];
@@ -279,21 +418,38 @@ class ImportanceClassifier {
 	/**
 	 * @param Account $account
 	 * @param Message[] $messages
+	 * @param LoggerInterface $logger
 	 *
 	 * @return bool[]
+	 *
 	 * @throws ServiceException
 	 */
-	public function classifyImportance(Account $account, array $messages): array {
-		$estimator = null;
+	public function classifyImportance(Account $account,
+		array $messages,
+		LoggerInterface $logger): array {
+		$pipeline = null;
 		try {
-			$estimator = $this->persistenceService->loadLatest($account);
+			$pipeline = $this->persistenceService->loadLatest($account);
 		} catch (ServiceException $e) {
-			$this->logger->warning('Failed to load importance classifier: ' . $e->getMessage(), [
+			$logger->warning('Failed to load persisted estimator and extractor: ' . $e->getMessage(), [
 				'exception' => $e,
 			]);
 		}
 
-		if ($estimator === null) {
+		// Persistence is disabled on some instances (due to no memory cache being available).
+		// Try to train a classifier on-the-fly on those instances.
+		if ($pipeline === null) {
+			$pipeline = $this->train($account, $logger);
+		}
+
+		// Can't train pipeline and no persistence available? -> Skip rule based classifier ...
+		// It won't yield good results. Instead, we have to wait for the user to accumulate more
+		// emails so that training a classifier succeeds.
+		if ($pipeline === null && !$this->persistenceService->isAvailable()) {
+			return [];
+		}
+
+		if ($pipeline === null) {
 			$predictions = $this->rulesClassifier->classifyImportance(
 				$account,
 				$this->getIncomingMailboxes($account),
@@ -309,15 +465,16 @@ class ImportanceClassifier {
 				}, $messages)
 			);
 		}
-		$messagesWithSender = array_filter($messages, [$this, 'filterMessageHasSenderEmail']);
 
+		$messagesWithSender = array_filter($messages, [$this, 'filterMessageHasSenderEmail']);
 		$features = $this->getFeaturesAndImportance(
 			$account,
 			$this->getIncomingMailboxes($account),
 			$this->getOutgoingMailboxes($account),
-			$messagesWithSender
+			$messagesWithSender,
+			$pipeline->getExtractor(),
 		);
-		$predictions = $estimator->predict(
+		$predictions = $pipeline->getEstimator()->predict(
 			Unlabeled::build(array_column($features, 'features'))
 		);
 		return array_combine(
@@ -330,22 +487,20 @@ class ImportanceClassifier {
 		);
 	}
 
-	private function trainClassifier(array $trainingSet): GaussianNB {
-		$classifier = new GaussianNB();
+	private function trainClassifier(Learner $classifier, array $trainingSet): void {
 		$classifier->train(Labeled::build(
 			array_column($trainingSet, 'features'),
 			array_column($trainingSet, 'label')
 		));
-		return $classifier;
 	}
 
 	/**
 	 * @param Estimator $estimator
 	 * @param array $trainingSet
 	 * @param array $validationSet
+	 * @param LoggerInterface $logger
 	 *
 	 * @return Classifier
-	 * @throws ClassifierTrainingException
 	 */
 	private function validateClassifier(Estimator $estimator,
 		array $trainingSet,
